##' *PAPER 3 LETS GO######
##' 
#load libraries
devtools::install_github("pzylstra/frame_r", build_vignettes = TRUE)
install.packages("processx")
install.packages("frame_r")
library(frame)

loadApp_mini <- function(){
  load.lib<-c("broom", "cowplot", "DHARMa", 
              "dplyr", "emmeans", "extraDistr", 
              "ggplot2", "ggeffects", "ggpubr", 
              "ggstance", "glmmTMB", "jtools",
              "loo", "MuMIn", "performance",
              "readxl", "robustHD", "Rmisc", 
              "SciViews", "sjPlot", "tidyverse"
              )
  install.lib <- load.lib[!load.lib %in% installed.packages()]
  for(lib in install.lib) install.packages(lib,dependences=TRUE)
  sapply(load.lib,require,character=TRUE)
}
loadApp_mini()

#data
site_all_ex        <- read_excel("C:/Users/User/Documents/PhD/paper_3/site_all_v2.xlsx")
traits_all_ex      <- read_excel("C:/Users/User/Documents/PhD/paper_3/trait_data_v3.xlsx")
weather_all_ex     <- read_excel("C:/Users/User/Documents/PhD/paper_3/weather_variables.xlsx")
flora_all_ex       <- read_excel("C:/Users/User/Documents/PhD/paper_3/flora_all_v5.xlsx")
structure_all_ex   <- read_excel("C:/Users/User/Documents/PhD/paper_3/structure_all_v4.xlsx")
fire_data_ex       <- read_excel("C:/Users/User/Documents/PhD/paper_3/fire_data_v1.xlsx")
spacing_ex         <- read_excel("C:/Users/User/Documents/PhD/paper_3/spacing_analysis.xlsx")

#dropping some columns to fit with model input
site_all      <- subset(site_all_ex, select = -c(1:4))
flora_all     <- subset(flora_all_ex, select = -c(2,3))
structure_all <- structure_all_ex
traits_all    <- traits_all_ex
fire_data     <- fire_data_ex
weather_all   <- weather_all_ex[-c(6:28),]

#weather set 1 (w1) is a remnant from a trail using dummy data for fire behaviour predictions, can be ignored

#values from Zylstra (2011)
saplingBark   <- 0.01
treeBark      <- 0.04
saplingPhloem <- 0.005
treePhloem    <- 0.01
step          <- 0.01

records       <- c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
                   11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
                   21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
                   31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
                   41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
                   51, 52, 53, 54, 55, 56, 57, 58, 59, 60,
                   61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
                   71, 72, 73, 74, 75, 76, 77, 78)
weather_unique <- c(1, 2, 3, 4, 5)

#-----------------------looping------------------------------
set.seed(3456) 

for(w in weather_unique){
    weather_sub <- subset(weather_all, weather_all$weather_set == w)
    temp_sub <- weather_sub$temperature
    dfmc_sub <- (weather_sub$DFMC * 0.01)
    wind_sub <- weather_sub$wind

      for(r in records){
        #subset all data frames to the site level
        site_sub      <- subset(site_all, site_all$record == r)
        s <- site_sub$site
        flora_sub     <- subset(flora_all, flora_all$record == r)
        structure_sub <- subset(structure_all, structure_all$record == r)
        record <- r
  
            base.params <- paramBuilder(site_sub, structure_sub, flora_sub, traits_all, record)
            
            probFire(base.params, db.path = "out_mc.db", jitters = 50, slope = 0, slopeSD = 0.01, slopeRange = 1,
                     temp = 33, tempSD = 0.1, 
                     tempRange = temp_sub, 
                     DFMC = dfmc_sub, 
                     DFMCSD = 0.01, DFMCRange = 2,
                     wind = wind_sub, 
                     windSD = 0.1, windRange = 1, moistureMultiplier = 1, moistureSD = 0.01, moistureRange = 1.5,
                     heightSD = 2, heightRange = 1.41, leafVar = 0.1, updateProgress = TRUE)
            
            res <-ffm_db_load("out_mc.db")
            runs <- summary(res$FlameSummaries, res$Sites, res$ROS, res$SurfaceResults)%>%
              mutate(byram = 20000*(as.numeric(base.params$value[base.params$param == "fuelLoad"])/10)*(ros_kph/3.6))
          
        #write into data frame
        fire_data$zyl_ros[fire_data$site == s & fire_data$record == r & fire_data$weather_set == w] <- mean(runs$ros_kph)
        fire_data$zyl_fht[fire_data$site == s & fire_data$record == r & fire_data$weather_set == w] <- mean(runs$fh)
        fire_data$wind[fire_data$site == s & fire_data$record == r & fire_data$weather_set == w] <- wind_sub
        fire_data$temp[fire_data$site == s & fire_data$record == r & fire_data$weather_set == w] <- temp_sub
        fire_data$dfmc[fire_data$site == s & fire_data$record == r & fire_data$weather_set == w] <- dfmc_sub
  } 
}

#rate of spread is in km/hr
fire_data$zyl_fli <- 16000 * (fire_data$total_fuel_t_ha/10) * (fire_data$zyl_ros/3.6) #dividing by 3.6 to get to m/s for formula

hist(fire_data$zyl_fli)
hist(fire_data$zyl_fht)

#--------------------------FUEL DATA------------------------------------------------------
detach("package:frame_r", unload=TRUE) #need to detach frame here or it doesnt work

fuel_ex   <- read_excel("C:/Users/User/Documents/PhD/paper_3/fuel_data.xlsx")

fuel              <- fuel_ex
fuel$treatment    <- factor(fuel$treatment, levels = c("open", "partial", "closed"))
fuel$fire_treat   <- factor(fuel$fire_treat, levels = c("unburnt", "burnt"))
fuel$year         <- as.factor(fuel$year)
fuel_output       <- subset(fuel, select = -c(6,9,12,13,14,15,17,18))

#####################################
#####################################
weather_unique <- c(1, 2, 3, 4, 5)

for(w in weather_unique){
  weather_sub <- subset(weather_all, weather_all$weather_set == w)
  temp_sub <- weather_sub$temperature
  dfmc_sub <- weather_sub$DFMC
  wind_sub <- weather_sub$wind #wind speed
  humi_sub <- weather_sub$humidity   #humidity
  dght_sub <- weather_sub$`dought factor`   #drought factor
  bias  <- 1.07 #correction bias for vesta
  
  fuel_sub <- subset(fuel, fuel$weather_set == w)
  #Mk5
  fuel_sub$mkv_fdi  <-  2 * exp(-0.45 + 0.987 * ln(dght_sub) - 0.0345 * humi_sub + 0.0338 * temp_sub + 0.0234 * wind_sub)
  fuel_sub$mkv_mois     <- 5.658 + (0.04651 * humi_sub) + (0.0003151 * (humi_sub)^3 * (temp_sub)^-1) - (0.184 * (temp_sub)^0.77)
  fuel_sub$mkv_ros    <- 0.0012 * fuel_sub$mkv_fdi * fuel_sub$total_fuel_t_ha 
  fuel_sub$mkv_fli  <- 16000 * (fuel_sub$total_fuel_t_ha/10) * (fuel_sub$mkv_ros/3.6) 
  fuel_sub$mkv_fht    <- 13 * fuel_sub$mkv_ros + 0.24 * fuel_sub$total_fuel_t_ha - 2
  
  #Ves mk2
  fuel_sub$ves2_w2m <- wind_sub/3.4 #3.4 was chosen as the 'wind reduction factor' for stand canopy b/w 30-60% and stand height 10-30m
  
  fuel_sub$ves2_mdc <- 0.9082 + 0.1206 * dfmc_sub - 0.03106 * (dfmc_sub)^2 + 0.001853 * (dfmc_sub)^3 - 0.00003467 * (dfmc_sub)^4

  fuel_sub$ves2_fav <- 1.008/(1 + 104.9 * exp(-0.9306 * dght_sub)) #fuel availability function

  fuel_sub$ves2_fme <- fuel_sub$ves2_mdc * fuel_sub$ves2_fav #overall fuel moisture effect function
  
  fuel_sub$ves2_gxph2  <- -23.915 + 1.7033 * fuel_sub$ves2_w2m + 12.0822 * fuel_sub$ves2_fme + 0.95236 * (fuel_sub$sur_t_ha + fuel_sub$ns_t_ha) #the logit for the transition likelihood that takes into
  #account the effect of understorey wind speed (U2), the fuel moisture effect (M) and fuel load (Ws, t/ha) of surface fuels 
  fuel_sub$ves2_ph2 <- 1/(1+ exp(-(ves2_gxph2)))
  
  fuel_sub$ves2_gxph3 <- -32.3074 + 0.2951 * wind_sub + 26.8734 * fuel_sub$ves2_fme

  fuel_sub$ves2_rosph1 <- (0.03 + 0.05024 * (fuel_sub$ves2_w2m - 1)^0.92628 * ((fuel_sub$sur_t_ha + fuel_sub$ns_t_ha)/10)^0.79928) * fuel_sub$ves2_fme # used for wind speeds (U2) > 2km/hr

  fuel_sub$ves2_hun <- -0.1 + 0.06 * fuel_sub$ele_fhs + 0.48 * fuel_sub$ele_m #average height of understory fuel 
  fuel_sub$ves2_rosph2 <- 0.19591 * (fuel_sub$ves2_w2m)^0.8257 * ((fuel_sub$sur_t_ha + fuel_sub$ns_t_ha)/10)^0.4672 * (fuel_sub$ves2_hun)^0.495 * fuel_sub$ves2_fme #for observed ros between 0.1 - 1.5 km/h

  fuel_sub$ves2_ph3 <- ifelse(fuel_sub$ves2_rosph2 < 0.3, 0, 1/(1+exp(-(fuel_sub$ves2_gxph3))))
  
  fuel_sub$ves2_rosph3 <- 0.05235 * (wind_sub)^1.19128 * fuel_sub$ves2_fme
  
  fuel_sub$ves2_ros_fin <- ifelse(fuel_sub$ves2_ph2 < 0.5, fuel_sub$ves2_rosph1 * (1 - fuel_sub$ves2_ph2) + fuel_sub$ves2_rosph2 * fuel_sub$ves2_ph2,
                                  (fuel_sub$ves2_rosph1 * (1 - fuel_sub$ves2_ph2) + fuel_sub$ves2_rosph2 * fuel_sub$ves2_ph2) * 
                                    (1 - fuel_sub$ves2_ph3) + fuel_sub$ves2_rosph3 * fuel_sub$ves2_ph3) #km/hr
  
  fuel_sub$ves2_fht <- bias * (0.0193 * (fuel_sub$ves2_ros_fin * 1000)^0.723 * exp(0.0064 * (fuel_sub$ele_m * 100)))
  fuel_sub$ves2_fli <- 16000 * (fuel_sub$total_fuel_t_ha/10) * ( fuel_sub$ves2_ros_fin/3.6)
  
  fuel_output$mkv_fli[fuel_output$weather_set == w] <- fuel_sub$mkv_fli
  fuel_output$mkv_fht[fuel_output$weather_set == w] <- fuel_sub$mkv_fht
  fuel_output$ves_fli[fuel_output$weather_set == w] <- fuel_sub$ves_fli
  fuel_output$ves_fht[fuel_output$weather_set == w] <- fuel_sub$ves_fht
  fuel_output$mkv_ros[fuel_output$weather_set == w] <- fuel_sub$mkv_ros
  fuel_output$ves2_ros[fuel_output$weather_set == w] <- fuel_sub$ves2_ros_fin
  fuel_output$ves2_fht[fuel_output$weather_set == w] <- fuel_sub$ves2_fht
  fuel_output$ves2_fli[fuel_output$weather_set == w] <- fuel_sub$ves2_fli
}

view(fuel_output)

#-------------------------SPLIT LRG & SML----------------------------------------------------

values <- merge(fuel_output, fire_data,by=c("weather_set","site", "size", "year", "block", "fire_treat", "treatment", "total_fuel_t_ha"))
values$tsf_factor <- as.factor(values$tsf)
values$treatment <- factor(values$treatment, levels = c("open", "partial", "closed"))
values$fire_treat   <- factor(values$fire_treat, levels = c("unburnt", "burnt"))

values_lrg_w1 <- subset(values, values$size == "large" & values$weather_set == 1)
values_lrg_w2 <- subset(values, values$size == "large" & values$weather_set == 2)
values_lrg_w3 <- subset(values, values$size == "large" & values$weather_set == 3)
values_lrg_w4 <- subset(values, values$size == "large" & values$weather_set == 4)
values_lrg_w5 <- subset(values, values$size == "large" & values$weather_set == 5)

values_sml_w1 <- subset(values, values$size == "small" & values$weather_set == 1)
values_sml_w2 <- subset(values, values$size == "small" & values$weather_set == 2)
values_sml_w3 <- subset(values, values$size == "small" & values$weather_set == 3)
values_sml_w4 <- subset(values, values$size == "small" & values$weather_set == 4)
values_sml_w5 <- subset(values, values$size == "small" & values$weather_set == 5)

#---------------------------transforming the fli-----------------------------------------
values_lrg_w1$mkv_fli_k  <- values_lrg_w1$mkv_fli/1000
values_lrg_w2$mkv_fli_k  <- values_lrg_w2$mkv_fli/1000
values_lrg_w3$mkv_fli_k  <- values_lrg_w3$mkv_fli/1000
values_lrg_w4$mkv_fli_k  <- values_lrg_w4$mkv_fli/1000
values_lrg_w5$mkv_fli_k  <- values_lrg_w5$mkv_fli/1000

values_sml_w1$mkv_fli_k  <- values_sml_w1$mkv_fli/1000
values_sml_w2$mkv_fli_k  <- values_sml_w2$mkv_fli/1000
values_sml_w3$mkv_fli_k  <- values_sml_w3$mkv_fli/1000
values_sml_w4$mkv_fli_k  <- values_sml_w4$mkv_fli/1000
values_sml_w5$mkv_fli_k  <- values_sml_w5$mkv_fli/1000

values_lrg_w1$ves2_fli_k  <- values_lrg_w1$ves2_fli/1000
values_lrg_w2$ves2_fli_k  <- values_lrg_w2$ves2_fli/1000
values_lrg_w3$ves2_fli_k  <- values_lrg_w3$ves2_fli/1000
values_lrg_w4$ves2_fli_k  <- values_lrg_w4$ves2_fli/1000
values_lrg_w5$ves2_fli_k  <- values_lrg_w5$ves2_fli/1000

values_sml_w1$ves2_fli_k  <- values_sml_w1$ves2_fli/1000
values_sml_w2$ves2_fli_k  <- values_sml_w2$ves2_fli/1000
values_sml_w3$ves2_fli_k  <- values_sml_w3$ves2_fli/1000
values_sml_w4$ves2_fli_k  <- values_sml_w4$ves2_fli/1000
values_sml_w5$ves2_fli_k  <- values_sml_w5$ves2_fli/1000

values_lrg_w1$zyl_fli_k  <- values_lrg_w1$zyl_fli/1000
values_lrg_w2$zyl_fli_k  <- values_lrg_w2$zyl_fli/1000
values_lrg_w3$zyl_fli_k  <- values_lrg_w3$zyl_fli/1000
values_lrg_w4$zyl_fli_k  <- values_lrg_w4$zyl_fli/1000
values_lrg_w5$zyl_fli_k  <- values_lrg_w5$zyl_fli/1000

values_sml_w1$zyl_fli_k  <- values_sml_w1$zyl_fli/1000
values_sml_w2$zyl_fli_k  <- values_sml_w2$zyl_fli/1000
values_sml_w3$zyl_fli_k  <- values_sml_w3$zyl_fli/1000
values_sml_w4$zyl_fli_k  <- values_sml_w4$zyl_fli/1000
values_sml_w5$zyl_fli_k  <- values_sml_w5$zyl_fli/1000

#######################################################################################
#######################################################################################
#-----------------------------MODEL CONSTRUCTION AND SELECTION-------------------------
#######################################################################################
#######################################################################################

#######################################################################################
#######################################FUEL LOADS W1###################################
#######################################################################################

#surface------------------------------------------------------------------------------

glmm_sur_fuel_sml_w1_1 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_sur_fuel_sml_w1_2 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_sur_fuel_sml_w1_3 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_sur_fuel_sml_w1_4 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_sur_fuel_sml_w1_5 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_sur_fuel_sml_w1_6 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_sur_fuel_sml_w1_7 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_sur_fuel_sml_w1_8 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_sur_fuel_sml_w1_9 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_sur_fuel_sml_w1_comp <- model.sel(glmm_sur_fuel_sml_w1_1, glmm_sur_fuel_sml_w1_2, glmm_sur_fuel_sml_w1_3,
                                   glmm_sur_fuel_sml_w1_4, glmm_sur_fuel_sml_w1_5, glmm_sur_fuel_sml_w1_6,
                                   glmm_sur_fuel_sml_w1_7, glmm_sur_fuel_sml_w1_8, glmm_sur_fuel_sml_w1_9)
head(glmm_sur_fuel_sml_w1_comp)
options(na.action="na.fail")
glmm_sur_fuel_sml_w1_comp2 <- model.sel(list(glmm_sur_fuel_sml_w1_1, glmm_sur_fuel_sml_w1_2, glmm_sur_fuel_sml_w1_3,
                                       glmm_sur_fuel_sml_w1_4, glmm_sur_fuel_sml_w1_5, glmm_sur_fuel_sml_w1_6,
                                       glmm_sur_fuel_sml_w1_7, glmm_sur_fuel_sml_w1_8, glmm_sur_fuel_sml_w1_9))
head(glmm_sur_fuel_sml_w1_comp2)

#best model = glmm_fuel_sml_w1_1
sim_sur_fuel_sml_w1 <- simulateResiduals(fittedModel = glmm_sur_fuel_sml_w1_1, plot = F)
plot(sim_sur_fuel_sml_w1)
summary(glmm_sur_fuel_sml_w1_1)

#fuel_load large sites
glmm_sur_fuel_lrg_w1_1  <- glmmTMB(data = fuel_lrg, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+tsf_factor                         + block  + (1|site))
glmm_sur_fuel_lrg_w1_2  <- glmmTMB(data = fuel_lrg, family = "gaussian", na.action = "na.fail",  sur_t_ha ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_sur_fuel_lrg_w1_comp <- model.sel(glmm_sur_fuel_lrg_w1_1, glmm_sur_fuel_lrg_w1_2)
head(glmm_sur_fuel_lrg_w1_comp)
#best model = glmm_fuel_lrg_w1_1
sim_sur_fuel_lrg_w1 <- simulateResiduals(fittedModel = glmm_sur_fuel_lrg_w1_1, plot = F)
plot(sim_sur_fuel_lrg_w1)
summary(glmm_sur_fuel_lrg_w1_1)

#near-surface--------------------------------------------------------------------------------------------------------------
glmm_ns_fuel_sml_w1_1 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ns_fuel_sml_w1_2 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ns_fuel_sml_w1_3 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ns_fuel_sml_w1_4 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ns_fuel_sml_w1_5 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ns_fuel_sml_w1_6 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ns_fuel_sml_w1_7 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ns_fuel_sml_w1_8 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ns_fuel_sml_w1_9 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ns_fuel_sml_w1_comp <- model.sel(glmm_ns_fuel_sml_w1_1, glmm_ns_fuel_sml_w1_2, glmm_ns_fuel_sml_w1_3,
                                       glmm_ns_fuel_sml_w1_4, glmm_ns_fuel_sml_w1_5, glmm_ns_fuel_sml_w1_6,
                                       glmm_ns_fuel_sml_w1_7, glmm_ns_fuel_sml_w1_8, glmm_ns_fuel_sml_w1_9)
head(glmm_ns_fuel_sml_w1_comp)
#best model = glmm_fuel_sml_w1_1
sim_ns_fuel_sml_w1 <- simulateResiduals(fittedModel = glmm_ns_fuel_sml_w1_1, plot = F)
plot(sim_ns_fuel_sml_w1)
summary(glmm_ns_fuel_sml_w1_1)

#fuel_load large sites
glmm_ns_fuel_lrg_w1_1  <- glmmTMB(data = fuel_lrg, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ns_fuel_lrg_w1_2  <- glmmTMB(data = fuel_lrg, family = "gaussian", na.action = "na.fail",  ns_t_ha ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ns_fuel_lrg_w1_comp <- model.sel(glmm_ns_fuel_lrg_w1_1, glmm_ns_fuel_lrg_w1_2)
head(glmm_ns_fuel_lrg_w1_comp)
#best model = glmm_fuel_lrg_w1_1
sim_ns_fuel_lrg_w1 <- simulateResiduals(fittedModel = glmm_ns_fuel_lrg_w1_1, plot = F)
plot(sim_ns_fuel_lrg_w1)
summary(glmm_ns_fuel_lrg_w1_1)

#elevated------------------------------------------------------------------------------------------------------
glmm_ele_fuel_sml_w1_1 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ele_fuel_sml_w1_2 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ele_fuel_sml_w1_3 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ele_fuel_sml_w1_4 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ele_fuel_sml_w1_5 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ele_fuel_sml_w1_6 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ele_fuel_sml_w1_7 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ele_fuel_sml_w1_8 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ele_fuel_sml_w1_9 <- glmmTMB(data = fuel_sml, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ele_fuel_sml_w1_comp <- model.sel(glmm_ele_fuel_sml_w1_1, glmm_ele_fuel_sml_w1_2, glmm_ele_fuel_sml_w1_3,
                                       glmm_ele_fuel_sml_w1_4, glmm_ele_fuel_sml_w1_5, glmm_ele_fuel_sml_w1_6,
                                       glmm_ele_fuel_sml_w1_7, glmm_ele_fuel_sml_w1_8, glmm_ele_fuel_sml_w1_9)
head(glmm_ele_fuel_sml_w1_comp)
#best model = glmm_fuel_sml_w1_1
sim_ele_fuel_sml_w1 <- simulateResiduals(fittedModel = glmm_ele_fuel_sml_w1_1, plot = F)
plot(sim_ele_fuel_sml_w1)
summary(glmm_ele_fuel_sml_w1_1)

#fuel_load large sites
glmm_ele_fuel_lrg_w1_1  <- glmmTMB(data = fuel_lrg, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ele_fuel_lrg_w1_2  <- glmmTMB(data = fuel_lrg, family = "gaussian", na.action = "na.fail",  ele_t_ha ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ele_fuel_lrg_w1_comp <- model.sel(glmm_ele_fuel_lrg_w1_1, glmm_ele_fuel_lrg_w1_2)
head(glmm_ele_fuel_lrg_w1_comp)
#best model = glmm_fuel_lrg_w1_1
sim_ele_fuel_lrg_w1 <- simulateResiduals(fittedModel = glmm_ele_fuel_lrg_w1_1, plot = F)
plot(sim_ele_fuel_lrg_w1)
summary(glmm_ele_fuel_lrg_w1_1)

#total t/ha------------------------------------------------------------------------------------------------------
#fuel t/ha small sites

glmm_fuel_sml_w1_1 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_fuel_sml_w1_2 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_fuel_sml_w1_3 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_fuel_sml_w1_4 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_fuel_sml_w1_5 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_fuel_sml_w1_6 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_fuel_sml_w1_7 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_fuel_sml_w1_8 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_fuel_sml_w1_9 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_fuel_sml_w1_comp <- model.sel(glmm_fuel_sml_w1_1, glmm_fuel_sml_w1_2, glmm_fuel_sml_w1_3,
                                   glmm_fuel_sml_w1_4, glmm_fuel_sml_w1_5, glmm_fuel_sml_w1_6,
                                   glmm_fuel_sml_w1_7, glmm_fuel_sml_w1_8, glmm_fuel_sml_w1_9)
head(glmm_fuel_sml_w1_comp)
#best model = glmm_fuel_sml_w1_1
sim_fuel_sml_w1 <- simulateResiduals(fittedModel = glmm_fuel_sml_w1_1, plot = F)
plot(sim_fuel_sml_w1)
summary(glmm_fuel_sml_w1_1)

#fuel_load large sites
glmm_fuel_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+tsf_factor                         + block  + (1|site))
glmm_fuel_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  total_fuel_t_ha ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_fuel_lrg_w1_comp <- model.sel(glmm_fuel_lrg_w1_1, glmm_fuel_lrg_w1_2)
head(glmm_fuel_lrg_w1_comp)
#best model = glmm_fuel_lrg_w1_1
sim_fuel_lrg_w1 <- simulateResiduals(fittedModel = glmm_fuel_lrg_w1_1, plot = F)
plot(sim_fuel_lrg_w1)
summary(glmm_fuel_lrg_w1_1)

#######################################################################################
#######################################mkv models#########################################
#######################################################################################

################## MK5 Fht w1----------------------------------------------------------

glmm_mkv_fht_sml_w1_1  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fht_sml_w1_2  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fht_sml_w1_3  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fht_sml_w1_4  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fht_sml_w1_5  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w1_6  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w1_7  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fht_sml_w1_8  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fht_sml_w1_9  <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fht_sml_w1_comp <- model.sel(glmm_mkv_fht_sml_w1_1, glmm_mkv_fht_sml_w1_2, glmm_mkv_fht_sml_w1_3,
                                   glmm_mkv_fht_sml_w1_4, glmm_mkv_fht_sml_w1_5, glmm_mkv_fht_sml_w1_6,
                                   glmm_mkv_fht_sml_w1_7, glmm_mkv_fht_sml_w1_8, glmm_mkv_fht_sml_w1_9)
head(glmm_mkv_fht_sml_w1_comp)
#best model = glmm_mkv_fht_sml_w1_1
sim_mkv_fht_sml_w1 <- simulateResiduals(fittedModel = glmm_mkv_fht_sml_w1_1, plot = F)
plot(sim_mkv_fht_sml_w1)
summary(glmm_mkv_fht_sml_w1_1)

####LARGE
glmm_mkv_fht_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fht_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fht_lrg_w1_comp <- model.sel(glmm_mkv_fht_lrg_w1_1, glmm_mkv_fht_lrg_w1_2)
head(glmm_mkv_fht_lrg_w1_comp)
#best model = glmm_mkv_fht_lrg_w1_1
sim_mkv_fht_lrg_w1 <- simulateResiduals(fittedModel = glmm_mkv_fht_lrg_w1_1, plot = F)
plot(sim_mkv_fht_lrg_w1)
summary(glmm_mkv_fht_lrg_w1_1)

################## MK5 fht w2----------------------------------------------------------

glmm_mkv_fht_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fht_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fht_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fht_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fht_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fht_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fht_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fht_sml_w2_comp <- model.sel(glmm_mkv_fht_sml_w2_1, glmm_mkv_fht_sml_w2_2, glmm_mkv_fht_sml_w2_3,
                                   glmm_mkv_fht_sml_w2_4, glmm_mkv_fht_sml_w2_5, glmm_mkv_fht_sml_w2_6,
                                   glmm_mkv_fht_sml_w2_7, glmm_mkv_fht_sml_w2_8, glmm_mkv_fht_sml_w2_9)
head(glmm_mkv_fht_sml_w2_comp)
#best model = glmm_mkv_fht_sml_w2_1
sim_mkv_fht_sml_w2 <- simulateResiduals(fittedModel = glmm_mkv_fht_sml_w2_1, plot = F)
plot(sim_mkv_fht_sml_w2)
summary(glmm_mkv_fht_sml_w2_1)

#mkv_fht_load large sites
glmm_mkv_fht_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fht_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fht_lrg_w2_comp <- model.sel(glmm_mkv_fht_lrg_w2_1, glmm_mkv_fht_lrg_w2_2)
head(glmm_mkv_fht_lrg_w2_comp)
#best model = glmm_mkv_fht_lrg_w2_1
sim_mkv_fht_lrg_w2 <- simulateResiduals(fittedModel = glmm_mkv_fht_lrg_w2_1, plot = F)
plot(sim_mkv_fht_lrg_w2)
summary(glmm_mkv_fht_lrg_w2_1)

################## MK5 fht w3----------------------------------------------------------
#mkv_fht t/ha small sites
glmm_mkv_fht_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fht_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fht_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fht_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fht_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fht_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fht_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fht_sml_w3_comp <- model.sel(glmm_mkv_fht_sml_w3_1, glmm_mkv_fht_sml_w3_2, glmm_mkv_fht_sml_w3_3,
                                   glmm_mkv_fht_sml_w3_4, glmm_mkv_fht_sml_w3_5, glmm_mkv_fht_sml_w3_6,
                                   glmm_mkv_fht_sml_w3_7, glmm_mkv_fht_sml_w3_8, glmm_mkv_fht_sml_w3_9)
head(glmm_mkv_fht_sml_w3_comp)
#best model = glmm_mkv_fht_sml_w3_1
sim_mkv_fht_sml_w3 <- simulateResiduals(fittedModel = glmm_mkv_fht_sml_w3_1, plot = F)
plot(sim_mkv_fht_sml_w3)
summary(glmm_mkv_fht_sml_w3_1)

#mkv_fht_load large sites
glmm_mkv_fht_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fht_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fht_lrg_w3_comp <- model.sel(glmm_mkv_fht_lrg_w3_1, glmm_mkv_fht_lrg_w3_2)
head(glmm_mkv_fht_lrg_w3_comp)
#best model = glmm_mkv_fht_lrg_w3_1
sim_mkv_fht_lrg_w3 <- simulateResiduals(fittedModel = glmm_mkv_fht_lrg_w3_1, plot = F)
plot(sim_mkv_fht_lrg_w3)
summary(glmm_mkv_fht_lrg_w3_1)

################## MK5 fht w4----------------------------------------------------------
#mkv_fht t/ha small sites
glmm_mkv_fht_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fht_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fht_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fht_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fht_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fht_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fht_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fht_sml_w4_comp <- model.sel(glmm_mkv_fht_sml_w4_1, glmm_mkv_fht_sml_w4_2, glmm_mkv_fht_sml_w4_3,
                                   glmm_mkv_fht_sml_w4_4, glmm_mkv_fht_sml_w4_5, glmm_mkv_fht_sml_w4_6,
                                   glmm_mkv_fht_sml_w4_7, glmm_mkv_fht_sml_w4_8, glmm_mkv_fht_sml_w4_9)
head(glmm_mkv_fht_sml_w4_comp)
#best model = glmm_mkv_fht_sml_w4_1
sim_mkv_fht_sml_w4 <- simulateResiduals(fittedModel = glmm_mkv_fht_sml_w4_1, plot = F)
plot(sim_mkv_fht_sml_w4)
summary(glmm_mkv_fht_sml_w4_1)

#mkv_fht_load large sites
glmm_mkv_fht_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fht_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fht_lrg_w4_comp <- model.sel(glmm_mkv_fht_lrg_w4_1, glmm_mkv_fht_lrg_w4_2)
head(glmm_mkv_fht_lrg_w4_comp)
#best model = glmm_mkv_fht_lrg_w4_1
sim_mkv_fht_lrg_w4 <- simulateResiduals(fittedModel = glmm_mkv_fht_lrg_w4_1, plot = F)
plot(sim_mkv_fht_lrg_w4)
summary(glmm_mkv_fht_lrg_w4_1)

################## MK5 fht w5----------------------------------------------------------

glmm_mkv_fht_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fht_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fht_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fht_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fht_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fht_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fht_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fht_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fht_sml_w5_comp <- model.sel(glmm_mkv_fht_sml_w5_1, glmm_mkv_fht_sml_w5_2, glmm_mkv_fht_sml_w5_3,
                                   glmm_mkv_fht_sml_w5_4, glmm_mkv_fht_sml_w5_5, glmm_mkv_fht_sml_w5_6,
                                   glmm_mkv_fht_sml_w5_7, glmm_mkv_fht_sml_w5_8, glmm_mkv_fht_sml_w5_9)
head(glmm_mkv_fht_sml_w5_comp)
#best model = glmm_mkv_fht_sml_w5_1
sim_mkv_fht_sml_w5 <- simulateResiduals(fittedModel = glmm_mkv_fht_sml_w5_1, plot = F)
plot(sim_mkv_fht_sml_w5)
summary(glmm_mkv_fht_sml_w5_1)

#LARGE
glmm_mkv_fht_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fht_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  mkv_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fht_lrg_w5_comp <- model.sel(glmm_mkv_fht_lrg_w5_1, glmm_mkv_fht_lrg_w5_2)
head(glmm_mkv_fht_lrg_w5_comp)
#best model = glmm_mkv_fht_lrg_w5_1
sim_mkv_fht_lrg_w5 <- simulateResiduals(fittedModel = glmm_mkv_fht_lrg_w5_1, plot = F)
plot(sim_mkv_fht_lrg_w5)
summary(glmm_mkv_fht_lrg_w5_1)

#####mkv_fli small sites-------------------------------------------------------------------------------------------

glmm_mkv_fli_sml_w1_1 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fli_sml_w1_2 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fli_sml_w1_3 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fli_sml_w1_4 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fli_sml_w1_5 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w1_6 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w1_7 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fli_sml_w1_8 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fli_sml_w1_9 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fli_sml_w1_comp <- model.sel(glmm_mkv_fli_sml_w1_1, glmm_mkv_fli_sml_w1_2, glmm_mkv_fli_sml_w1_3,
                                      glmm_mkv_fli_sml_w1_4, glmm_mkv_fli_sml_w1_5, glmm_mkv_fli_sml_w1_6,
                                      glmm_mkv_fli_sml_w1_7, glmm_mkv_fli_sml_w1_8, glmm_mkv_fli_sml_w1_9)
head(glmm_mkv_fli_sml_w1_comp)
#best model = glmm_mkv_fli_sml_w1_1
sim_mkv_fli_kml_w1 <- simulateResiduals(fittedModel = glmm_mkv_fli_sml_w1_1, plot = F)
plot(sim_mkv_fli_kml_w1)
summary(glmm_mkv_fli_sml_w1_1)

####LARGE
glmm_mkv_fli_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fli_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fli_lrg_w1_comp <- model.sel(glmm_mkv_fli_lrg_w1_1, glmm_mkv_fli_lrg_w1_2)
head(glmm_mkv_fli_lrg_w1_comp)
#best model = glmm_mkv_fli_lrg_w1_1
sim_mkv_fli_lrg_w1 <- simulateResiduals(fittedModel = glmm_mkv_fli_lrg_w1_1, plot = F)
plot(sim_mkv_fli_lrg_w1)
summary(glmm_mkv_fli_lrg_w1_1)

################## MK5 FLI w2----------------------------------------------------------

glmm_mkv_fli_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fli_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fli_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fli_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fli_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fli_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fli_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fli_sml_w2_comp <- model.sel(glmm_mkv_fli_sml_w2_1, glmm_mkv_fli_sml_w2_2, glmm_mkv_fli_sml_w2_3,
                                      glmm_mkv_fli_sml_w2_4, glmm_mkv_fli_sml_w2_5, glmm_mkv_fli_sml_w2_6,
                                      glmm_mkv_fli_sml_w2_7, glmm_mkv_fli_sml_w2_8, glmm_mkv_fli_sml_w2_9)
head(glmm_mkv_fli_sml_w2_comp)
#best model = glmm_mkv_fli_sml_w2_1
sim_mkv_fli_kml_w2 <- simulateResiduals(fittedModel = glmm_mkv_fli_sml_w2_1, plot = F)
plot(sim_mkv_fli_kml_w2)
summary(glmm_mkv_fli_sml_w2_1)

#mkv_fli_load large sites
glmm_mkv_fli_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fli_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fli_lrg_w2_comp <- model.sel(glmm_mkv_fli_lrg_w2_1, glmm_mkv_fli_lrg_w2_2)
head(glmm_mkv_fli_lrg_w2_comp)
#best model = glmm_mkv_fli_lrg_w2_1
sim_mkv_fli_lrg_w2 <- simulateResiduals(fittedModel = glmm_mkv_fli_lrg_w2_1, plot = F)
plot(sim_mkv_fli_lrg_w2)
summary(glmm_mkv_fli_lrg_w2_1)

################## MK5 FLI w3----------------------------------------------------------
#mkv_fli t/ha small sites
fixef(glmm_mkv_fli_sml_w3_1)
summary(glmm_mkv_fli_sml_w3_1)
values_sml_w3$mkv_fli
values_sml_w3$mkv_fli_k
hist(values_sml_w3$mkv_fli)

values_sml_w3$mkv_fli_test <- values_sml_w3$mkv_fli/1000
glmm_mkv_fli_sml_w3_test <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_test ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
summary(glmm_mkv_fli_sml_w3_test)


glmm_mkv_fli_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fli_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fli_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fli_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fli_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fli_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fli_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fli_sml_w3_comp <- model.sel(glmm_mkv_fli_sml_w3_1, glmm_mkv_fli_sml_w3_2, glmm_mkv_fli_sml_w3_3,
                                      glmm_mkv_fli_sml_w3_4, glmm_mkv_fli_sml_w3_5, glmm_mkv_fli_sml_w3_6,
                                      glmm_mkv_fli_sml_w3_7, glmm_mkv_fli_sml_w3_8, glmm_mkv_fli_sml_w3_9)
head(glmm_mkv_fli_sml_w3_comp)
#best model = glmm_mkv_fli_sml_w3_1
sim_mkv_fli_kml_w3 <- simulateResiduals(fittedModel = glmm_mkv_fli_sml_w3_1, plot = F)
plot(sim_mkv_fli_kml_w3)
summary(glmm_mkv_fli_sml_w3_1)

#mkv_fli_load large sites
glmm_mkv_fli_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fli_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fli_lrg_w3_comp <- model.sel(glmm_mkv_fli_lrg_w3_1, glmm_mkv_fli_lrg_w3_2)
head(glmm_mkv_fli_lrg_w3_comp)
#best model = glmm_mkv_fli_lrg_w3_1
sim_mkv_fli_lrg_w3 <- simulateResiduals(fittedModel = glmm_mkv_fli_lrg_w3_1, plot = F)
plot(sim_mkv_fli_lrg_w3)
summary(glmm_mkv_fli_lrg_w3_1)

################## MK5 FLI w4----------------------------------------------------------
#mkv_fli t/ha small sites
glmm_mkv_fli_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fli_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fli_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fli_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fli_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fli_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fli_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fli_sml_w4_comp <- model.sel(glmm_mkv_fli_sml_w4_1, glmm_mkv_fli_sml_w4_2, glmm_mkv_fli_sml_w4_3,
                                      glmm_mkv_fli_sml_w4_4, glmm_mkv_fli_sml_w4_5, glmm_mkv_fli_sml_w4_6,
                                      glmm_mkv_fli_sml_w4_7, glmm_mkv_fli_sml_w4_8, glmm_mkv_fli_sml_w4_9)
head(glmm_mkv_fli_sml_w4_comp)
#best model = glmm_mkv_fli_sml_w4_1
sim_mkv_fli_kml_w4 <- simulateResiduals(fittedModel = glmm_mkv_fli_sml_w4_1, plot = F)
plot(sim_mkv_fli_kml_w4)
summary(glmm_mkv_fli_sml_w4_1)

#mkv_fli_load large sites
glmm_mkv_fli_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fli_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fli_lrg_w4_comp <- model.sel(glmm_mkv_fli_lrg_w4_1, glmm_mkv_fli_lrg_w4_2)
head(glmm_mkv_fli_lrg_w4_comp)
#best model = glmm_mkv_fli_lrg_w4_1
sim_mkv_fli_lrg_w4 <- simulateResiduals(fittedModel = glmm_mkv_fli_lrg_w4_1, plot = F)
plot(sim_mkv_fli_lrg_w4)
summary(glmm_mkv_fli_lrg_w4_1)

################## MK5 FLI w5----------------------------------------------------------

glmm_mkv_fli_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_fli_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_fli_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_fli_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_fli_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_fli_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_fli_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_fli_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_fli_sml_w5_comp <- model.sel(glmm_mkv_fli_sml_w5_1, glmm_mkv_fli_sml_w5_2, glmm_mkv_fli_sml_w5_3,
                                      glmm_mkv_fli_sml_w5_4, glmm_mkv_fli_sml_w5_5, glmm_mkv_fli_sml_w5_6,
                                      glmm_mkv_fli_sml_w5_7, glmm_mkv_fli_sml_w5_8, glmm_mkv_fli_sml_w5_9)
head(glmm_mkv_fli_sml_w5_comp)
#best model = glmm_mkv_fli_sml_w5_1
sim_mkv_fli_kml_w5 <- simulateResiduals(fittedModel = glmm_mkv_fli_sml_w5_1, plot = F)
plot(sim_mkv_fli_kml_w5)
summary(glmm_mkv_fli_sml_w5_1)

#LARGE
glmm_mkv_fli_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_fli_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  mkv_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_fli_lrg_w5_comp <- model.sel(glmm_mkv_fli_lrg_w5_1, glmm_mkv_fli_lrg_w5_2)
head(glmm_mkv_fli_lrg_w5_comp)
#best model = glmm_mkv_fli_lrg_w5_1
sim_mkv_fli_lrg_w5 <- simulateResiduals(fittedModel = glmm_mkv_fli_lrg_w5_1, plot = F)
plot(sim_mkv_fli_lrg_w5)
summary(glmm_mkv_fli_lrg_w5_1)

#####mkv_ros small sites-------------------------------------------------------------------------------------------

glmm_mkv_ros_sml_w1_1 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_ros_sml_w1_2 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_ros_sml_w1_3 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_ros_sml_w1_4 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_ros_sml_w1_5 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w1_6 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w1_7 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_ros_sml_w1_8 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_ros_sml_w1_9 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_ros_sml_w1_comp <- model.sel(glmm_mkv_ros_sml_w1_1, glmm_mkv_ros_sml_w1_2, glmm_mkv_ros_sml_w1_3,
                                      glmm_mkv_ros_sml_w1_4, glmm_mkv_ros_sml_w1_5, glmm_mkv_ros_sml_w1_6,
                                      glmm_mkv_ros_sml_w1_7, glmm_mkv_ros_sml_w1_8, glmm_mkv_ros_sml_w1_9)
head(glmm_mkv_ros_sml_w1_comp)
#best model = glmm_mkv_ros_sml_w1_1
sim_mkv_ros_sml_w1 <- simulateResiduals(fittedModel = glmm_mkv_ros_sml_w1_1, plot = F)
plot(sim_mkv_ros_sml_w1)
summary(glmm_mkv_ros_sml_w1_1)

####LARGE
glmm_mkv_ros_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_ros_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_ros_lrg_w1_comp <- model.sel(glmm_mkv_ros_lrg_w1_1, glmm_mkv_ros_lrg_w1_2)
head(glmm_mkv_ros_lrg_w1_comp)
#best model = glmm_mkv_ros_lrg_w1_1
sim_mkv_ros_lrg_w1 <- simulateResiduals(fittedModel = glmm_mkv_ros_lrg_w1_1, plot = F)
plot(sim_mkv_ros_lrg_w1)
summary(glmm_mkv_ros_lrg_w1_1)

################## MK5 ros w2----------------------------------------------------------

glmm_mkv_ros_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_ros_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_ros_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_ros_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_ros_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_ros_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_ros_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_ros_sml_w2_comp <- model.sel(glmm_mkv_ros_sml_w2_1, glmm_mkv_ros_sml_w2_2, glmm_mkv_ros_sml_w2_3,
                                      glmm_mkv_ros_sml_w2_4, glmm_mkv_ros_sml_w2_5, glmm_mkv_ros_sml_w2_6,
                                      glmm_mkv_ros_sml_w2_7, glmm_mkv_ros_sml_w2_8, glmm_mkv_ros_sml_w2_9)
head(glmm_mkv_ros_sml_w2_comp)
#best model = glmm_mkv_ros_sml_w2_1
sim_mkv_ros_sml_w2 <- simulateResiduals(fittedModel = glmm_mkv_ros_sml_w2_1, plot = F)
plot(sim_mkv_ros_sml_w2)
summary(glmm_mkv_ros_sml_w2_1)

#mkv_ros_load large sites
glmm_mkv_ros_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_ros_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_ros_lrg_w2_comp <- model.sel(glmm_mkv_ros_lrg_w2_1, glmm_mkv_ros_lrg_w2_2)
head(glmm_mkv_ros_lrg_w2_comp)
#best model = glmm_mkv_ros_lrg_w2_1
sim_mkv_ros_lrg_w2 <- simulateResiduals(fittedModel = glmm_mkv_ros_lrg_w2_1, plot = F)
plot(sim_mkv_ros_lrg_w2)
summary(glmm_mkv_ros_lrg_w2_1)

################## MK5 ros w3----------------------------------------------------------
#mkv_ros t/ha small sites
glmm_mkv_ros_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_ros_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_ros_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_ros_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_ros_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_ros_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_ros_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_ros_sml_w3_comp <- model.sel(glmm_mkv_ros_sml_w3_1, glmm_mkv_ros_sml_w3_2, glmm_mkv_ros_sml_w3_3,
                                      glmm_mkv_ros_sml_w3_4, glmm_mkv_ros_sml_w3_5, glmm_mkv_ros_sml_w3_6,
                                      glmm_mkv_ros_sml_w3_7, glmm_mkv_ros_sml_w3_8, glmm_mkv_ros_sml_w3_9)
head(glmm_mkv_ros_sml_w3_comp)
#best model = glmm_mkv_ros_sml_w3_1
sim_mkv_ros_sml_w3 <- simulateResiduals(fittedModel = glmm_mkv_ros_sml_w3_1, plot = F)
plot(sim_mkv_ros_sml_w3)
summary(glmm_mkv_ros_sml_w3_1)

#mkv_ros_load large sites
glmm_mkv_ros_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_ros_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_ros_lrg_w3_comp <- model.sel(glmm_mkv_ros_lrg_w3_1, glmm_mkv_ros_lrg_w3_2)
head(glmm_mkv_ros_lrg_w3_comp)
#best model = glmm_mkv_ros_lrg_w3_1
sim_mkv_ros_lrg_w3 <- simulateResiduals(fittedModel = glmm_mkv_ros_lrg_w3_1, plot = F)
plot(sim_mkv_ros_lrg_w3)
summary(glmm_mkv_ros_lrg_w3_1)

################## MK5 ros w4----------------------------------------------------------
#mkv_ros t/ha small sites
glmm_mkv_ros_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_ros_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_ros_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_ros_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_ros_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_ros_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_ros_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_ros_sml_w4_comp <- model.sel(glmm_mkv_ros_sml_w4_1, glmm_mkv_ros_sml_w4_2, glmm_mkv_ros_sml_w4_3,
                                      glmm_mkv_ros_sml_w4_4, glmm_mkv_ros_sml_w4_5, glmm_mkv_ros_sml_w4_6,
                                      glmm_mkv_ros_sml_w4_7, glmm_mkv_ros_sml_w4_8, glmm_mkv_ros_sml_w4_9)
head(glmm_mkv_ros_sml_w4_comp)
#best model = glmm_mkv_ros_sml_w4_1
sim_mkv_ros_sml_w4 <- simulateResiduals(fittedModel = glmm_mkv_ros_sml_w4_1, plot = F)
plot(sim_mkv_ros_sml_w4)
summary(glmm_mkv_ros_sml_w4_1)

#mkv_ros_load large sites
glmm_mkv_ros_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_ros_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_ros_lrg_w4_comp <- model.sel(glmm_mkv_ros_lrg_w4_1, glmm_mkv_ros_lrg_w4_2)
head(glmm_mkv_ros_lrg_w4_comp)
#best model = glmm_mkv_ros_lrg_w4_1
sim_mkv_ros_lrg_w4 <- simulateResiduals(fittedModel = glmm_mkv_ros_lrg_w4_1, plot = F)
plot(sim_mkv_ros_lrg_w4)
summary(glmm_mkv_ros_lrg_w4_1)

################## MK5 ros w5----------------------------------------------------------

glmm_mkv_ros_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_mkv_ros_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_mkv_ros_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_mkv_ros_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_mkv_ros_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_mkv_ros_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_mkv_ros_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_mkv_ros_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_mkv_ros_sml_w5_comp <- model.sel(glmm_mkv_ros_sml_w5_1, glmm_mkv_ros_sml_w5_2, glmm_mkv_ros_sml_w5_3,
                                      glmm_mkv_ros_sml_w5_4, glmm_mkv_ros_sml_w5_5, glmm_mkv_ros_sml_w5_6,
                                      glmm_mkv_ros_sml_w5_7, glmm_mkv_ros_sml_w5_8, glmm_mkv_ros_sml_w5_9)
head(glmm_mkv_ros_sml_w5_comp)
#best model = glmm_mkv_ros_sml_w5_1
sim_mkv_ros_sml_w5 <- simulateResiduals(fittedModel = glmm_mkv_ros_sml_w5_1, plot = F)
plot(sim_mkv_ros_sml_w5)
summary(glmm_mkv_ros_sml_w5_1)

#LARGE
glmm_mkv_ros_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_mkv_ros_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  mkv_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_mkv_ros_lrg_w5_comp <- model.sel(glmm_mkv_ros_lrg_w5_1, glmm_mkv_ros_lrg_w5_2)
head(glmm_mkv_ros_lrg_w5_comp)
#best model = glmm_mkv_ros_lrg_w5_1
sim_mkv_ros_lrg_w5 <- simulateResiduals(fittedModel = glmm_mkv_ros_lrg_w5_1, plot = F)
plot(sim_mkv_ros_lrg_w5)
summary(glmm_mkv_ros_lrg_w5_1)

################################################################################################################
#vesta model mark 2 below here

##################################################################################
#####################################VES MK2 MODELS###############################
##################################################################################

################## ves fht w2----------------------------------------------------------

glmm_ves2_fht_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fht_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fht_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fht_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fht_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fht_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fht_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fht_sml_w2_comp <- model.sel(glmm_ves2_fht_sml_w2_1, glmm_ves2_fht_sml_w2_2, glmm_ves2_fht_sml_w2_3,
                                      glmm_ves2_fht_sml_w2_4, glmm_ves2_fht_sml_w2_5, glmm_ves2_fht_sml_w2_6,
                                      glmm_ves2_fht_sml_w2_7, glmm_ves2_fht_sml_w2_8, glmm_ves2_fht_sml_w2_9)
head(glmm_ves2_fht_sml_w2_comp)
#best model = glmm_ves2_fht_sml_w2_1
sim_ves2_fht_sml_w2 <- simulateResiduals(fittedModel = glmm_ves2_fht_sml_w2_1, plot = F)
plot(sim_ves2_fht_sml_w2)
summary(glmm_ves2_fht_sml_w2_1)

#ves2_fht_load large sites
glmm_ves2_fht_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fht_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fht_lrg_w2_comp <- model.sel(glmm_ves2_fht_lrg_w2_1, glmm_ves2_fht_lrg_w2_2)
head(glmm_ves2_fht_lrg_w2_comp)
#best model = glmm_ves2_fht_lrg_w2_1
sim_ves2_fht_lrg_w2 <- simulateResiduals(fittedModel = glmm_ves2_fht_lrg_w2_1, plot = F)
plot(sim_ves2_fht_lrg_w2)
summary(glmm_ves2_fht_lrg_w2_1)

################## ves fht w3----------------------------------------------------------
#ves2_fht t/ha small sites
glmm_ves2_fht_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fht_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fht_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fht_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fht_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fht_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fht_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fht_sml_w3_comp <- model.sel(glmm_ves2_fht_sml_w3_1, glmm_ves2_fht_sml_w3_2, glmm_ves2_fht_sml_w3_3,
                                      glmm_ves2_fht_sml_w3_4, glmm_ves2_fht_sml_w3_5, glmm_ves2_fht_sml_w3_6,
                                      glmm_ves2_fht_sml_w3_7, glmm_ves2_fht_sml_w3_8, glmm_ves2_fht_sml_w3_9)
head(glmm_ves2_fht_sml_w3_comp)
#best model = glmm_ves2_fht_sml_w3_1
sim_ves2_fht_sml_w3 <- simulateResiduals(fittedModel = glmm_ves2_fht_sml_w3_1, plot = F)
plot(sim_ves2_fht_sml_w3)
summary(glmm_ves2_fht_sml_w3_1)

#ves2_fht_load large sites
glmm_ves2_fht_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fht_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fht_lrg_w3_comp <- model.sel(glmm_ves2_fht_lrg_w3_1, glmm_ves2_fht_lrg_w3_2)
head(glmm_ves2_fht_lrg_w3_comp)
#best model = glmm_ves2_fht_lrg_w3_1
sim_ves2_fht_lrg_w3 <- simulateResiduals(fittedModel = glmm_ves2_fht_lrg_w3_1, plot = F)
plot(sim_ves2_fht_lrg_w3)
summary(glmm_ves2_fht_lrg_w3_1)

################## ves fht w4----------------------------------------------------------
#ves2_fht t/ha small sites
glmm_ves2_fht_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fht_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fht_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fht_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fht_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fht_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fht_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fht_sml_w4_comp <- model.sel(glmm_ves2_fht_sml_w4_1, glmm_ves2_fht_sml_w4_2, glmm_ves2_fht_sml_w4_3,
                                      glmm_ves2_fht_sml_w4_4, glmm_ves2_fht_sml_w4_5, glmm_ves2_fht_sml_w4_6,
                                      glmm_ves2_fht_sml_w4_7, glmm_ves2_fht_sml_w4_8, glmm_ves2_fht_sml_w4_9)
head(glmm_ves2_fht_sml_w4_comp)
#best model = glmm_ves2_fht_sml_w4_1
sim_ves2_fht_sml_w4 <- simulateResiduals(fittedModel = glmm_ves2_fht_sml_w4_1, plot = F)
plot(sim_ves2_fht_sml_w4)
summary(glmm_ves2_fht_sml_w4_1)

#ves2_fht_load large sites
glmm_ves2_fht_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fht_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fht_lrg_w4_comp <- model.sel(glmm_ves2_fht_lrg_w4_1, glmm_ves2_fht_lrg_w4_2)
head(glmm_ves2_fht_lrg_w4_comp)
#best model = glmm_ves2_fht_lrg_w4_1
sim_ves2_fht_lrg_w4 <- simulateResiduals(fittedModel = glmm_ves2_fht_lrg_w4_1, plot = F)
plot(sim_ves2_fht_lrg_w4)
summary(glmm_ves2_fht_lrg_w4_1)

################## ves fht w5----------------------------------------------------------

glmm_ves2_fht_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fht_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fht_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fht_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fht_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fht_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fht_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fht_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fht_sml_w5_comp <- model.sel(glmm_ves2_fht_sml_w5_1, glmm_ves2_fht_sml_w5_2, glmm_ves2_fht_sml_w5_3,
                                      glmm_ves2_fht_sml_w5_4, glmm_ves2_fht_sml_w5_5, glmm_ves2_fht_sml_w5_6,
                                      glmm_ves2_fht_sml_w5_7, glmm_ves2_fht_sml_w5_8, glmm_ves2_fht_sml_w5_9)
head(glmm_ves2_fht_sml_w5_comp)
#best model = glmm_ves2_fht_sml_w5_1
sim_ves2_fht_sml_w5 <- simulateResiduals(fittedModel = glmm_ves2_fht_sml_w5_1, plot = F)
plot(sim_ves2_fht_sml_w5)
summary(glmm_ves2_fht_sml_w5_1)

#LARGE
glmm_ves2_fht_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fht_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  ves2_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fht_lrg_w5_comp <- model.sel(glmm_ves2_fht_lrg_w5_1, glmm_ves2_fht_lrg_w5_2)
head(glmm_ves2_fht_lrg_w5_comp)
#best model = glmm_ves2_fht_lrg_w5_1
sim_ves2_fht_lrg_w5 <- simulateResiduals(fittedModel = glmm_ves2_fht_lrg_w5_1, plot = F)
plot(sim_ves2_fht_lrg_w5)
summary(glmm_ves2_fht_lrg_w5_1)

#####ves2_fli-------------------------------------------------------------------------------------------

################## ves FLI w2----------------------------------------------------------

glmm_ves2_fli_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fli_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fli_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fli_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fli_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fli_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fli_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fli_sml_w2_comp <- model.sel(glmm_ves2_fli_sml_w2_1, glmm_ves2_fli_sml_w2_2, glmm_ves2_fli_sml_w2_3,
                                      glmm_ves2_fli_sml_w2_4, glmm_ves2_fli_sml_w2_5, glmm_ves2_fli_sml_w2_6,
                                      glmm_ves2_fli_sml_w2_7, glmm_ves2_fli_sml_w2_8, glmm_ves2_fli_sml_w2_9)
head(glmm_ves2_fli_sml_w2_comp)
#best model = glmm_ves2_fli_sml_w2_1
sim_ves2_fli_sml_w2 <- simulateResiduals(fittedModel = glmm_ves2_fli_sml_w2_1, plot = F)
plot(sim_ves2_fli_sml_w2)
summary(glmm_ves2_fli_sml_w2_1)

#ves2_fli_load large sites
glmm_ves2_fli_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fli_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fli_lrg_w2_comp <- model.sel(glmm_ves2_fli_lrg_w2_1, glmm_ves2_fli_lrg_w2_2)
head(glmm_ves2_fli_lrg_w2_comp)
#best model = glmm_ves2_fli_lrg_w2_1
sim_ves2_fli_lrg_w2 <- simulateResiduals(fittedModel = glmm_ves2_fli_lrg_w2_1, plot = F)
plot(sim_ves2_fli_lrg_w2)
summary(glmm_ves2_fli_lrg_w2_1)

################## ves FLI w3----------------------------------------------------------
glmm_ves2_fli_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fli_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fli_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fli_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fli_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fli_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fli_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fli_sml_w3_comp <- model.sel(glmm_ves2_fli_sml_w3_1, glmm_ves2_fli_sml_w3_2, glmm_ves2_fli_sml_w3_3,
                                      glmm_ves2_fli_sml_w3_4, glmm_ves2_fli_sml_w3_5, glmm_ves2_fli_sml_w3_6,
                                      glmm_ves2_fli_sml_w3_7, glmm_ves2_fli_sml_w3_8, glmm_ves2_fli_sml_w3_9)
head(glmm_ves2_fli_sml_w3_comp)
#best model = glmm_ves2_fli_sml_w3_1
sim_ves2_fli_sml_w3 <- simulateResiduals(fittedModel = glmm_ves2_fli_sml_w3_1, plot = F)
plot(sim_ves2_fli_sml_w3)
summary(glmm_ves2_fli_sml_w3_1)

#ves2_fli_load large sites
glmm_ves2_fli_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fli_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fli_lrg_w3_comp <- model.sel(glmm_ves2_fli_lrg_w3_1, glmm_ves2_fli_lrg_w3_2)
head(glmm_ves2_fli_lrg_w3_comp)
#best model = glmm_ves2_fli_lrg_w3_1
sim_ves2_fli_lrg_w3 <- simulateResiduals(fittedModel = glmm_ves2_fli_lrg_w3_1, plot = F)
plot(sim_ves2_fli_lrg_w3)
summary(glmm_ves2_fli_lrg_w3_1)

################## ves FLI w4----------------------------------------------------------
#ves2_fli t/ha small sites
glmm_ves2_fli_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fli_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fli_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fli_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fli_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fli_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fli_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fli_sml_w4_comp <- model.sel(glmm_ves2_fli_sml_w4_1, glmm_ves2_fli_sml_w4_2, glmm_ves2_fli_sml_w4_3,
                                      glmm_ves2_fli_sml_w4_4, glmm_ves2_fli_sml_w4_5, glmm_ves2_fli_sml_w4_6,
                                      glmm_ves2_fli_sml_w4_7, glmm_ves2_fli_sml_w4_8, glmm_ves2_fli_sml_w4_9)
head(glmm_ves2_fli_sml_w4_comp)
#best model = glmm_ves2_fli_sml_w4_1
sim_ves2_fli_sml_w4 <- simulateResiduals(fittedModel = glmm_ves2_fli_sml_w4_1, plot = F)
plot(sim_ves2_fli_sml_w4)
summary(glmm_ves2_fli_sml_w4_1)

#ves2_fli_load large sites
glmm_ves2_fli_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fli_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fli_lrg_w4_comp <- model.sel(glmm_ves2_fli_lrg_w4_1, glmm_ves2_fli_lrg_w4_2)
head(glmm_ves2_fli_lrg_w4_comp)
#best model = glmm_ves2_fli_lrg_w4_1
sim_ves2_fli_lrg_w4 <- simulateResiduals(fittedModel = glmm_ves2_fli_lrg_w4_1, plot = F)
plot(sim_ves2_fli_lrg_w4)
summary(glmm_ves2_fli_lrg_w4_1)

################## ves FLI w5----------------------------------------------------------

glmm_ves2_fli_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_fli_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_fli_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_fli_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_fli_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_fli_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_fli_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_fli_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_fli_sml_w5_comp <- model.sel(glmm_ves2_fli_sml_w5_1, glmm_ves2_fli_sml_w5_2, glmm_ves2_fli_sml_w5_3,
                                      glmm_ves2_fli_sml_w5_4, glmm_ves2_fli_sml_w5_5, glmm_ves2_fli_sml_w5_6,
                                      glmm_ves2_fli_sml_w5_7, glmm_ves2_fli_sml_w5_8, glmm_ves2_fli_sml_w5_9)
head(glmm_ves2_fli_sml_w5_comp)
#best model = glmm_ves2_fli_sml_w5_1
sim_ves2_fli_sml_w5 <- simulateResiduals(fittedModel = glmm_ves2_fli_sml_w5_1, plot = F)
plot(sim_ves2_fli_sml_w5)
summary(glmm_ves2_fli_sml_w5_1)

#LARGE
glmm_ves2_fli_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_fli_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  ves2_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_fli_lrg_w5_comp <- model.sel(glmm_ves2_fli_lrg_w5_1, glmm_ves2_fli_lrg_w5_2)
head(glmm_ves2_fli_lrg_w5_comp)
#best model = glmm_ves2_fli_lrg_w5_1
sim_ves2_fli_lrg_w5 <- simulateResiduals(fittedModel = glmm_ves2_fli_lrg_w5_1, plot = F)
plot(sim_ves2_fli_lrg_w5)
summary(glmm_ves2_fli_lrg_w5_1)

#####ves2_ros-------------------------------------------------------------------------------------------

################## ves ros w2----------------------------------------------------------

glmm_ves2_ros_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_ros_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_ros_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_ros_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_ros_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_ros_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_ros_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_ros_sml_w2_comp <- model.sel(glmm_ves2_ros_sml_w2_1, glmm_ves2_ros_sml_w2_2, glmm_ves2_ros_sml_w2_3,
                                      glmm_ves2_ros_sml_w2_4, glmm_ves2_ros_sml_w2_5, glmm_ves2_ros_sml_w2_6,
                                      glmm_ves2_ros_sml_w2_7, glmm_ves2_ros_sml_w2_8, glmm_ves2_ros_sml_w2_9)
head(glmm_ves2_ros_sml_w2_comp)
#best model = glmm_ves2_ros_sml_w2_1
sim_ves2_ros_sml_w2 <- simulateResiduals(fittedModel = glmm_ves2_ros_sml_w2_1, plot = F)
plot(sim_ves2_ros_sml_w2)
summary(glmm_ves2_ros_sml_w2_1)

#ves2_ros_load large sites
glmm_ves2_ros_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_ros_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_ros_lrg_w2_comp <- model.sel(glmm_ves2_ros_lrg_w2_1, glmm_ves2_ros_lrg_w2_2)
head(glmm_ves2_ros_lrg_w2_comp)
#best model = glmm_ves2_ros_lrg_w2_1
sim_ves2_ros_lrg_w2 <- simulateResiduals(fittedModel = glmm_ves2_ros_lrg_w2_1, plot = F)
plot(sim_ves2_ros_lrg_w2)
summary(glmm_ves2_ros_lrg_w2_1)

################## ves ros w3----------------------------------------------------------
glmm_ves2_ros_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_ros_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_ros_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_ros_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_ros_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_ros_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_ros_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_ros_sml_w3_comp <- model.sel(glmm_ves2_ros_sml_w3_1, glmm_ves2_ros_sml_w3_2, glmm_ves2_ros_sml_w3_3,
                                      glmm_ves2_ros_sml_w3_4, glmm_ves2_ros_sml_w3_5, glmm_ves2_ros_sml_w3_6,
                                      glmm_ves2_ros_sml_w3_7, glmm_ves2_ros_sml_w3_8, glmm_ves2_ros_sml_w3_9)
head(glmm_ves2_ros_sml_w3_comp)
#best model = glmm_ves2_ros_sml_w3_1
sim_ves2_ros_sml_w3 <- simulateResiduals(fittedModel = glmm_ves2_ros_sml_w3_1, plot = F)
plot(sim_ves2_ros_sml_w3)
summary(glmm_ves2_ros_sml_w3_1)

#ves2_ros_load large sites
glmm_ves2_ros_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_ros_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_ros_lrg_w3_comp <- model.sel(glmm_ves2_ros_lrg_w3_1, glmm_ves2_ros_lrg_w3_2)
head(glmm_ves2_ros_lrg_w3_comp)
#best model = glmm_ves2_ros_lrg_w3_1
sim_ves2_ros_lrg_w3 <- simulateResiduals(fittedModel = glmm_ves2_ros_lrg_w3_1, plot = F)
plot(sim_ves2_ros_lrg_w3)
summary(glmm_ves2_ros_lrg_w3_1)

################## ves ros w4----------------------------------------------------------
#ves2_ros t/ha small sites
glmm_ves2_ros_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_ros_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_ros_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_ros_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_ros_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_ros_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_ros_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_ros_sml_w4_comp <- model.sel(glmm_ves2_ros_sml_w4_1, glmm_ves2_ros_sml_w4_2, glmm_ves2_ros_sml_w4_3,
                                      glmm_ves2_ros_sml_w4_4, glmm_ves2_ros_sml_w4_5, glmm_ves2_ros_sml_w4_6,
                                      glmm_ves2_ros_sml_w4_7, glmm_ves2_ros_sml_w4_8, glmm_ves2_ros_sml_w4_9)
head(glmm_ves2_ros_sml_w4_comp)
#best model = glmm_ves2_ros_sml_w4_1
sim_ves2_ros_sml_w4 <- simulateResiduals(fittedModel = glmm_ves2_ros_sml_w4_1, plot = F)
plot(sim_ves2_ros_sml_w4)
summary(glmm_ves2_ros_sml_w4_1)

#ves2_ros_load large sites
glmm_ves2_ros_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_ros_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_ros_lrg_w4_comp <- model.sel(glmm_ves2_ros_lrg_w4_1, glmm_ves2_ros_lrg_w4_2)
head(glmm_ves2_ros_lrg_w4_comp)
#best model = glmm_ves2_ros_lrg_w4_1
sim_ves2_ros_lrg_w4 <- simulateResiduals(fittedModel = glmm_ves2_ros_lrg_w4_1, plot = F)
plot(sim_ves2_ros_lrg_w4)
summary(glmm_ves2_ros_lrg_w4_1)

################## ves ros w5----------------------------------------------------------

glmm_ves2_ros_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_ves2_ros_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_ves2_ros_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_ves2_ros_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_ves2_ros_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_ves2_ros_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_ves2_ros_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_ves2_ros_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_ves2_ros_sml_w5_comp <- model.sel(glmm_ves2_ros_sml_w5_1, glmm_ves2_ros_sml_w5_2, glmm_ves2_ros_sml_w5_3,
                                      glmm_ves2_ros_sml_w5_4, glmm_ves2_ros_sml_w5_5, glmm_ves2_ros_sml_w5_6,
                                      glmm_ves2_ros_sml_w5_7, glmm_ves2_ros_sml_w5_8, glmm_ves2_ros_sml_w5_9)
head(glmm_ves2_ros_sml_w5_comp)
#best model = glmm_ves2_ros_sml_w5_1
sim_ves2_ros_sml_w5 <- simulateResiduals(fittedModel = glmm_ves2_ros_sml_w5_1, plot = F)
plot(sim_ves2_ros_sml_w5)
summary(glmm_ves2_ros_sml_w5_1)

#LARGE
glmm_ves2_ros_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_ves2_ros_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  ves2_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_ves2_ros_lrg_w5_comp <- model.sel(glmm_ves2_ros_lrg_w5_1, glmm_ves2_ros_lrg_w5_2)
head(glmm_ves2_ros_lrg_w5_comp)
#best model = glmm_ves2_ros_lrg_w5_1
sim_ves2_ros_lrg_w5 <- simulateResiduals(fittedModel = glmm_ves2_ros_lrg_w5_1, plot = F)
plot(sim_ves2_ros_lrg_w5)
summary(glmm_ves2_ros_lrg_w5_1)


#####################################################################################
##################################zyl MODELS#########################################
#####################################################################################

#zyl_fht small sites
glmm_zyl_fht_sml_w1_1 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fht_sml_w1_2 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fht_sml_w1_3 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fht_sml_w1_4 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fht_sml_w1_5 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w1_6 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w1_7 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fht_sml_w1_8 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fht_sml_w1_9 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fht_sml_w1_comp <- model.sel(glmm_zyl_fht_sml_w1_1, glmm_zyl_fht_sml_w1_2, glmm_zyl_fht_sml_w1_3,
                                      glmm_zyl_fht_sml_w1_4, glmm_zyl_fht_sml_w1_5, glmm_zyl_fht_sml_w1_6,
                                      glmm_zyl_fht_sml_w1_7, glmm_zyl_fht_sml_w1_8, glmm_zyl_fht_sml_w1_9)
head(glmm_zyl_fht_sml_w1_comp)
#best model = glmm_zyl_fht_sml_w1_1
sim_zyl_fht_sml_w1 <- simulateResiduals(fittedModel = glmm_zyl_fht_sml_w1_1, plot = F)
plot(sim_zyl_fht_sml_w1)
summary(glmm_zyl_fht_sml_w1_1)

####LARGE
glmm_zyl_fht_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fht_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fht_lrg_w1_comp <- model.sel(glmm_zyl_fht_lrg_w1_1, glmm_zyl_fht_lrg_w1_2)
head(glmm_zyl_fht_lrg_w1_comp)
#best model = glmm_zyl_fht_lrg_w1_1
sim_zyl_fht_lrg_w1 <- simulateResiduals(fittedModel = glmm_zyl_fht_lrg_w1_1, plot = F)
plot(sim_zyl_fht_lrg_w1)
summary(glmm_zyl_fht_lrg_w1_1)

################## zyl fht w2----------------------------------------------------------

glmm_zyl_fht_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fht_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fht_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fht_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fht_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fht_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fht_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fht_sml_w2_comp <- model.sel(glmm_zyl_fht_sml_w2_1, glmm_zyl_fht_sml_w2_2, glmm_zyl_fht_sml_w2_3,
                                      glmm_zyl_fht_sml_w2_4, glmm_zyl_fht_sml_w2_5, glmm_zyl_fht_sml_w2_6,
                                      glmm_zyl_fht_sml_w2_7, glmm_zyl_fht_sml_w2_8, glmm_zyl_fht_sml_w2_9)
head(glmm_zyl_fht_sml_w2_comp)
#best model = glmm_zyl_fht_sml_w2_1
sim_zyl_fht_sml_w2 <- simulateResiduals(fittedModel = glmm_zyl_fht_sml_w2_1, plot = F)
plot(sim_zyl_fht_sml_w2)
summary(glmm_zyl_fht_sml_w2_1)

#zyl_fht_load large sites
glmm_zyl_fht_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fht_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fht_lrg_w2_comp <- model.sel(glmm_zyl_fht_lrg_w2_1, glmm_zyl_fht_lrg_w2_2)
head(glmm_zyl_fht_lrg_w2_comp)
#best model = glmm_zyl_fht_lrg_w2_1
sim_zyl_fht_lrg_w2 <- simulateResiduals(fittedModel = glmm_zyl_fht_lrg_w2_1, plot = F)
plot(sim_zyl_fht_lrg_w2)
summary(glmm_zyl_fht_lrg_w2_1)

################## zyl fht w3----------------------------------------------------------
#zyl_fht t/ha small sites
glmm_zyl_fht_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fht_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fht_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fht_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fht_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fht_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fht_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fht_sml_w3_comp <- model.sel(glmm_zyl_fht_sml_w3_1, glmm_zyl_fht_sml_w3_2, glmm_zyl_fht_sml_w3_3,
                                      glmm_zyl_fht_sml_w3_4, glmm_zyl_fht_sml_w3_5, glmm_zyl_fht_sml_w3_6,
                                      glmm_zyl_fht_sml_w3_7, glmm_zyl_fht_sml_w3_8, glmm_zyl_fht_sml_w3_9)
head(glmm_zyl_fht_sml_w3_comp)
#best model = glmm_zyl_fht_sml_w3_1
sim_zyl_fht_sml_w3 <- simulateResiduals(fittedModel = glmm_zyl_fht_sml_w3_1, plot = F)
plot(sim_zyl_fht_sml_w3)
summary(glmm_zyl_fht_sml_w3_1)

#zyl_fht_load large sites
glmm_zyl_fht_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fht_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fht_lrg_w3_comp <- model.sel(glmm_zyl_fht_lrg_w3_1, glmm_zyl_fht_lrg_w3_2)
head(glmm_zyl_fht_lrg_w3_comp)
#best model = glmm_zyl_fht_lrg_w3_1
sim_zyl_fht_lrg_w3 <- simulateResiduals(fittedModel = glmm_zyl_fht_lrg_w3_1, plot = F)
plot(sim_zyl_fht_lrg_w3)
summary(glmm_zyl_fht_lrg_w3_1)

################## zyl fht w4----------------------------------------------------------
#zyl_fht t/ha small sites
glmm_zyl_fht_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fht_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fht_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fht_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fht_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fht_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fht_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fht_sml_w4_comp <- model.sel(glmm_zyl_fht_sml_w4_1, glmm_zyl_fht_sml_w4_2, glmm_zyl_fht_sml_w4_3,
                                      glmm_zyl_fht_sml_w4_4, glmm_zyl_fht_sml_w4_5, glmm_zyl_fht_sml_w4_6,
                                      glmm_zyl_fht_sml_w4_7, glmm_zyl_fht_sml_w4_8, glmm_zyl_fht_sml_w4_9)
head(glmm_zyl_fht_sml_w4_comp)
#best model = glmm_zyl_fht_sml_w4_1
sim_zyl_fht_sml_w4 <- simulateResiduals(fittedModel = glmm_zyl_fht_sml_w4_1, plot = F)
plot(sim_zyl_fht_sml_w4)
summary(glmm_zyl_fht_sml_w4_1)

#zyl_fht_load large sites
glmm_zyl_fht_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fht_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fht_lrg_w4_comp <- model.sel(glmm_zyl_fht_lrg_w4_1, glmm_zyl_fht_lrg_w4_2)
head(glmm_zyl_fht_lrg_w4_comp)
#best model = glmm_zyl_fht_lrg_w4_1
sim_zyl_fht_lrg_w4 <- simulateResiduals(fittedModel = glmm_zyl_fht_lrg_w4_1, plot = F)
plot(sim_zyl_fht_lrg_w4)
summary(glmm_zyl_fht_lrg_w4_1)

################## zyl fht w5----------------------------------------------------------

glmm_zyl_fht_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fht_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fht_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fht_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fht_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fht_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fht_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fht_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fht_sml_w5_comp <- model.sel(glmm_zyl_fht_sml_w5_1, glmm_zyl_fht_sml_w5_2, glmm_zyl_fht_sml_w5_3,
                                      glmm_zyl_fht_sml_w5_4, glmm_zyl_fht_sml_w5_5, glmm_zyl_fht_sml_w5_6,
                                      glmm_zyl_fht_sml_w5_7, glmm_zyl_fht_sml_w5_8, glmm_zyl_fht_sml_w5_9)
head(glmm_zyl_fht_sml_w5_comp)
#best model = glmm_zyl_fht_sml_w5_1
sim_zyl_fht_sml_w5 <- simulateResiduals(fittedModel = glmm_zyl_fht_sml_w5_1, plot = F)
plot(sim_zyl_fht_sml_w5)
summary(glmm_zyl_fht_sml_w5_1)

#LARGE
glmm_zyl_fht_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fht_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  zyl_fht ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fht_lrg_w5_comp <- model.sel(glmm_zyl_fht_lrg_w5_1, glmm_zyl_fht_lrg_w5_2)
head(glmm_zyl_fht_lrg_w5_comp)
#best model = glmm_zyl_fht_lrg_w5_1
sim_zyl_fht_lrg_w5 <- simulateResiduals(fittedModel = glmm_zyl_fht_lrg_w5_1, plot = F)
plot(sim_zyl_fht_lrg_w5)
summary(glmm_zyl_fht_lrg_w5_1)


#####zyl_fli small sites-------------------------------------------------------------------------------------------

glmm_zyl_fli_sml_w1_1 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fli_sml_w1_2 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fli_sml_w1_3 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fli_sml_w1_4 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fli_sml_w1_5 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w1_6 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w1_7 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fli_sml_w1_8 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fli_sml_w1_9 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fli_sml_w1_comp <- model.sel(glmm_zyl_fli_sml_w1_1, glmm_zyl_fli_sml_w1_2, glmm_zyl_fli_sml_w1_3,
                                      glmm_zyl_fli_sml_w1_4, glmm_zyl_fli_sml_w1_5, glmm_zyl_fli_sml_w1_6,
                                      glmm_zyl_fli_sml_w1_7, glmm_zyl_fli_sml_w1_8, glmm_zyl_fli_sml_w1_9)
head(glmm_zyl_fli_sml_w1_comp)
#best model = glmm_zyl_fli_sml_w1_1
sim_zyl_fli_sml_w1 <- simulateResiduals(fittedModel = glmm_zyl_fli_sml_w1_1, plot = F)
plot(sim_zyl_fli_sml_w1)
summary(glmm_zyl_fli_sml_w1_1)

####LARGE
glmm_zyl_fli_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fli_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fli_lrg_w1_comp <- model.sel(glmm_zyl_fli_lrg_w1_1, glmm_zyl_fli_lrg_w1_2)
head(glmm_zyl_fli_lrg_w1_comp)
#best model = glmm_zyl_fli_lrg_w1_1
sim_zyl_fli_lrg_w1 <- simulateResiduals(fittedModel = glmm_zyl_fli_lrg_w1_1, plot = F)
plot(sim_zyl_fli_lrg_w1)
summary(glmm_zyl_fli_lrg_w1_1)

################## zyl FLI w2----------------------------------------------------------

glmm_zyl_fli_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fli_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fli_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fli_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fli_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fli_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fli_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fli_sml_w2_comp <- model.sel(glmm_zyl_fli_sml_w2_1, glmm_zyl_fli_sml_w2_2, glmm_zyl_fli_sml_w2_3,
                                      glmm_zyl_fli_sml_w2_4, glmm_zyl_fli_sml_w2_5, glmm_zyl_fli_sml_w2_6,
                                      glmm_zyl_fli_sml_w2_7, glmm_zyl_fli_sml_w2_8, glmm_zyl_fli_sml_w2_9)
head(glmm_zyl_fli_sml_w2_comp)
#best model = glmm_zyl_fli_sml_w2_1
sim_zyl_fli_sml_w2 <- simulateResiduals(fittedModel = glmm_zyl_fli_sml_w2_1, plot = F)
plot(sim_zyl_fli_sml_w2)
summary(glmm_zyl_fli_sml_w2_1)

#zyl_fli_load large sites
glmm_zyl_fli_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fli_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fli_lrg_w2_comp <- model.sel(glmm_zyl_fli_lrg_w2_1, glmm_zyl_fli_lrg_w2_2)
head(glmm_zyl_fli_lrg_w2_comp)
#best model = glmm_zyl_fli_lrg_w2_1
sim_zyl_fli_lrg_w2 <- simulateResiduals(fittedModel = glmm_zyl_fli_lrg_w2_1, plot = F)
plot(sim_zyl_fli_lrg_w2)
summary(glmm_zyl_fli_lrg_w2_1)

################## zyl FLI w3----------------------------------------------------------
#zyl_fli t/ha small sites
glmm_zyl_fli_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fli_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fli_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fli_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fli_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fli_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fli_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fli_sml_w3_comp <- model.sel(glmm_zyl_fli_sml_w3_1, glmm_zyl_fli_sml_w3_2, glmm_zyl_fli_sml_w3_3,
                                      glmm_zyl_fli_sml_w3_4, glmm_zyl_fli_sml_w3_5, glmm_zyl_fli_sml_w3_6,
                                      glmm_zyl_fli_sml_w3_7, glmm_zyl_fli_sml_w3_8, glmm_zyl_fli_sml_w3_9)
head(glmm_zyl_fli_sml_w3_comp)
#best model = glmm_zyl_fli_sml_w3_1
sim_zyl_fli_sml_w3 <- simulateResiduals(fittedModel = glmm_zyl_fli_sml_w3_1, plot = F)
plot(sim_zyl_fli_sml_w3)
summary(glmm_zyl_fli_sml_w3_1)

#zyl_fli_load large sites
glmm_zyl_fli_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fli_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fli_lrg_w3_comp <- model.sel(glmm_zyl_fli_lrg_w3_1, glmm_zyl_fli_lrg_w3_2)
head(glmm_zyl_fli_lrg_w3_comp)
#best model = glmm_zyl_fli_lrg_w3_1
sim_zyl_fli_lrg_w3 <- simulateResiduals(fittedModel = glmm_zyl_fli_lrg_w3_1, plot = F)
plot(sim_zyl_fli_lrg_w3)
summary(glmm_zyl_fli_lrg_w3_1)

################## zyl FLI w4----------------------------------------------------------
#zyl_fli t/ha small sites
glmm_zyl_fli_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fli_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fli_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fli_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fli_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fli_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fli_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fli_sml_w4_comp <- model.sel(glmm_zyl_fli_sml_w4_1, glmm_zyl_fli_sml_w4_2, glmm_zyl_fli_sml_w4_3,
                                      glmm_zyl_fli_sml_w4_4, glmm_zyl_fli_sml_w4_5, glmm_zyl_fli_sml_w4_6,
                                      glmm_zyl_fli_sml_w4_7, glmm_zyl_fli_sml_w4_8, glmm_zyl_fli_sml_w4_9)
head(glmm_zyl_fli_sml_w4_comp)
#best model = glmm_zyl_fli_sml_w4_1
sim_zyl_fli_sml_w4 <- simulateResiduals(fittedModel = glmm_zyl_fli_sml_w4_1, plot = F)
plot(sim_zyl_fli_sml_w4)
summary(glmm_zyl_fli_sml_w4_1)

#zyl_fli_load large sites
glmm_zyl_fli_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fli_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fli_lrg_w4_comp <- model.sel(glmm_zyl_fli_lrg_w4_1, glmm_zyl_fli_lrg_w4_2)
head(glmm_zyl_fli_lrg_w4_comp)
#best model = glmm_zyl_fli_lrg_w4_1
sim_zyl_fli_lrg_w4 <- simulateResiduals(fittedModel = glmm_zyl_fli_lrg_w4_1, plot = F)
plot(sim_zyl_fli_lrg_w4)
summary(glmm_zyl_fli_lrg_w4_1)

################## zyl FLI w5----------------------------------------------------------
glmm_zyl_fli_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_fli_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_fli_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_fli_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_fli_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_fli_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_fli_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_fli_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_fli_sml_w5_comp <- model.sel(glmm_zyl_fli_sml_w5_1, glmm_zyl_fli_sml_w5_2, glmm_zyl_fli_sml_w5_3,
                                      glmm_zyl_fli_sml_w5_4, glmm_zyl_fli_sml_w5_5, glmm_zyl_fli_sml_w5_6,
                                      glmm_zyl_fli_sml_w5_7, glmm_zyl_fli_sml_w5_8, glmm_zyl_fli_sml_w5_9)
head(glmm_zyl_fli_sml_w5_comp)
#best model = glmm_zyl_fli_sml_w5_1
sim_zyl_fli_sml_w5 <- simulateResiduals(fittedModel = glmm_zyl_fli_sml_w5_1, plot = F)
plot(sim_zyl_fli_sml_w5)
summary(glmm_zyl_fli_sml_w5_1)

#LARGE
glmm_zyl_fli_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_fli_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  zyl_fli_k ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_fli_lrg_w5_comp <- model.sel(glmm_zyl_fli_lrg_w5_1, glmm_zyl_fli_lrg_w5_2)
head(glmm_zyl_fli_lrg_w5_comp)
#best model = glmm_zyl_fli_lrg_w5_1
sim_zyl_fli_lrg_w5 <- simulateResiduals(fittedModel = glmm_zyl_fli_lrg_w5_1, plot = F)
plot(sim_zyl_fli_lrg_w5)
summary(glmm_zyl_fli_lrg_w5_1)

#####zyl_ros small sites-------------------------------------------------------------------------------------------

glmm_zyl_ros_sml_w1_1 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_ros_sml_w1_2 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_ros_sml_w1_3 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_ros_sml_w1_4 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_ros_sml_w1_5 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w1_6 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w1_7 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_ros_sml_w1_8 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_ros_sml_w1_9 <- glmmTMB(data = values_sml_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_ros_sml_w1_comp <- model.sel(glmm_zyl_ros_sml_w1_1, glmm_zyl_ros_sml_w1_2, glmm_zyl_ros_sml_w1_3,
                                      glmm_zyl_ros_sml_w1_4, glmm_zyl_ros_sml_w1_5, glmm_zyl_ros_sml_w1_6,
                                      glmm_zyl_ros_sml_w1_7, glmm_zyl_ros_sml_w1_8, glmm_zyl_ros_sml_w1_9)
head(glmm_zyl_ros_sml_w1_comp)
#best model = glmm_zyl_ros_sml_w1_1
sim_zyl_ros_sml_w1 <- simulateResiduals(fittedModel = glmm_zyl_ros_sml_w1_1, plot = F)
plot(sim_zyl_ros_sml_w1)
summary(glmm_zyl_ros_sml_w1_1)

####LARGE
glmm_zyl_ros_lrg_w1_1  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_ros_lrg_w1_2  <- glmmTMB(data = values_lrg_w1, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_ros_lrg_w1_comp <- model.sel(glmm_zyl_ros_lrg_w1_1, glmm_zyl_ros_lrg_w1_2)
head(glmm_zyl_ros_lrg_w1_comp)

#best model = glmm_zyl_ros_lrg_w1_1
sim_zyl_ros_lrg_w1 <- simulateResiduals(fittedModel = glmm_zyl_ros_lrg_w1_1, plot = F)
plot(sim_zyl_ros_lrg_w1)
summary(glmm_zyl_ros_lrg_w1_1)

################## zyl ros w2----------------------------------------------------------

glmm_zyl_ros_sml_w2_1 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_ros_sml_w2_2 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_ros_sml_w2_3 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_ros_sml_w2_4 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_ros_sml_w2_5 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w2_6 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w2_7 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_ros_sml_w2_8 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_ros_sml_w2_9 <- glmmTMB(data = values_sml_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_ros_sml_w2_comp <- model.sel(glmm_zyl_ros_sml_w2_1, glmm_zyl_ros_sml_w2_2, glmm_zyl_ros_sml_w2_3,
                                      glmm_zyl_ros_sml_w2_4, glmm_zyl_ros_sml_w2_5, glmm_zyl_ros_sml_w2_6,
                                      glmm_zyl_ros_sml_w2_7, glmm_zyl_ros_sml_w2_8, glmm_zyl_ros_sml_w2_9)
head(glmm_zyl_ros_sml_w2_comp)
#best model = glmm_zyl_ros_sml_w2_1
sim_zyl_ros_sml_w2 <- simulateResiduals(fittedModel = glmm_zyl_ros_sml_w2_1, plot = F)
plot(sim_zyl_ros_sml_w2)
summary(glmm_zyl_ros_sml_w2_1)

#zyl_ros_load large sites
glmm_zyl_ros_lrg_w2_1  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_ros_lrg_w2_2  <- glmmTMB(data = values_lrg_w2, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_ros_lrg_w2_comp <- model.sel(glmm_zyl_ros_lrg_w2_1, glmm_zyl_ros_lrg_w2_2)
head(glmm_zyl_ros_lrg_w2_comp)
#best model = glmm_zyl_ros_lrg_w2_1
sim_zyl_ros_lrg_w2 <- simulateResiduals(fittedModel = glmm_zyl_ros_lrg_w2_1, plot = F)
plot(sim_zyl_ros_lrg_w2)
summary(glmm_zyl_ros_lrg_w2_1)

################## zyl ros w3----------------------------------------------------------
#zyl_ros t/ha small sites
glmm_zyl_ros_sml_w3_1 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_ros_sml_w3_2 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_ros_sml_w3_3 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_ros_sml_w3_4 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_ros_sml_w3_5 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w3_6 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w3_7 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_ros_sml_w3_8 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_ros_sml_w3_9 <- glmmTMB(data = values_sml_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_ros_sml_w3_comp <- model.sel(glmm_zyl_ros_sml_w3_1, glmm_zyl_ros_sml_w3_2, glmm_zyl_ros_sml_w3_3,
                                      glmm_zyl_ros_sml_w3_4, glmm_zyl_ros_sml_w3_5, glmm_zyl_ros_sml_w3_6,
                                      glmm_zyl_ros_sml_w3_7, glmm_zyl_ros_sml_w3_8, glmm_zyl_ros_sml_w3_9)
head(glmm_zyl_ros_sml_w3_comp)
#best model = glmm_zyl_ros_sml_w3_1
sim_zyl_ros_sml_w3 <- simulateResiduals(fittedModel = glmm_zyl_ros_sml_w3_1, plot = F)
plot(sim_zyl_ros_sml_w3)
summary(glmm_zyl_ros_sml_w3_1)

#zyl_ros_load large sites
glmm_zyl_ros_lrg_w3_1  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_ros_lrg_w3_2  <- glmmTMB(data = values_lrg_w3, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_ros_lrg_w3_comp <- model.sel(glmm_zyl_ros_lrg_w3_1, glmm_zyl_ros_lrg_w3_2)
head(glmm_zyl_ros_lrg_w3_comp)
#best model = glmm_zyl_ros_lrg_w3_1
sim_zyl_ros_lrg_w3 <- simulateResiduals(fittedModel = glmm_zyl_ros_lrg_w3_1, plot = F)
plot(sim_zyl_ros_lrg_w3)
summary(glmm_zyl_ros_lrg_w3_1)

################## zyl ros w4----------------------------------------------------------
#zyl_ros t/ha small sites
glmm_zyl_ros_sml_w4_1 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_ros_sml_w4_2 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_ros_sml_w4_3 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_ros_sml_w4_4 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_ros_sml_w4_5 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w4_6 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w4_7 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_ros_sml_w4_8 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_ros_sml_w4_9 <- glmmTMB(data = values_sml_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_ros_sml_w4_comp <- model.sel(glmm_zyl_ros_sml_w4_1, glmm_zyl_ros_sml_w4_2, glmm_zyl_ros_sml_w4_3,
                                      glmm_zyl_ros_sml_w4_4, glmm_zyl_ros_sml_w4_5, glmm_zyl_ros_sml_w4_6,
                                      glmm_zyl_ros_sml_w4_7, glmm_zyl_ros_sml_w4_8, glmm_zyl_ros_sml_w4_9)
head(glmm_zyl_ros_sml_w4_comp)
#best model = glmm_zyl_ros_sml_w4_1
sim_zyl_ros_sml_w4 <- simulateResiduals(fittedModel = glmm_zyl_ros_sml_w4_1, plot = F)
plot(sim_zyl_ros_sml_w4)
summary(glmm_zyl_ros_sml_w4_1)

#zyl_ros_load large sites
glmm_zyl_ros_lrg_w4_1  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_ros_lrg_w4_2  <- glmmTMB(data = values_lrg_w4, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_ros_lrg_w4_comp <- model.sel(glmm_zyl_ros_lrg_w4_1, glmm_zyl_ros_lrg_w4_2)
head(glmm_zyl_ros_lrg_w4_comp)
#best model = glmm_zyl_ros_lrg_w4_1
sim_zyl_ros_lrg_w4 <- simulateResiduals(fittedModel = glmm_zyl_ros_lrg_w4_1, plot = F)
plot(sim_zyl_ros_lrg_w4)
summary(glmm_zyl_ros_lrg_w4_1)

################## zyl ros w5----------------------------------------------------------
glmm_zyl_ros_sml_w5_test <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor                                                + block)
summary(glmm_zyl_ros_sml_w5_test)
glmm_zyl_ros_sml_w5_1 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor                                                + block  + (1|site))
glmm_zyl_ros_sml_w5_2 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat                         + block  + (1|site))
glmm_zyl_ros_sml_w5_3 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor                        + block  + (1|site))
glmm_zyl_ros_sml_w5_4 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:tsf_factor                         + block  + (1|site))
glmm_zyl_ros_sml_w5_5 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat+ fire_treat:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w5_6 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + treatment:fire_treat + treatment:tsf_factor  + block  + (1|site))
glmm_zyl_ros_sml_w5_7 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+fire_treat+tsf_factor + fire_treat:tsf_factor + treatment:tsf_factor + block  + (1|site))
glmm_zyl_ros_sml_w5_8 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^2                                            + block  + (1|site))
glmm_zyl_ros_sml_w5_9 <- glmmTMB(data = values_sml_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  (treatment+fire_treat+tsf_factor)^3                                            + block  + (1|site))

glmm_zyl_ros_sml_w5_comp <- model.sel(glmm_zyl_ros_sml_w5_1, glmm_zyl_ros_sml_w5_2, glmm_zyl_ros_sml_w5_3,
                                      glmm_zyl_ros_sml_w5_4, glmm_zyl_ros_sml_w5_5, glmm_zyl_ros_sml_w5_6,
                                      glmm_zyl_ros_sml_w5_7, glmm_zyl_ros_sml_w5_8, glmm_zyl_ros_sml_w5_9)
head(glmm_zyl_ros_sml_w5_comp)
#best model = glmm_zyl_ros_sml_w5_1
sim_zyl_ros_sml_w5 <- simulateResiduals(fittedModel = glmm_zyl_ros_sml_w5_1, plot = F)
plot(sim_zyl_ros_sml_w5)
summary(glmm_zyl_ros_sml_w5_1)

#LARGE
glmm_zyl_ros_lrg_w5_1  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor                         + block  + (1|site))
glmm_zyl_ros_lrg_w5_2  <- glmmTMB(data = values_lrg_w5, family = "gaussian", na.action = "na.fail",  zyl_ros ~  treatment+tsf_factor + treatment:tsf_factor  + block  + (1|site))

glmm_zyl_ros_lrg_w5_comp <- model.sel(glmm_zyl_ros_lrg_w5_1, glmm_zyl_ros_lrg_w5_2)
head(glmm_zyl_ros_lrg_w5_comp)
#best model = glmm_zyl_ros_lrg_w5_1
sim_zyl_ros_lrg_w5 <- simulateResiduals(fittedModel = glmm_zyl_ros_lrg_w5_1, plot = F)
plot(sim_zyl_ros_lrg_w5)
summary(glmm_zyl_ros_lrg_w5_1)


##------------------------stiching appendix tables--------------------------
#mkv
glmm_mkv_fht_sml_all_comp<- bind_rows(glmm_mkv_fht_sml_w1_comp, glmm_mkv_fht_sml_w2_comp, glmm_mkv_fht_sml_w3_comp, glmm_mkv_fht_sml_w4_comp, glmm_mkv_fht_sml_w5_comp)
glmm_mkv_fli_sml_all_comp<- bind_rows(glmm_mkv_fli_sml_w1_comp, glmm_mkv_fli_sml_w2_comp, glmm_mkv_fli_sml_w3_comp, glmm_mkv_fli_sml_w4_comp, glmm_mkv_fli_sml_w5_comp)
glmm_mkv_ros_sml_all_comp<- bind_rows(glmm_mkv_ros_sml_w1_comp, glmm_mkv_ros_sml_w2_comp, glmm_mkv_ros_sml_w3_comp, glmm_mkv_ros_sml_w4_comp, glmm_mkv_ros_sml_w5_comp)

glmm_mkv_fht_lrg_all_comp<- bind_rows(glmm_mkv_fht_lrg_w1_comp, glmm_mkv_fht_lrg_w2_comp, glmm_mkv_fht_lrg_w3_comp, glmm_mkv_fht_lrg_w4_comp, glmm_mkv_fht_lrg_w5_comp)
glmm_mkv_fli_lrg_all_comp<- bind_rows(glmm_mkv_fli_lrg_w1_comp, glmm_mkv_fli_lrg_w2_comp, glmm_mkv_fli_lrg_w3_comp, glmm_mkv_fli_lrg_w4_comp, glmm_mkv_fli_lrg_w5_comp)
glmm_mkv_ros_lrg_all_comp<- bind_rows(glmm_mkv_ros_lrg_w1_comp, glmm_mkv_ros_lrg_w2_comp, glmm_mkv_ros_lrg_w3_comp, glmm_mkv_ros_lrg_w4_comp, glmm_mkv_ros_lrg_w5_comp)

#ves2
glmm_ves2_fht_sml_all_comp<- bind_rows(glmm_ves2_fht_sml_w1_comp, glmm_ves2_fht_sml_w2_comp, glmm_ves2_fht_sml_w3_comp, glmm_ves2_fht_sml_w4_comp, glmm_ves2_fht_sml_w5_comp)
glmm_ves2_fli_sml_all_comp<- bind_rows(glmm_ves2_fli_sml_w1_comp, glmm_ves2_fli_sml_w2_comp, glmm_ves2_fli_sml_w3_comp, glmm_ves2_fli_sml_w4_comp, glmm_ves2_fli_sml_w5_comp)
glmm_ves2_ros_sml_all_comp<- bind_rows(glmm_ves2_ros_sml_w1_comp, glmm_ves2_ros_sml_w2_comp, glmm_ves2_ros_sml_w3_comp, glmm_ves2_ros_sml_w4_comp, glmm_ves2_ros_sml_w5_comp)

glmm_ves2_fht_lrg_all_comp<- bind_rows(glmm_ves2_fht_lrg_w1_comp, glmm_ves2_fht_lrg_w2_comp, glmm_ves2_fht_lrg_w3_comp, glmm_ves2_fht_lrg_w4_comp, glmm_ves2_fht_lrg_w5_comp)
glmm_ves2_fli_lrg_all_comp<- bind_rows(glmm_ves2_fli_lrg_w1_comp, glmm_ves2_fli_lrg_w2_comp, glmm_ves2_fli_lrg_w3_comp, glmm_ves2_fli_lrg_w4_comp, glmm_ves2_fli_lrg_w5_comp)
glmm_ves2_ros_lrg_all_comp<- bind_rows(glmm_ves2_ros_lrg_w1_comp, glmm_ves2_ros_lrg_w2_comp, glmm_ves2_ros_lrg_w3_comp, glmm_ves2_ros_lrg_w4_comp, glmm_ves2_ros_lrg_w5_comp)

#zyl
glmm_zyl_fht_sml_all_comp<- bind_rows(glmm_zyl_fht_sml_w1_comp, glmm_zyl_fht_sml_w2_comp, glmm_zyl_fht_sml_w3_comp, glmm_zyl_fht_sml_w4_comp, glmm_zyl_fht_sml_w5_comp)
glmm_zyl_fli_sml_all_comp<- bind_rows(glmm_zyl_fli_sml_w1_comp, glmm_zyl_fli_sml_w2_comp, glmm_zyl_fli_sml_w3_comp, glmm_zyl_fli_sml_w4_comp, glmm_zyl_fli_sml_w5_comp)
glmm_zyl_ros_sml_all_comp<- bind_rows(glmm_zyl_ros_sml_w1_comp, glmm_zyl_ros_sml_w2_comp, glmm_zyl_ros_sml_w3_comp, glmm_zyl_ros_sml_w4_comp, glmm_zyl_ros_sml_w5_comp)

glmm_zyl_fht_lrg_all_comp<- bind_rows(glmm_zyl_fht_lrg_w1_comp, glmm_zyl_fht_lrg_w2_comp, glmm_zyl_fht_lrg_w3_comp, glmm_zyl_fht_lrg_w4_comp, glmm_zyl_fht_lrg_w5_comp)
glmm_zyl_fli_lrg_all_comp<- bind_rows(glmm_zyl_fli_lrg_w1_comp, glmm_zyl_fli_lrg_w2_comp, glmm_zyl_fli_lrg_w3_comp, glmm_zyl_fli_lrg_w4_comp, glmm_zyl_fli_lrg_w5_comp)
glmm_zyl_ros_lrg_all_comp<- bind_rows(glmm_zyl_ros_lrg_w1_comp, glmm_zyl_ros_lrg_w2_comp, glmm_zyl_ros_lrg_w3_comp, glmm_zyl_ros_lrg_w4_comp, glmm_zyl_ros_lrg_w5_comp)

#hmmm, lets try them all

#updated version with ves2
#sml
glmm_mkv_ves2_zyl_fht_fli_ros_sml_all_comp <- bind_rows(
  glmm_mkv_fht_sml_w2_comp, glmm_mkv_fht_sml_w3_comp, glmm_mkv_fht_sml_w4_comp, glmm_mkv_fht_sml_w5_comp,
  glmm_ves2_fht_sml_w2_comp, glmm_ves2_fht_sml_w3_comp, glmm_ves2_fht_sml_w4_comp, glmm_ves2_fht_sml_w5_comp,
  glmm_zyl_fht_sml_w2_comp, glmm_zyl_fht_sml_w3_comp, glmm_zyl_fht_sml_w4_comp, glmm_zyl_fht_sml_w5_comp,
  
  glmm_mkv_ros_sml_w2_comp, glmm_mkv_ros_sml_w3_comp, glmm_mkv_ros_sml_w4_comp, glmm_mkv_ros_sml_w5_comp,
  glmm_ves2_ros_sml_w2_comp, glmm_ves2_ros_sml_w3_comp, glmm_ves2_ros_sml_w4_comp, glmm_ves2_ros_sml_w5_comp,
  glmm_zyl_ros_sml_w2_comp, glmm_zyl_ros_sml_w3_comp, glmm_zyl_ros_sml_w4_comp, glmm_zyl_ros_sml_w5_comp,
  
  glmm_mkv_fli_sml_w2_comp, glmm_mkv_fli_sml_w3_comp, glmm_mkv_fli_sml_w4_comp, glmm_mkv_fli_sml_w5_comp,
  glmm_ves2_fli_sml_w2_comp, glmm_ves2_fli_sml_w3_comp, glmm_ves2_fli_sml_w4_comp, glmm_ves2_fli_sml_w5_comp,
  glmm_zyl_fli_sml_w2_comp, glmm_zyl_fli_sml_w3_comp, glmm_zyl_fli_sml_w4_comp, glmm_zyl_fli_sml_w5_comp)
glmm_mkv_ves2_zyl_fht_fli_ros_sml_all_comp2 <- subset.data.frame(glmm_mkv_ves2_zyl_fht_fli_ros_sml_all_comp, select = -c(2,3,4,5,6,7,8,9,10,15))
view(glmm_mkv_ves2_zyl_fht_fli_ros_sml_all_comp2)

glmm_mkv_ves2_zyl_fht_fli_ros_lrg_all_comp <- bind_rows(
  glmm_mkv_fht_lrg_w2_comp, glmm_mkv_fht_lrg_w3_comp, glmm_mkv_fht_lrg_w4_comp, glmm_mkv_fht_lrg_w5_comp,
  glmm_ves2_fht_lrg_w2_comp, glmm_ves2_fht_lrg_w3_comp, glmm_ves2_fht_lrg_w4_comp, glmm_ves2_fht_lrg_w5_comp,
  glmm_zyl_fht_lrg_w2_comp, glmm_zyl_fht_lrg_w3_comp, glmm_zyl_fht_lrg_w4_comp, glmm_zyl_fht_lrg_w5_comp,
  
  glmm_mkv_ros_lrg_w2_comp, glmm_mkv_ros_lrg_w3_comp, glmm_mkv_ros_lrg_w4_comp, glmm_mkv_ros_lrg_w5_comp,
  glmm_ves2_ros_lrg_w2_comp, glmm_ves2_ros_lrg_w3_comp, glmm_ves2_ros_lrg_w4_comp, glmm_ves2_ros_lrg_w5_comp,
  glmm_zyl_ros_lrg_w2_comp, glmm_zyl_ros_lrg_w3_comp, glmm_zyl_ros_lrg_w4_comp, glmm_zyl_ros_lrg_w5_comp,
  
  glmm_mkv_fli_lrg_w2_comp, glmm_mkv_fli_lrg_w3_comp, glmm_mkv_fli_lrg_w4_comp, glmm_mkv_fli_lrg_w5_comp,
  glmm_ves2_fli_lrg_w2_comp, glmm_ves2_fli_lrg_w3_comp, glmm_ves2_fli_lrg_w4_comp, glmm_ves2_fli_lrg_w5_comp,
  glmm_zyl_fli_lrg_w2_comp, glmm_zyl_fli_lrg_w3_comp, glmm_zyl_fli_lrg_w4_comp, glmm_zyl_fli_lrg_w5_comp)
glmm_mkv_ves2_zyl_fht_fli_ros_lrg_all_comp2 <- subset.data.frame(glmm_mkv_ves2_zyl_fht_fli_ros_lrg_all_comp, select = -c(2,3,4,5,6,11,12))
view(glmm_mkv_ves2_zyl_fht_fli_ros_lrg_all_comp2)

#--------------------------TABLES-------------------------------------------

#-----------------------Fuel Loads smal and larg----------------------------------------
r2_nakagawa(glmm_sur_fuel_sml_w1_1, by_group = FALSE, tolerance = 1e-05)
check_singularity(glmm_sur_fuel_sml_w1_1)
hist(fuel_sml$sur_t_ha)

plot_model(glmm_sur_fuel_sml_w1_1)

all_tab_fuel_sml <- tab_model(glmm_sur_fuel_sml_w1_1, 
                              glmm_ns_fuel_sml_w1_1, 
                              glmm_ele_fuel_sml_w1_1,
                              glmm_fuel_sml_w1_1, 
                              transform = NULL, show.est = TRUE,
                              pred.labels = c("Intercept", "Herbivory (Partial)", "Herbivory (Closed)", "Fire (Burnt)",
                                              "Year (2019)", "Year (2020)", "Block B", "Block C" ),
                              dv.labels = c("surface", "near_surface", "elevated", "total"),
                              string.pred = "Coefficient",
                              string.ci = "Conf. Int (95%)")
all_tab_fuel_sml

all_tab_fuel_lrg <- tab_model(glmm_sur_fuel_lrg_w1_1, 
                              glmm_ns_fuel_lrg_w1_1, 
                              glmm_ele_fuel_lrg_w1_1,
                              glmm_fuel_lrg_w1_1, 
                              transform = NULL, show.est = TRUE,
                              pred.labels = c("Intercept", "Herbivory (Closed)",
                                              "Year (2019)", "Year (2020)", 
                                              "Block B", "Block C", "Block D" ),
                              dv.labels = c("surface", "near_surface", "elevated", "total"),
                              string.pred = "Coefficient",
                              string.ci = "Conf. Int (95%)")
all_tab_fuel_lrg

#--------------------------------FINAL TABLE OUTPUTS------------------------------------------
#---------------------------------------FUEL LEVEL

fin_tab_fuel_sml <- (plot_models(glmm_sur_fuel_sml_w1_1, 
                                 glmm_ns_fuel_sml_w1_1, 
                                 glmm_ele_fuel_sml_w1_1, 
                                 glmm_fuel_sml_w1_1,
            axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                            "Herbivory (Closed)", "Herbivory (Partial)"),
            m.labels = c("Surface", "Near-surface", "Elevated", "Total"),
            show.values = FALSE, 
            vline.color = "red",
            colors = "gs",
            show.legend = FALSE,
            dot.size = 1,
            title = "SMALL PLOTS",
            legend.title = "Fuel Level"
            )) + theme_classic()
fin_tab_fuel_sml

fin_tab_fuel_lrg <- (plot_models(glmm_sur_fuel_lrg_w1_1, 
                                 glmm_ns_fuel_lrg_w1_1, 
                                 glmm_ele_fuel_lrg_w1_1, 
                                 glmm_fuel_lrg_w1_1,
                                 axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                 "Herbivory (Closed)"),
                                 m.labels = c("Surface", "Near-surface", "Elevated", "Total"),
                                 show.values = FALSE, 
                                 vline.color = "red",
                                 colors = "gs",
                                 show.legend = FALSE,
                                 dot.size = 1,
                                 title = "LARGE PLOTS"
                                 #legend.title = "Fuel Level"
                                 )) + theme_classic() + ylim(-1.4, 14)
fin_tab_fuel_lrg

fin_all_fuels <- cowplot::plot_grid(fin_tab_fuel_sml, fin_tab_fuel_lrg,
                                         #align = 'v', 
                                         #labels = c('A', 'B'), #label_x = 0.9, #label_y = 0.5, 
                                         ncol = 2)
fin_all_fuels

legend_fuel <- get_legend(
  # create some space to the left of the legend
  fin_tab_fuel_sml + guides(color = guide_legend(nrow = 1, reverse = TRUE)) +
    theme(legend.position = "bottom")
)

# add the legend to the row we made earlier. Give it one-third of 
# the width of one plot (via rel_widths).
fin_all_fuel_leg <- plot_grid(fin_all_fuels, legend_fuel, ncol = 1, rel_heights = c(1, .1))
fin_all_fuel_leg

#-----------------------------------MKV FINAL TABLES

fin_tab_mkv_fht_sml <- (plot_models(#glmm_mkv_fht_sml_w1_1, 
                                    glmm_mkv_fht_sml_w2_1, 
                                    glmm_mkv_fht_sml_w3_1, 
                                    glmm_mkv_fht_sml_w4_1, 
                                    glmm_mkv_fht_sml_w5_1,
                                 axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                 "Herbivory (Closed)", "Herbivory (Partial)"),
                                 m.labels = c( "WF03",
                                               "WF07",
                                               "WF17",
                                               "SuAv"),
                                 show.values = FALSE, 
                                 vline.color = "red",
                                 colors = "gs",
                                 show.legend = FALSE,
                                 dot.size = 1,
                                 title = "SMALL PLOTS
                                    Flame height",
                                 axis.title = "",
                                 legend.title = "Weather Scenario")) + theme_classic()
fin_tab_mkv_fht_sml

fin_tab_mkv_fht_lrg <- (plot_models(#glmm_mkv_fht_lrg_w1_1, 
                                    glmm_mkv_fht_lrg_w2_1, 
                                    glmm_mkv_fht_lrg_w3_1, 
                                    glmm_mkv_fht_lrg_w4_1, 
                                    glmm_mkv_fht_lrg_w5_1,
                                 axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                 "Herbivory (Closed)"),
                                 m.labels = c( "WF03",
                                               "WF07",
                                               "WF17",
                                               "SuAv"),
                                 show.values = FALSE, 
                                 vline.color = "red",
                                 colors = "gs",
                                 show.legend = FALSE,
                                 dot.size = 1,
                                 title = "LARGE PLOTS
                                      ",
                                 axis.title = "",
                                 legend.title = "Weather Scenario")) + theme_classic() + ylim(-1, 10)
fin_tab_mkv_fht_lrg

fin_tab_mkv_ros_sml <- (plot_models(#glmm_mkv_ros_sml_w1_1, 
                                    glmm_mkv_ros_sml_w2_1, 
                                    glmm_mkv_ros_sml_w3_1, 
                                    glmm_mkv_ros_sml_w4_1, 
                                    glmm_mkv_ros_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "Rate of fire spread",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.2, 0.5)
fin_tab_mkv_ros_sml

fin_tab_mkv_ros_lrg <- (plot_models(#glmm_mkv_ros_lrg_w1_1, 
                                    glmm_mkv_ros_lrg_w2_1, 
                                    glmm_mkv_ros_lrg_w3_1, 
                                    glmm_mkv_ros_lrg_w4_1, 
                                    glmm_mkv_ros_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = " ",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.1, 0.5)
fin_tab_mkv_ros_lrg

fin_tab_mkv_fli_sml <- (plot_models(#glmm_mkv_fli_sml_w1_1, 
                                    glmm_mkv_fli_sml_w2_1, 
                                    glmm_mkv_fli_sml_w3_1, 
                                    glmm_mkv_fli_sml_w4_1, 
                                    glmm_mkv_fli_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "Fireline intensity",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-2.5, 7.5)
fin_tab_mkv_fli_sml

fin_tab_mkv_fli_lrg <- (plot_models(#glmm_mkv_fli_lrg_w1_1, 
                                    glmm_mkv_fli_lrg_w2_1, 
                                    glmm_mkv_fli_lrg_w3_1, 
                                    glmm_mkv_fli_lrg_w4_1, 
                                    glmm_mkv_fli_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = " ",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-1, 7.5)
fin_tab_mkv_fli_lrg

fin_all_mkv <- cowplot::plot_grid(fin_tab_mkv_fht_sml, fin_tab_mkv_fht_lrg,
                                  fin_tab_mkv_ros_sml, fin_tab_mkv_ros_lrg,
                                  fin_tab_mkv_fli_sml, fin_tab_mkv_fli_lrg,
                                    #align = 'v', 
                                    labels = NULL, #label_x = 0.9, #label_y = 0.5, 
                                    ncol = 2)
fin_all_mkv

legend_mkv <- get_legend(fin_tab_mkv_fht_sml + 
                           guides(color = guide_legend(nrow = 1, reverse = TRUE)) +
                            theme(legend.position = "bottom"))

fin_all_mkv_leg <- cowplot::plot_grid(fin_all_mkv, legend_mkv,
                             ncol = 1, rel_heights = c(1, .1))
fin_all_mkv_leg

#-----------------------------------ves2 FINAL TABLES

fin_tab_ves2_fht_sml <- (plot_models(#glmm_ves2_fht_sml_w1_1, 
                                    glmm_ves2_fht_sml_w2_1, 
                                    glmm_ves2_fht_sml_w3_1, 
                                    glmm_ves2_fht_sml_w4_1, 
                                    glmm_ves2_fht_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "SMALL PLOTS
                                    Flame height",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.5, 4.5)
fin_tab_ves2_fht_sml

fin_tab_ves2_fht_lrg <- (plot_models(#glmm_ves2_fht_lrg_w1_1, 
                                    glmm_ves2_fht_lrg_w2_1, 
                                    glmm_ves2_fht_lrg_w3_1, 
                                    glmm_ves2_fht_lrg_w4_1, 
                                    glmm_ves2_fht_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "LARGE PLOTS
                                      ",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-3.5, 2)
fin_tab_ves2_fht_lrg

fin_tab_ves2_ros_sml <- (plot_models(#glmm_ves2_ros_sml_w1_1, 
                                    glmm_ves2_ros_sml_w2_1, 
                                    glmm_ves2_ros_sml_w3_1, 
                                    glmm_ves2_ros_sml_w4_1, 
                                    glmm_ves2_ros_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    #axis.lim = c(-0.25, 0.25),
                                    title = "Rate of fire spread",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.1, 0.25)
fin_tab_ves2_ros_sml 

fin_tab_ves2_ros_lrg <- (plot_models(#glmm_ves2_ros_lrg_w1_1, 
                                    glmm_ves2_ros_lrg_w2_1, 
                                    glmm_ves2_ros_lrg_w3_1, 
                                    glmm_ves2_ros_lrg_w4_1, 
                                    glmm_ves2_ros_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = " ",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.2, 0.25)
fin_tab_ves2_ros_lrg

fin_tab_ves2_fli_sml <- (plot_models(#glmm_ves2_fli_sml_w1_1, 
                                    glmm_ves2_fli_sml_w2_1, 
                                    glmm_ves2_fli_sml_w3_1, 
                                    glmm_ves2_fli_sml_w4_1, 
                                    glmm_ves2_fli_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "Fireline intensity",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-3, 17)
fin_tab_ves2_fli_sml

fin_tab_ves2_fli_lrg <- (plot_models(#glmm_ves2_fli_lrg_w1_1, 
                                    glmm_ves2_fli_lrg_w2_1, 
                                    glmm_ves2_fli_lrg_w3_1, 
                                    glmm_ves2_fli_lrg_w4_1, 
                                    glmm_ves2_fli_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = " ",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-2, 20)
fin_tab_ves2_fli_lrg

fin_all_ves2 <- cowplot::plot_grid(fin_tab_ves2_fht_sml, fin_tab_ves2_fht_lrg,
                                  fin_tab_ves2_ros_sml, fin_tab_ves2_ros_lrg,
                                  fin_tab_ves2_fli_sml, fin_tab_ves2_fli_lrg,
                                  #align = 'v', 
                                  labels = NULL, #label_x = 0.9, #label_y = 0.5, 
                                  ncol = 2)
fin_all_ves2

legend_ves2 <- get_legend(fin_tab_ves2_fht_sml + 
                           guides(color = guide_legend(nrow = 1, reverse = TRUE)) +
                           theme(legend.position = "bottom"))

fin_all_ves2_leg <- cowplot::plot_grid(fin_all_ves2, legend_ves2,
                             ncol = 1, rel_heights = c(1, .1))
fin_all_ves2_leg

#-----------------------------------zyl FINAL TABLES

fin_tab_zyl_fht_sml <- (plot_models(#glmm_zyl_fht_sml_w1_1, 
                                    glmm_zyl_fht_sml_w2_1, 
                                    glmm_zyl_fht_sml_w3_1, 
                                    glmm_zyl_fht_sml_w4_1, 
                                    glmm_zyl_fht_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "SMALL PLOTS
                                    Flame height",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-3.2, 4.5)
fin_tab_zyl_fht_sml

fin_tab_zyl_fht_lrg <- (plot_models(#glmm_zyl_fht_lrg_w1_1, 
                                    glmm_zyl_fht_lrg_w2_1, 
                                    glmm_zyl_fht_lrg_w3_1, 
                                    glmm_zyl_fht_lrg_w4_1, 
                                    glmm_zyl_fht_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "LARGE PLOTS
                                      ",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-2.6, 2.5)
fin_tab_zyl_fht_lrg

fin_tab_zyl_ros_sml <- (plot_models(#glmm_zyl_ros_sml_w1_1, 
                                    glmm_zyl_ros_sml_w2_1, 
                                    glmm_zyl_ros_sml_w3_1, 
                                    glmm_zyl_ros_sml_w4_1, 
                                    glmm_zyl_ros_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "Rate of fire spread",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.2, 0.5)
fin_tab_zyl_ros_sml

fin_tab_zyl_ros_lrg <- (plot_models(#glmm_zyl_ros_lrg_w1_1, 
                                    glmm_zyl_ros_lrg_w2_1, 
                                    glmm_zyl_ros_lrg_w3_1, 
                                    glmm_zyl_ros_lrg_w4_1, 
                                    glmm_zyl_ros_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = " ",
                                    axis.title = "",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-0.2, 0.5)
fin_tab_zyl_ros_lrg

fin_tab_zyl_fli_sml <- (plot_models(#glmm_zyl_fli_sml_w1_1, 
                                    glmm_zyl_fli_sml_w2_1, 
                                    glmm_zyl_fli_sml_w3_1, 
                                    glmm_zyl_fli_sml_w4_1, 
                                    glmm_zyl_fli_sml_w5_1,
                                    axis.labels = c("Block C" , "Block B", "Year (2020)", "Year (2019)", "Fire (Burnt)", 
                                                    "Herbivory (Closed)", "Herbivory (Partial)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = "Fireline intensity",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-2.5, 6.5)
fin_tab_zyl_fli_sml

fin_tab_zyl_fli_lrg <- (plot_models(#glmm_zyl_fli_lrg_w1_1, 
                                    glmm_zyl_fli_lrg_w2_1, 
                                    glmm_zyl_fli_lrg_w3_1, 
                                    glmm_zyl_fli_lrg_w4_1, 
                                    glmm_zyl_fli_lrg_w5_1,
                                    axis.labels = c("Block D", "Block C" , "Block B", "Year (2020)", "Year (2019)", 
                                                    "Herbivory (Closed)"),
                                    m.labels = c( "WF03",
                                                  "WF07",
                                                  "WF17",
                                                  "SuAv"),
                                    show.values = FALSE, 
                                    vline.color = "red",
                                    colors = "gs",
                                    show.legend = FALSE,
                                    dot.size = 1,
                                    title = " ",
                                    legend.title = "Weather Scenario")) + theme_classic() + ylim(-1.5, 4.5)
fin_tab_zyl_fli_lrg

fin_all_zyl <- cowplot::plot_grid(fin_tab_zyl_fht_sml, fin_tab_zyl_fht_lrg,
                                  fin_tab_zyl_ros_sml, fin_tab_zyl_ros_lrg,
                                  fin_tab_zyl_fli_sml, fin_tab_zyl_fli_lrg,
                                  #align = 'v', 
                                  labels = NULL, #label_x = 0.9, #label_y = 0.5, 
                                  ncol = 2)
fin_all_zyl

legend_zyl <- get_legend(fin_tab_zyl_fht_sml + 
                           guides(color = guide_legend(nrow = 1, reverse = TRUE)) +
                           theme(legend.position = "bottom"))

fin_all_zyl_leg <- cowplot::plot_grid(fin_all_zyl, legend_zyl,
                             ncol = 1, rel_heights = c(1, .1))
fin_all_zyl_leg
#-----------------------Exporting

fin_all_fuel_leg #825x602 96dpi
ggsave("glmm_tree_fuel.tiff")

fin_all_mkv_leg
ggsave("glmm_tree_mkv_v2.tiff", width = 8.59, height = 12, units = c("in"))

fin_all_ves2_leg
ggsave("glmm_tree_ves2_v2.tiff", width = 8.59, height = 12, units = c("in"))

fin_all_zyl_leg
ggsave("glmm_tree_zyl_v2.tiff", width = 8.59, height = 12, units = c("in"))

#-------------------------------plots-----------------------------------------

dodge <- position_dodge(width = 0.5)
weather_names <- c(
  `1` = "(1) 33°C 25% 20km/h",
  `2` = "(2) 24°C 44% 22km/h",
  `3` = "(3) 27°C 20% 32km/h",
  `4` = "(4) 17°C 64% 20km/h",
  `5` = "(5) 24°C 21% 17km/h")

#-------------------------------FINAL PLOTS
###################################################################################
###################################FUEL LOADS######################################
####################################################################################
summary(glmm_fuel_sml_w1_1)
#library(multcomp)

emm_total_fuel_sml_her <- emmeans(glmm_fuel_sml_w1_1, "treatment", type = "response")
emm_total_fuel_sml_her <- multcomp::cld(emm_total_fuel_sml_her, alpha = 0.10, Letters = LETTERS)
emm_total_fuel_sml_her$strata <- "total"
emm_total_fuel_sml_her$.group <- trimws(emm_total_fuel_sml_her$.group, which = c("both"))
emm_total_fuel_sml_her$order <- "d"

emm_sur_fuel_sml_her <- emmeans(glmm_sur_fuel_sml_w1_1, "treatment", type = "response")
emm_sur_fuel_sml_her <- multcomp::cld(emm_sur_fuel_sml_her, alpha = 0.10, Letters = LETTERS)
emm_sur_fuel_sml_her$strata <- "surface"
emm_sur_fuel_sml_her$.group <- trimws(emm_sur_fuel_sml_her$.group, which = c("both"))
emm_sur_fuel_sml_her$order <- "a"

emm_ns_fuel_sml_her <- emmeans(glmm_ns_fuel_sml_w1_1, "treatment", type = "response")
emm_ns_fuel_sml_her <- multcomp::cld(emm_ns_fuel_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ns_fuel_sml_her$strata <- "near-surface"
emm_ns_fuel_sml_her$.group <- trimws(emm_ns_fuel_sml_her$.group, which = c("both"))
emm_ns_fuel_sml_her$order <- "b"

emm_ele_fuel_sml_her <- emmeans(glmm_ele_fuel_sml_w1_1, "treatment", type = "response")
emm_ele_fuel_sml_her <- multcomp::cld(emm_ele_fuel_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ele_fuel_sml_her$strata <- "elevated"
emm_ele_fuel_sml_her$.group <- trimws(emm_ele_fuel_sml_her$.group, which = c("both"))
emm_ele_fuel_sml_her$order <- "c"

summ_fuel_all_sml_her <- rbind(emm_sur_fuel_sml_her,
                                  emm_ns_fuel_sml_her,
                                  emm_ele_fuel_sml_her,
                                  emm_total_fuel_sml_her)

plot_fuel_all_sml_her <- ggplot(data = summ_fuel_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = order)) +
  labs(x = " ", y = "Derived Fuel load (t/ha)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 25) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 1), position = position_dodge(width = 0.3))
plot_fuel_all_sml_her

########################
#######################

emm_total_fuel_sml_tsf <- emmeans(glmm_fuel_sml_w1_1, "tsf_factor", type = "response")
emm_total_fuel_sml_tsf <- multcomp::cld(emm_total_fuel_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_total_fuel_sml_tsf$strata <- "total"
emm_total_fuel_sml_tsf$.group <- trimws(emm_total_fuel_sml_tsf$.group, which = c("both"))
emm_total_fuel_sml_tsf$order <- "d"

emm_sur_fuel_sml_tsf <- emmeans(glmm_sur_fuel_sml_w1_1, "tsf_factor", type = "response")
emm_sur_fuel_sml_tsf <- multcomp::cld(emm_sur_fuel_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_sur_fuel_sml_tsf$strata <- "surface"
emm_sur_fuel_sml_tsf$.group <- trimws(emm_sur_fuel_sml_tsf$.group, which = c("both"))
emm_sur_fuel_sml_tsf$order <- "a"

emm_ns_fuel_sml_tsf <- emmeans(glmm_ns_fuel_sml_w1_1, "tsf_factor", type = "response")
emm_ns_fuel_sml_tsf <- multcomp::cld(emm_ns_fuel_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ns_fuel_sml_tsf$strata <- "near-surface"
emm_ns_fuel_sml_tsf$.group <- trimws(emm_ns_fuel_sml_tsf$.group, which = c("both"))
emm_ns_fuel_sml_tsf$order <- "b"

emm_ele_fuel_sml_tsf <- emmeans(glmm_ele_fuel_sml_w1_1, "tsf_factor", type = "response")
emm_ele_fuel_sml_tsf <- multcomp::cld(emm_ele_fuel_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ele_fuel_sml_tsf$strata <- "elevated"
emm_ele_fuel_sml_tsf$.group <- trimws(emm_ele_fuel_sml_tsf$.group, which = c("both"))
emm_ele_fuel_sml_tsf$order <- "c"

summ_fuel_all_sml_tsf <- rbind(emm_sur_fuel_sml_tsf,
                               emm_ns_fuel_sml_tsf,
                               emm_ele_fuel_sml_tsf,
                               emm_total_fuel_sml_tsf)

plot_fuel_all_sml_tsf <- ggplot(data = summ_fuel_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                  ymin = lower.CL, ymax = upper.CL,
                                                                  colour = order)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 25) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 1), position = position_dodge(width = 0.3))
plot_fuel_all_sml_tsf

########################
########################
emm_total_fuel_lrg_her <- emmeans(glmm_fuel_lrg_w1_1, "treatment", type = "response")
emm_total_fuel_lrg_her <- multcomp::cld(emm_total_fuel_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_total_fuel_lrg_her$strata <- "total"
emm_total_fuel_lrg_her$.group <- trimws(emm_total_fuel_lrg_her$.group, which = c("both"))
emm_total_fuel_lrg_her$order <- "d"

emm_sur_fuel_lrg_her <- emmeans(glmm_sur_fuel_lrg_w1_1, "treatment", type = "response")
emm_sur_fuel_lrg_her <- multcomp::cld(emm_sur_fuel_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_sur_fuel_lrg_her$strata <- "surface"
emm_sur_fuel_lrg_her$.group <- trimws(emm_sur_fuel_lrg_her$.group, which = c("both"))
emm_sur_fuel_lrg_her$order <- "a"

emm_ns_fuel_lrg_her <- emmeans(glmm_ns_fuel_lrg_w1_1, "treatment", type = "response")
emm_ns_fuel_lrg_her <- multcomp::cld(emm_ns_fuel_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ns_fuel_lrg_her$strata <- "near-surface"
emm_ns_fuel_lrg_her$.group <- trimws(emm_ns_fuel_lrg_her$.group, which = c("both"))
emm_ns_fuel_lrg_her$order <- "b"

emm_ele_fuel_lrg_her <- emmeans(glmm_ele_fuel_lrg_w1_1, "treatment", type = "response")
emm_ele_fuel_lrg_her <- multcomp::cld(emm_ele_fuel_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ele_fuel_lrg_her$strata <- "elevated"
emm_ele_fuel_lrg_her$.group <- trimws(emm_ele_fuel_lrg_her$.group, which = c("both"))
emm_ele_fuel_lrg_her$order <- "c"

summ_fuel_all_lrg_her <- rbind(emm_sur_fuel_lrg_her,
                               emm_ns_fuel_lrg_her,
                               emm_ele_fuel_lrg_her,
                               emm_total_fuel_lrg_her)

plot_fuel_all_lrg_her <- ggplot(data = summ_fuel_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                  ymin = lower.CL, ymax = upper.CL,
                                                                  colour = order)) +
  labs(x = "Fencing treatment", y = "Derived Fuel load (t/ha)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 25) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 1), position = position_dodge(width = 0.3))
plot_fuel_all_lrg_her

########################
#######################

emm_total_fuel_lrg_tsf <- emmeans(glmm_fuel_lrg_w1_1, "tsf_factor", type = "response")
emm_total_fuel_lrg_tsf <- multcomp::cld(emm_total_fuel_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_total_fuel_lrg_tsf$strata <- "total"
emm_total_fuel_lrg_tsf$.group <- trimws(emm_total_fuel_lrg_tsf$.group, which = c("both"))
emm_total_fuel_lrg_tsf$order <- "d"

emm_sur_fuel_lrg_tsf <- emmeans(glmm_sur_fuel_lrg_w1_1, "tsf_factor", type = "response")
emm_sur_fuel_lrg_tsf <- multcomp::cld(emm_sur_fuel_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_sur_fuel_lrg_tsf$strata <- "surface"
emm_sur_fuel_lrg_tsf$.group <- trimws(emm_sur_fuel_lrg_tsf$.group, which = c("both"))
emm_sur_fuel_lrg_tsf$order <- "a"

emm_ns_fuel_lrg_tsf <- emmeans(glmm_ns_fuel_lrg_w1_1, "tsf_factor", type = "response")
emm_ns_fuel_lrg_tsf <- multcomp::cld(emm_ns_fuel_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ns_fuel_lrg_tsf$strata <- "near-surface"
emm_ns_fuel_lrg_tsf$.group <- trimws(emm_ns_fuel_lrg_tsf$.group, which = c("both"))
emm_ns_fuel_lrg_tsf$order <- "b"

emm_ele_fuel_lrg_tsf <- emmeans(glmm_ele_fuel_lrg_w1_1, "tsf_factor", type = "response")
emm_ele_fuel_lrg_tsf <- multcomp::cld(emm_ele_fuel_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ele_fuel_lrg_tsf$strata <- "elevated"
emm_ele_fuel_lrg_tsf$.group <- trimws(emm_ele_fuel_lrg_tsf$.group, which = c("both"))
emm_ele_fuel_lrg_tsf$order <- "c"

summ_fuel_all_lrg_tsf <- rbind(emm_sur_fuel_lrg_tsf,
                               emm_ns_fuel_lrg_tsf,
                               emm_ele_fuel_lrg_tsf,
                               emm_total_fuel_lrg_tsf)

plot_fuel_all_lrg_tsf <- ggplot(data = summ_fuel_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                  ymin = lower.CL, ymax = upper.CL,
                                                                  colour = factor(order, labels = c("Surface", "Near-surface", "Elevated", "Total")))) +
  labs(x = "Time since fire (years)", y = " ", colour = "Strata") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  #theme( axis.title.y = element_text(margin = margin(b = 70))) +
  
  #scale_color_manual(labels = c("surface", "near-surface", "elevated", "total")) +
  ylim(0, 25) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 1), position = position_dodge(width = 0.3))
plot_fuel_all_lrg_tsf

#########################
########################
legend_fuel <- get_legend(plot_fuel_all_lrg_tsf + guides(color = guide_legend(nrow = 1)) + theme(legend.position = "bottom"))

fin_fuel_plots <- cowplot::plot_grid(plot_fuel_all_sml_her, 
                                     plot_fuel_all_sml_tsf, 
                                     plot_fuel_all_lrg_her,
                                     plot_fuel_all_lrg_tsf,
                   #align = 'v', 
                   labels = "AUTO", label_x = 0.9, label_y = 1, 
                   ncol = 2)
fin_fuel_plots_leg <- cowplot::plot_grid(fin_fuel_plots, legend_fuel,ncol = 1, rel_heights = c(1, .1))
fin_fuel_plots_leg

ggsave("fig_fuel_all2.tiff", width = 8.59, height = 9, units = c("in"))


#for pres
fin_fuel_plots2 <- cowplot::plot_grid(plot_fuel_all_sml_her, 
                                     plot_fuel_all_lrg_her,
                                     align = 'v', 
                                     labels = c("small", "large"), label_x = 0.7, label_y = 1, 
                                     ncol = 1)
fin_fuel_plots_leg2 <- cowplot::plot_grid(fin_fuel_plots2, legend_fuel,ncol = 1, rel_heights = c(1, .1))
fin_fuel_plots_leg2

############################NEW SET WITH NEW VESTA MARK 2######################################################################
####################################################################################################
####################################ALL SML PLOTS###################################################
####################################################################################################
#####FHT HER SML ALL

emm_mkv_fht_sml_her <- emmeans(glmm_mkv_fht_sml_w5_1, "treatment", type = "response")
emm_mkv_fht_sml_her <- multcomp::cld(emm_mkv_fht_sml_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_her$.group <- trimws(emm_mkv_fht_sml_her$.group, which = c("both"))
emm_mkv_fht_sml_her$model <- "a"

emm_ves2_fht_sml_her <- emmeans(glmm_ves2_fht_sml_w5_1, "treatment", type = "response")
emm_ves2_fht_sml_her <- multcomp::cld(emm_ves2_fht_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_her$.group <- trimws(emm_ves2_fht_sml_her$.group, which = c("both"))
emm_ves2_fht_sml_her$model <- "b"

emm_zyl_fht_sml_her <- emmeans(glmm_zyl_fht_sml_w5_1, "treatment", type = "response")
emm_zyl_fht_sml_her <- multcomp::cld(emm_zyl_fht_sml_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_her$.group <- trimws(emm_zyl_fht_sml_her$.group, which = c("both"))
emm_zyl_fht_sml_her$model <- "c"

summ_fht_all_sml_her <- rbind(emm_mkv_fht_sml_her, emm_ves2_fht_sml_her, emm_zyl_fht_sml_her)
view(summ_fht_all_sml_her)
plot_fht_all_sml_her <- ggplot(data = summ_fht_all_sml_her, aes(y = emmean, x = factor(treatment, levels = c("open", "partial", "closed")),  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = factor(model, labels = c("FFDM", "Vesta Mk2", "FRaME")))) +
  labs(x = " ", y = "Flame height (m)", colour = "Model") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  #ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_fht_all_sml_her
#######
##FHT TSF SML ALL

emm_mkv_fht_sml_tsf <- emmeans(glmm_mkv_fht_sml_w5_1, "tsf_factor", type = "response")
emm_mkv_fht_sml_tsf <- multcomp::cld(emm_mkv_fht_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_tsf$.group <- trimws(emm_mkv_fht_sml_tsf$.group, which = c("both"))
emm_mkv_fht_sml_tsf$model <- "a"

emm_ves2_fht_sml_tsf <- emmeans(glmm_ves2_fht_sml_w5_1, "tsf_factor", type = "response")
emm_ves2_fht_sml_tsf <- multcomp::cld(emm_ves2_fht_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_tsf$.group <- trimws(emm_ves2_fht_sml_tsf$.group, which = c("both"))
emm_ves2_fht_sml_tsf$model <- "b"

emm_zyl_fht_sml_tsf <- emmeans(glmm_zyl_fht_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_fht_sml_tsf <- multcomp::cld(emm_zyl_fht_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_tsf$.group <- trimws(emm_zyl_fht_sml_tsf$.group, which = c("both"))
emm_zyl_fht_sml_tsf$model <- "c"

summ_fht_all_sml_tsf <- rbind(emm_mkv_fht_sml_tsf, emm_ves2_fht_sml_tsf, emm_zyl_fht_sml_tsf)

plot_fht_all_sml_tsf <- ggplot(data = summ_fht_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = model)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  #ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_fht_all_sml_tsf

#####ros HER SML ALL

emm_mkv_ros_sml_her <- emmeans(glmm_mkv_ros_sml_w5_1, "treatment", type = "response")
emm_mkv_ros_sml_her <- multcomp::cld(emm_mkv_ros_sml_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_her$.group <- trimws(emm_mkv_ros_sml_her$.group, which = c("both"))
emm_mkv_ros_sml_her$model <- "a"

emm_ves2_ros_sml_her <- emmeans(glmm_ves2_ros_sml_w5_1, "treatment", type = "response")
emm_ves2_ros_sml_her <- multcomp::cld(emm_ves2_ros_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_her$.group <- trimws(emm_ves2_ros_sml_her$.group, which = c("both"))
emm_ves2_ros_sml_her$model <- "b"

emm_zyl_ros_sml_her <- emmeans(glmm_zyl_ros_sml_w5_1, "treatment", type = "response")
emm_zyl_ros_sml_her <- multcomp::cld(emm_zyl_ros_sml_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_her$.group <- trimws(emm_zyl_ros_sml_her$.group, which = c("both"))
emm_zyl_ros_sml_her$model <- "c"

summ_ros_all_sml_her <- rbind(emm_mkv_ros_sml_her, emm_ves2_ros_sml_her, emm_zyl_ros_sml_her)
view(summ_ros_all_sml_her)
plot_ros_all_sml_her <- ggplot(data = summ_ros_all_sml_her, aes(y = emmean, x = factor(treatment, levels = c("open", "partial", "closed")),  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = factor(model, labels = c("FFDM", "Vesta Mk2", "FRaME")))) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.1), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.06, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_ros_all_sml_her
#######
##ros TSF SML ALL

emm_mkv_ros_sml_tsf <- emmeans(glmm_mkv_ros_sml_w5_1, "tsf_factor", type = "response")
emm_mkv_ros_sml_tsf <- multcomp::cld(emm_mkv_ros_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_tsf$.group <- trimws(emm_mkv_ros_sml_tsf$.group, which = c("both"))
emm_mkv_ros_sml_tsf$model <- "a"

emm_ves2_ros_sml_tsf <- emmeans(glmm_ves2_ros_sml_w5_1, "tsf_factor", type = "response")
emm_ves2_ros_sml_tsf <- multcomp::cld(emm_ves2_ros_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_tsf$.group <- trimws(emm_ves2_ros_sml_tsf$.group, which = c("both"))
emm_ves2_ros_sml_tsf$model <- "b"

emm_zyl_ros_sml_tsf <- emmeans(glmm_zyl_ros_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_ros_sml_tsf <- multcomp::cld(emm_zyl_ros_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_tsf$.group <- trimws(emm_zyl_ros_sml_tsf$.group, which = c("both"))
emm_zyl_ros_sml_tsf$model <- "c"

summ_ros_all_sml_tsf <- rbind(emm_mkv_ros_sml_tsf, emm_ves2_ros_sml_tsf, emm_zyl_ros_sml_tsf)

plot_ros_all_sml_tsf <- ggplot(data = summ_ros_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = model)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.1), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.06, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_ros_all_sml_tsf

#####fli HER SML ALL

emm_mkv_fli_sml_her <- emmeans(glmm_mkv_fli_sml_w5_1, "treatment", type = "response")
emm_mkv_fli_sml_her <- multcomp::cld(emm_mkv_fli_sml_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_her$emmean <- emm_mkv_fli_sml_her$emmean * 1000
emm_mkv_fli_sml_her$lower.CL <- emm_mkv_fli_sml_her$lower.CL * 1000
emm_mkv_fli_sml_her$upper.CL <- emm_mkv_fli_sml_her$upper.CL * 1000
emm_mkv_fli_sml_her$.group <- trimws(emm_mkv_fli_sml_her$.group, which = c("both"))
emm_mkv_fli_sml_her$model <- "a"

emm_ves2_fli_sml_her <- emmeans(glmm_ves2_fli_sml_w5_1, "treatment", type = "response")
emm_ves2_fli_sml_her <- multcomp::cld(emm_ves2_fli_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_her$emmean <- emm_ves2_fli_sml_her$emmean * 1000
emm_ves2_fli_sml_her$lower.CL <- emm_ves2_fli_sml_her$lower.CL * 1000
emm_ves2_fli_sml_her$upper.CL <- emm_ves2_fli_sml_her$upper.CL * 1000
emm_ves2_fli_sml_her$.group <- trimws(emm_ves2_fli_sml_her$.group, which = c("both"))
emm_ves2_fli_sml_her$model <- "b"

emm_zyl_fli_sml_her <- emmeans(glmm_zyl_fli_sml_w5_1, "treatment", type = "response")
emm_zyl_fli_sml_her <- multcomp::cld(emm_zyl_fli_sml_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_her$emmean <- emm_zyl_fli_sml_her$emmean * 1000
emm_zyl_fli_sml_her$lower.CL <- emm_zyl_fli_sml_her$lower.CL * 1000
emm_zyl_fli_sml_her$upper.CL <- emm_zyl_fli_sml_her$upper.CL * 1000
emm_zyl_fli_sml_her$.group <- trimws(emm_zyl_fli_sml_her$.group, which = c("both"))
emm_zyl_fli_sml_her$model <- "c"

summ_fli_all_sml_her <- rbind(emm_mkv_fli_sml_her, emm_ves2_fli_sml_her, emm_zyl_fli_sml_her)

plot_fli_all_sml_her <- ggplot(data = summ_fli_all_sml_her, aes(y = emmean, x = factor(treatment, levels = c("open", "partial", "closed")),  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = factor(model, labels = c("FFDM", "Vesta Mk2", "FRaME")))) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 5000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 400), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_fli_all_sml_her
#######
##fli TSF SML ALL

emm_mkv_fli_sml_tsf <- emmeans(glmm_mkv_fli_sml_w5_1, "tsf_factor", type = "response")
emm_mkv_fli_sml_tsf <- multcomp::cld(emm_mkv_fli_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_tsf$emmean <- emm_mkv_fli_sml_tsf$emmean * 1000
emm_mkv_fli_sml_tsf$lower.CL <- emm_mkv_fli_sml_tsf$lower.CL * 1000
emm_mkv_fli_sml_tsf$upper.CL <- emm_mkv_fli_sml_tsf$upper.CL * 1000
emm_mkv_fli_sml_tsf$.group <- trimws(emm_mkv_fli_sml_tsf$.group, which = c("both"))
emm_mkv_fli_sml_tsf$model <- "a"

emm_ves2_fli_sml_tsf <- emmeans(glmm_ves2_fli_sml_w5_1, "tsf_factor", type = "response")
emm_ves2_fli_sml_tsf <- multcomp::cld(emm_ves2_fli_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_tsf$emmean <- emm_ves2_fli_sml_tsf$emmean * 1000
emm_ves2_fli_sml_tsf$lower.CL <- emm_ves2_fli_sml_tsf$lower.CL * 1000
emm_ves2_fli_sml_tsf$upper.CL <- emm_ves2_fli_sml_tsf$upper.CL * 1000
emm_ves2_fli_sml_tsf$.group <- trimws(emm_ves2_fli_sml_tsf$.group, which = c("both"))
emm_ves2_fli_sml_tsf$model <- "b"

emm_zyl_fli_sml_tsf <- emmeans(glmm_zyl_fli_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_fli_sml_tsf <- multcomp::cld(emm_zyl_fli_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_tsf$emmean <- emm_zyl_fli_sml_tsf$emmean * 1000
emm_zyl_fli_sml_tsf$lower.CL <- emm_zyl_fli_sml_tsf$lower.CL * 1000
emm_zyl_fli_sml_tsf$upper.CL <- emm_zyl_fli_sml_tsf$upper.CL * 1000
emm_zyl_fli_sml_tsf$.group <- trimws(emm_zyl_fli_sml_tsf$.group, which = c("both"))
emm_zyl_fli_sml_tsf$model <- "c"

summ_fli_all_sml_tsf <- rbind(emm_mkv_fli_sml_tsf, emm_ves2_fli_sml_tsf, emm_zyl_fli_sml_tsf)

plot_fli_all_sml_tsf <- ggplot(data = summ_fli_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = model)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 5000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 400), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_fli_all_sml_tsf

##############################
###putting together

legend_model <- get_legend(plot_fht_all_sml_her + guides(color = guide_legend(nrow = 1)) + theme(legend.position = "bottom"))

fin_all_sml_plots <- cowplot::plot_grid(plot_fht_all_sml_her,
                                        plot_fht_all_sml_tsf,
                                        plot_ros_all_sml_her,
                                        plot_ros_all_sml_tsf,
                                        plot_fli_all_sml_her,
                                        plot_fli_all_sml_tsf,
                                        labels = "AUTO", label_x = 0.9, label_y = 1, 
                                        ncol = 2)
fin_all_sml_plots_leg3 <- cowplot::plot_grid(fin_all_sml_plots, legend_model,ncol = 1, rel_heights = c(1, .1))
fin_all_sml_plots_leg
fin_all_sml_plots_leg2
fin_all_sml_plots_leg3

ggsave("fig_sml_all_v4.tiff", width = 8.59, height = 12, units = c("in"))

# #for presentation
# 
# fin_all_sml_plots2 <- cowplot::plot_grid(plot_fht_all_sml_her,
#                                         plot_ros_all_sml_her,
#                                         plot_fli_all_sml_her,
#                                         labels = NA, label_x = 0.9, label_y = 1, 
#                                         ncol = 1)
# fin_all_sml_plots_leg2 <- cowplot::plot_grid(fin_all_sml_plots2, legend_model,ncol = 1, rel_heights = c(1, .1))
# fin_all_sml_plots_leg2
# 
# ggsave("fig_sml_all_pres_thres.tiff", width = 5, height = 7, units = c("in"))
# 
# 
# fin_all_sml_plots3 <- cowplot::plot_grid(plot_fht_all_sml_her2,
#                                          plot_ros_all_sml_her2,
#                                          plot_fli_all_sml_her2,
#                                          labels = NA, label_x = 0.9, label_y = 1, 
#                                          ncol = 1)
# fin_all_sml_plots_leg3 <- cowplot::plot_grid(fin_all_sml_plots3, legend_model,ncol = 1, rel_heights = c(1, .1))
# fin_all_sml_plots_leg3
# 
# ggsave("fig_sml_all_pres.tiff", width = 5, height = 7, units = c("in"))

####################################################################################################
######################################ALL LRG PLOTS#################################################
####################################################################################################
#####FHT HER lrg ALL

emm_mkv_fht_lrg_her <- emmeans(glmm_mkv_fht_lrg_w5_1, "treatment", type = "response")
emm_mkv_fht_lrg_her <- multcomp::cld(emm_mkv_fht_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_her$.group <- trimws(emm_mkv_fht_lrg_her$.group, which = c("both"))
emm_mkv_fht_lrg_her$model <- "a"

emm_ves2_fht_lrg_her <- emmeans(glmm_ves2_fht_lrg_w5_1, "treatment", type = "response")
emm_ves2_fht_lrg_her <- multcomp::cld(emm_ves2_fht_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_her$.group <- trimws(emm_ves2_fht_lrg_her$.group, which = c("both"))
emm_ves2_fht_lrg_her$model <- "b"

emm_zyl_fht_lrg_her <- emmeans(glmm_zyl_fht_lrg_w5_1, "treatment", type = "response")
emm_zyl_fht_lrg_her <- multcomp::cld(emm_zyl_fht_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_her$.group <- trimws(emm_zyl_fht_lrg_her$.group, which = c("both"))
emm_zyl_fht_lrg_her$model <- "c"

summ_fht_all_lrg_her <- rbind(emm_mkv_fht_lrg_her, emm_ves2_fht_lrg_her, emm_zyl_fht_lrg_her)

plot_fht_all_lrg_her2 <- ggplot(data = summ_fht_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = factor(model, labels = c("FFDM", "Vesta Mk2", "FRaME")))) +
  labs(x = " ", y = "Flame height (m)", colour = "Model") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  #ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_fht_all_lrg_her
#######
##FHT TSF lrg ALL

emm_mkv_fht_lrg_tsf <- emmeans(glmm_mkv_fht_lrg_w5_1, "tsf_factor", type = "response")
emm_mkv_fht_lrg_tsf <- multcomp::cld(emm_mkv_fht_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_tsf$.group <- trimws(emm_mkv_fht_lrg_tsf$.group, which = c("both"))
emm_mkv_fht_lrg_tsf$model <- "a"

emm_ves2_fht_lrg_tsf <- emmeans(glmm_ves2_fht_lrg_w5_1, "tsf_factor", type = "response")
emm_ves2_fht_lrg_tsf <- multcomp::cld(emm_ves2_fht_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_tsf$.group <- trimws(emm_ves2_fht_lrg_tsf$.group, which = c("both"))
emm_ves2_fht_lrg_tsf$model <- "b"

emm_zyl_fht_lrg_tsf <- emmeans(glmm_zyl_fht_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_fht_lrg_tsf <- multcomp::cld(emm_zyl_fht_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_tsf$.group <- trimws(emm_zyl_fht_lrg_tsf$.group, which = c("both"))
emm_zyl_fht_lrg_tsf$model <- "c"

summ_fht_all_lrg_tsf <- rbind(emm_mkv_fht_lrg_tsf, emm_ves2_fht_lrg_tsf, emm_zyl_fht_lrg_tsf)

plot_fht_all_lrg_tsf <- ggplot(data = summ_fht_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = model)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  #ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_fht_all_lrg_tsf

#####ros HER lrg ALL

emm_mkv_ros_lrg_her <- emmeans(glmm_mkv_ros_lrg_w5_1, "treatment", type = "response")
emm_mkv_ros_lrg_her <- multcomp::cld(emm_mkv_ros_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_her$.group <- trimws(emm_mkv_ros_lrg_her$.group, which = c("both"))
emm_mkv_ros_lrg_her$model <- "a"

emm_ves2_ros_lrg_her <- emmeans(glmm_ves2_ros_lrg_w5_1, "treatment", type = "response")
emm_ves2_ros_lrg_her <- multcomp::cld(emm_ves2_ros_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_her$.group <- trimws(emm_ves2_ros_lrg_her$.group, which = c("both"))
emm_ves2_ros_lrg_her$model <- "b"

emm_zyl_ros_lrg_her <- emmeans(glmm_zyl_ros_lrg_w5_1, "treatment", type = "response")
emm_zyl_ros_lrg_her <- multcomp::cld(emm_zyl_ros_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_her$.group <- trimws(emm_zyl_ros_lrg_her$.group, which = c("both"))
emm_zyl_ros_lrg_her$model <- "c"

summ_ros_all_lrg_her <- rbind(emm_mkv_ros_lrg_her, emm_ves2_ros_lrg_her, emm_zyl_ros_lrg_her)

plot_ros_all_lrg_her <- ggplot(data = summ_ros_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = factor(model, labels = c("FFDM", "Vesta Mk2", "FRaME")))) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.1), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.06, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_ros_all_lrg_her
#######
##ros TSF lrg ALL

emm_mkv_ros_lrg_tsf <- emmeans(glmm_mkv_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_mkv_ros_lrg_tsf <- multcomp::cld(emm_mkv_ros_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_tsf$.group <- trimws(emm_mkv_ros_lrg_tsf$.group, which = c("both"))
emm_mkv_ros_lrg_tsf$model <- "a"

emm_ves2_ros_lrg_tsf <- emmeans(glmm_ves2_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_ves2_ros_lrg_tsf <- multcomp::cld(emm_ves2_ros_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_tsf$.group <- trimws(emm_ves2_ros_lrg_tsf$.group, which = c("both"))
emm_ves2_ros_lrg_tsf$model <- "b"

emm_zyl_ros_lrg_tsf <- emmeans(glmm_zyl_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_ros_lrg_tsf <- multcomp::cld(emm_zyl_ros_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_tsf$.group <- trimws(emm_zyl_ros_lrg_tsf$.group, which = c("both"))
emm_zyl_ros_lrg_tsf$model <- "c"

summ_ros_all_lrg_tsf <- rbind(emm_mkv_ros_lrg_tsf, emm_ves2_ros_lrg_tsf, emm_zyl_ros_lrg_tsf)

plot_ros_all_lrg_tsf <- ggplot(data = summ_ros_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = model)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.1), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.06, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_ros_all_lrg_tsf

#####fli HER lrg ALL

emm_mkv_fli_lrg_her <- emmeans(glmm_mkv_fli_lrg_w5_1, "treatment", type = "response")
emm_mkv_fli_lrg_her <- multcomp::cld(emm_mkv_fli_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_her$emmean <- emm_mkv_fli_lrg_her$emmean * 1000
emm_mkv_fli_lrg_her$lower.CL <- emm_mkv_fli_lrg_her$lower.CL * 1000
emm_mkv_fli_lrg_her$upper.CL <- emm_mkv_fli_lrg_her$upper.CL * 1000
emm_mkv_fli_lrg_her$.group <- trimws(emm_mkv_fli_lrg_her$.group, which = c("both"))
emm_mkv_fli_lrg_her$model <- "a"

emm_ves2_fli_lrg_her <- emmeans(glmm_ves2_fli_lrg_w5_1, "treatment", type = "response")
emm_ves2_fli_lrg_her <- multcomp::cld(emm_ves2_fli_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_her$emmean <- emm_ves2_fli_lrg_her$emmean * 1000
emm_ves2_fli_lrg_her$lower.CL <- emm_ves2_fli_lrg_her$lower.CL * 1000
emm_ves2_fli_lrg_her$upper.CL <- emm_ves2_fli_lrg_her$upper.CL * 1000
emm_ves2_fli_lrg_her$.group <- trimws(emm_ves2_fli_lrg_her$.group, which = c("both"))
emm_ves2_fli_lrg_her$model <- "b"

emm_zyl_fli_lrg_her <- emmeans(glmm_zyl_fli_lrg_w5_1, "treatment", type = "response")
emm_zyl_fli_lrg_her <- multcomp::cld(emm_zyl_fli_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_her$emmean <- emm_zyl_fli_lrg_her$emmean * 1000
emm_zyl_fli_lrg_her$lower.CL <- emm_zyl_fli_lrg_her$lower.CL * 1000
emm_zyl_fli_lrg_her$upper.CL <- emm_zyl_fli_lrg_her$upper.CL * 1000
emm_zyl_fli_lrg_her$.group <- trimws(emm_zyl_fli_lrg_her$.group, which = c("both"))
emm_zyl_fli_lrg_her$model <- "c"

summ_fli_all_lrg_her <- rbind(emm_mkv_fli_lrg_her, emm_ves2_fli_lrg_her, emm_zyl_fli_lrg_her)

plot_fli_all_lrg_her <- ggplot(data = summ_fli_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = factor(model, labels = c("FFDM", "Vesta Mk2", "FRaME")))) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 5000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 400), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_fli_all_lrg_her
#######
##fli TSF lrg ALL

emm_mkv_fli_lrg_tsf <- emmeans(glmm_mkv_fli_lrg_w5_1, "tsf_factor", type = "response")
emm_mkv_fli_lrg_tsf <- multcomp::cld(emm_mkv_fli_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_tsf$emmean <- emm_mkv_fli_lrg_tsf$emmean * 1000
emm_mkv_fli_lrg_tsf$lower.CL <- emm_mkv_fli_lrg_tsf$lower.CL * 1000
emm_mkv_fli_lrg_tsf$upper.CL <- emm_mkv_fli_lrg_tsf$upper.CL * 1000
emm_mkv_fli_lrg_tsf$.group <- trimws(emm_mkv_fli_lrg_tsf$.group, which = c("both"))
emm_mkv_fli_lrg_tsf$model <- "a"

emm_ves2_fli_lrg_tsf <- emmeans(glmm_ves2_fli_lrg_w5_1, "tsf_factor", type = "response")
emm_ves2_fli_lrg_tsf <- multcomp::cld(emm_ves2_fli_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_tsf$emmean <- emm_ves2_fli_lrg_tsf$emmean * 1000
emm_ves2_fli_lrg_tsf$lower.CL <- emm_ves2_fli_lrg_tsf$lower.CL * 1000
emm_ves2_fli_lrg_tsf$upper.CL <- emm_ves2_fli_lrg_tsf$upper.CL * 1000
emm_ves2_fli_lrg_tsf$.group <- trimws(emm_ves2_fli_lrg_tsf$.group, which = c("both"))
emm_ves2_fli_lrg_tsf$model <- "b"

emm_zyl_fli_lrg_tsf <- emmeans(glmm_zyl_fli_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_fli_lrg_tsf <- multcomp::cld(emm_zyl_fli_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_tsf$emmean <- emm_zyl_fli_lrg_tsf$emmean * 1000
emm_zyl_fli_lrg_tsf$lower.CL <- emm_zyl_fli_lrg_tsf$lower.CL * 1000
emm_zyl_fli_lrg_tsf$upper.CL <- emm_zyl_fli_lrg_tsf$upper.CL * 1000
emm_zyl_fli_lrg_tsf$.group <- trimws(emm_zyl_fli_lrg_tsf$.group, which = c("both"))
emm_zyl_fli_lrg_tsf$model <- "c"

summ_fli_all_lrg_tsf <- rbind(emm_mkv_fli_lrg_tsf, emm_ves2_fli_lrg_tsf, emm_zyl_fli_lrg_tsf)

plot_fli_all_lrg_tsf <- ggplot(data = summ_fli_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                ymin = lower.CL, ymax = upper.CL,
                                                                colour = model)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 5000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 400), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_fli_all_lrg_tsf

##############################
###putting together

legend_model <- get_legend(plot_fht_all_lrg_her + guides(color = guide_legend(nrow = 1)) + theme(legend.position = "bottom"))

fin_all_lrg_plots <- cowplot::plot_grid(plot_fht_all_lrg_her,
                                        plot_fht_all_lrg_tsf,
                                        plot_ros_all_lrg_her,
                                        plot_ros_all_lrg_tsf,
                                        plot_fli_all_lrg_her,
                                        plot_fli_all_lrg_tsf,
                                        labels = "AUTO", label_x = 0.9, label_y = 1, 
                                        ncol = 2)
fin_all_lrg_plots_leg <- cowplot::plot_grid(fin_all_lrg_plots, legend_model,ncol = 1, rel_heights = c(1, .1))
fin_all_lrg_plots_leg

ggsave("fig_lrg_all_v2.tiff", width = 8.59, height = 12, units = c("in"))


# #for pres
# fin_all_lrg_plots2 <- cowplot::plot_grid(plot_fht_all_lrg_her,
#                                         plot_ros_all_lrg_her,
#                                         plot_fli_all_lrg_her,
#                                         labels = NA, label_x = 0.9, label_y = 1, 
#                                         ncol = 1)
# fin_all_lrg_plots_leg2 <- cowplot::plot_grid(fin_all_lrg_plots2, legend_model,ncol = 1, rel_heights = c(1, .1))
# fin_all_lrg_plots_leg2
# 
# ggsave("fig_lrg_all_pres_thres.tiff", width = 5, height = 7, units = c("in"))
# 
# fin_all_lrg_plots3 <- cowplot::plot_grid(plot_fht_all_lrg_her2,
#                                          plot_ros_all_lrg_her2,
#                                          plot_fli_all_lrg_her2,
#                                          labels = NA, label_x = 0.9, label_y = 1, 
#                                          ncol = 1)
# fin_all_lrg_plots_leg3 <- cowplot::plot_grid(fin_all_lrg_plots3, legend_model,ncol = 1, rel_heights = c(1, .1))
# fin_all_lrg_plots_leg3
# 
# ggsave("fig_lrg_all_pres.tiff", width = 5, height = 7, units = c("in"))

####################################################################################################
########################################MKV#########################################################
####################################################################################################
emm_mkv_fht_sml_her <- emmeans(glmm_mkv_fht_sml_w5_1, "treatment", type = "response")
emm_mkv_fht_sml_her <- multcomp::cld(emm_mkv_fht_sml_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_her$weather_set <- 5
emm_mkv_fht_sml_her$.group <- trimws(emm_mkv_fht_sml_her$.group, which = c("both"))

summ_mkv_fht_w1_sml_her <- summarySE(values_sml_w1, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w2_sml_her <- summarySE(values_sml_w2, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w3_sml_her <- summarySE(values_sml_w3, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w4_sml_her <- summarySE(values_sml_w4, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w1_sml_her$weather_set <- 1
summ_mkv_fht_w2_sml_her$weather_set <- 2
summ_mkv_fht_w3_sml_her$weather_set <- 3
summ_mkv_fht_w4_sml_her$weather_set <- 4
summ_mkv_fht_w1_sml_her$emmean <- summ_mkv_fht_w1_sml_her$mkv_fht
summ_mkv_fht_w1_sml_her$lower.CL <- summ_mkv_fht_w1_sml_her$mkv_fht - summ_mkv_fht_w1_sml_her$ci
summ_mkv_fht_w1_sml_her$upper.CL <- summ_mkv_fht_w1_sml_her$mkv_fht + summ_mkv_fht_w1_sml_her$ci
summ_mkv_fht_w1_sml_her$.group <- " "
summ_mkv_fht_w2_sml_her$emmean <- summ_mkv_fht_w2_sml_her$mkv_fht
summ_mkv_fht_w2_sml_her$lower.CL <- summ_mkv_fht_w2_sml_her$mkv_fht - summ_mkv_fht_w2_sml_her$ci
summ_mkv_fht_w2_sml_her$upper.CL <- summ_mkv_fht_w2_sml_her$mkv_fht + summ_mkv_fht_w2_sml_her$ci
summ_mkv_fht_w2_sml_her$.group <- " "
summ_mkv_fht_w3_sml_her$emmean <- summ_mkv_fht_w3_sml_her$mkv_fht
summ_mkv_fht_w3_sml_her$lower.CL <- summ_mkv_fht_w3_sml_her$mkv_fht - summ_mkv_fht_w3_sml_her$ci
summ_mkv_fht_w3_sml_her$upper.CL <- summ_mkv_fht_w3_sml_her$mkv_fht + summ_mkv_fht_w3_sml_her$ci
summ_mkv_fht_w3_sml_her$.group <- " "
summ_mkv_fht_w4_sml_her$emmean <- summ_mkv_fht_w4_sml_her$mkv_fht
summ_mkv_fht_w4_sml_her$lower.CL <- summ_mkv_fht_w4_sml_her$mkv_fht - summ_mkv_fht_w4_sml_her$ci
summ_mkv_fht_w4_sml_her$upper.CL <- summ_mkv_fht_w4_sml_her$mkv_fht + summ_mkv_fht_w4_sml_her$ci
summ_mkv_fht_w4_sml_her$.group <- " "

common_cols_mkv_fht_sml_her <- intersect(colnames(emm_mkv_fht_sml_her), colnames(summ_mkv_fht_w1_sml_her))
summ_mkv_fht_all_sml_her <- rbind(
  #subset(summ_mkv_fht_w1_sml_her, select = common_cols_mkv_fht_sml_her),
                                  subset(summ_mkv_fht_w2_sml_her, select = common_cols_mkv_fht_sml_her),
                                  subset(summ_mkv_fht_w3_sml_her, select = common_cols_mkv_fht_sml_her),
                                  subset(summ_mkv_fht_w4_sml_her, select = common_cols_mkv_fht_sml_her),
                                  subset(emm_mkv_fht_sml_her, select = common_cols_mkv_fht_sml_her))
summ_mkv_fht_all_sml_her$weather_set <- as.factor(summ_mkv_fht_all_sml_her$weather_set)

plot_mkv_fht_sml_her <- ggplot(data = summ_mkv_fht_all_sml_her, aes(y = emmean, x = treatment,  
                                                                     ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Flame height (m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_mkv_fht_sml_her
########################
emm_mkv_fht_sml_tsf <- emmeans(glmm_mkv_fht_sml_w5_1, "tsf_factor", type = "response")
emm_mkv_fht_sml_tsf <- multcomp::cld(emm_mkv_fht_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_tsf$weather_set <- 5
emm_mkv_fht_sml_tsf$.group <- trimws(emm_mkv_fht_sml_tsf$.group, which = c("both"))

summ_mkv_fht_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w1_sml_tsf$weather_set <- 1
summ_mkv_fht_w2_sml_tsf$weather_set <- 2
summ_mkv_fht_w3_sml_tsf$weather_set <- 3
summ_mkv_fht_w4_sml_tsf$weather_set <- 4
summ_mkv_fht_w1_sml_tsf$emmean <- summ_mkv_fht_w1_sml_tsf$mkv_fht
summ_mkv_fht_w1_sml_tsf$lower.CL <- summ_mkv_fht_w1_sml_tsf$mkv_fht - summ_mkv_fht_w1_sml_tsf$ci
summ_mkv_fht_w1_sml_tsf$upper.CL <- summ_mkv_fht_w1_sml_tsf$mkv_fht + summ_mkv_fht_w1_sml_tsf$ci
summ_mkv_fht_w1_sml_tsf$.group <- " "
summ_mkv_fht_w2_sml_tsf$emmean <- summ_mkv_fht_w2_sml_tsf$mkv_fht
summ_mkv_fht_w2_sml_tsf$lower.CL <- summ_mkv_fht_w2_sml_tsf$mkv_fht - summ_mkv_fht_w2_sml_tsf$ci
summ_mkv_fht_w2_sml_tsf$upper.CL <- summ_mkv_fht_w2_sml_tsf$mkv_fht + summ_mkv_fht_w2_sml_tsf$ci
summ_mkv_fht_w2_sml_tsf$.group <- " "
summ_mkv_fht_w3_sml_tsf$emmean <- summ_mkv_fht_w3_sml_tsf$mkv_fht
summ_mkv_fht_w3_sml_tsf$lower.CL <- summ_mkv_fht_w3_sml_tsf$mkv_fht - summ_mkv_fht_w3_sml_tsf$ci
summ_mkv_fht_w3_sml_tsf$upper.CL <- summ_mkv_fht_w3_sml_tsf$mkv_fht + summ_mkv_fht_w3_sml_tsf$ci
summ_mkv_fht_w3_sml_tsf$.group <- " "
summ_mkv_fht_w4_sml_tsf$emmean <- summ_mkv_fht_w4_sml_tsf$mkv_fht
summ_mkv_fht_w4_sml_tsf$lower.CL <- summ_mkv_fht_w4_sml_tsf$mkv_fht - summ_mkv_fht_w4_sml_tsf$ci
summ_mkv_fht_w4_sml_tsf$upper.CL <- summ_mkv_fht_w4_sml_tsf$mkv_fht + summ_mkv_fht_w4_sml_tsf$ci
summ_mkv_fht_w4_sml_tsf$.group <- " "

common_cols_mkv_fht_sml_tsf <- intersect(colnames(emm_mkv_fht_sml_tsf), colnames(summ_mkv_fht_w1_sml_tsf))
summ_mkv_fht_all_sml_tsf <- rbind(
  #subset(summ_mkv_fht_w1_sml_tsf, select = common_cols_mkv_fht_sml_tsf),
                                  subset(summ_mkv_fht_w2_sml_tsf, select = common_cols_mkv_fht_sml_tsf),
                                  subset(summ_mkv_fht_w3_sml_tsf, select = common_cols_mkv_fht_sml_tsf),
                                  subset(summ_mkv_fht_w4_sml_tsf, select = common_cols_mkv_fht_sml_tsf),
                                  subset(emm_mkv_fht_sml_tsf, select = common_cols_mkv_fht_sml_tsf))
summ_mkv_fht_all_sml_tsf$weather_set <- as.factor(summ_mkv_fht_all_sml_tsf$weather_set)

plot_mkv_fht_sml_tsf <- ggplot(data = summ_mkv_fht_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') #+
  # geom_text(aes(3.3, 1, label = "(i)")) +
  # geom_text(aes(3.3, 2.5, label = "(ii)")) +
  # geom_text(aes(3.3, 6, label = "(iii)")) +
  # geom_text(aes(3.3, 11, label = "(iv)"))
plot_mkv_fht_sml_tsf

########################
emm_mkv_fht_lrg_her <- emmeans(glmm_mkv_fht_lrg_w5_1, "treatment", type = "response")
emm_mkv_fht_lrg_her <- multcomp::cld(emm_mkv_fht_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_her$weather_set <- 5
emm_mkv_fht_lrg_her$.group <- trimws(emm_mkv_fht_lrg_her$.group, which = c("both"))

summ_mkv_fht_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "mkv_fht", groupvars = c("treatment"))
summ_mkv_fht_w1_lrg_her$weather_set <- 1
summ_mkv_fht_w2_lrg_her$weather_set <- 2
summ_mkv_fht_w3_lrg_her$weather_set <- 3
summ_mkv_fht_w4_lrg_her$weather_set <- 4
summ_mkv_fht_w1_lrg_her$emmean <- summ_mkv_fht_w1_lrg_her$mkv_fht
summ_mkv_fht_w1_lrg_her$lower.CL <- summ_mkv_fht_w1_lrg_her$mkv_fht - summ_mkv_fht_w1_lrg_her$ci
summ_mkv_fht_w1_lrg_her$upper.CL <- summ_mkv_fht_w1_lrg_her$mkv_fht + summ_mkv_fht_w1_lrg_her$ci
summ_mkv_fht_w1_lrg_her$.group <- " "
summ_mkv_fht_w2_lrg_her$emmean <- summ_mkv_fht_w2_lrg_her$mkv_fht
summ_mkv_fht_w2_lrg_her$lower.CL <- summ_mkv_fht_w2_lrg_her$mkv_fht - summ_mkv_fht_w2_lrg_her$ci
summ_mkv_fht_w2_lrg_her$upper.CL <- summ_mkv_fht_w2_lrg_her$mkv_fht + summ_mkv_fht_w2_lrg_her$ci
summ_mkv_fht_w2_lrg_her$.group <- " "
summ_mkv_fht_w3_lrg_her$emmean <- summ_mkv_fht_w3_lrg_her$mkv_fht
summ_mkv_fht_w3_lrg_her$lower.CL <- summ_mkv_fht_w3_lrg_her$mkv_fht - summ_mkv_fht_w3_lrg_her$ci
summ_mkv_fht_w3_lrg_her$upper.CL <- summ_mkv_fht_w3_lrg_her$mkv_fht + summ_mkv_fht_w3_lrg_her$ci
summ_mkv_fht_w3_lrg_her$.group <- " "
summ_mkv_fht_w4_lrg_her$emmean <- summ_mkv_fht_w4_lrg_her$mkv_fht
summ_mkv_fht_w4_lrg_her$lower.CL <- summ_mkv_fht_w4_lrg_her$mkv_fht - summ_mkv_fht_w4_lrg_her$ci
summ_mkv_fht_w4_lrg_her$upper.CL <- summ_mkv_fht_w4_lrg_her$mkv_fht + summ_mkv_fht_w4_lrg_her$ci
summ_mkv_fht_w4_lrg_her$.group <- " "

common_cols_mkv_fht_lrg_her <- intersect(colnames(emm_mkv_fht_lrg_her), colnames(summ_mkv_fht_w1_lrg_her))
summ_mkv_fht_all_lrg_her <- rbind(
  #subset(summ_mkv_fht_w1_lrg_her, select = common_cols_mkv_fht_lrg_her),
                                  subset(summ_mkv_fht_w2_lrg_her, select = common_cols_mkv_fht_lrg_her),
                                  subset(summ_mkv_fht_w3_lrg_her, select = common_cols_mkv_fht_lrg_her),
                                  subset(summ_mkv_fht_w4_lrg_her, select = common_cols_mkv_fht_lrg_her),
                                  subset(emm_mkv_fht_lrg_her, select = common_cols_mkv_fht_lrg_her))
summ_mkv_fht_all_lrg_her$weather_set <- as.factor(summ_mkv_fht_all_lrg_her$weather_set)

plot_mkv_fht_lrg_her <- ggplot(data = summ_mkv_fht_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = factor(weather_set, labels = c("WF03", "WF07", "WF17", "SuAv")))) +
  labs(x = " ", y = "Flame height (m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0, "Weather Scenario") +
  #theme(legend.justification = c(1, 1), axis.title.y = element_text(margin = margin(b = 70))) +
  #labs(colour = "weather set") +
  #scale_color_discrete("Weather Scenario") +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 16) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_mkv_fht_lrg_her
########################
emm_mkv_fht_lrg_tsf <- emmeans(glmm_mkv_fht_lrg_w5_1, "tsf_factor", type = "response")
emm_mkv_fht_lrg_tsf <- multcomp::cld(emm_mkv_fht_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_tsf$weather_set <- 5
emm_mkv_fht_lrg_tsf$.group <- trimws(emm_mkv_fht_lrg_tsf$.group, which = c("both"))

summ_mkv_fht_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "mkv_fht", groupvars = c("tsf_factor"))
summ_mkv_fht_w1_lrg_tsf$weather_set <- 1
summ_mkv_fht_w2_lrg_tsf$weather_set <- 2
summ_mkv_fht_w3_lrg_tsf$weather_set <- 3
summ_mkv_fht_w4_lrg_tsf$weather_set <- 4
summ_mkv_fht_w1_lrg_tsf$emmean <- summ_mkv_fht_w1_lrg_tsf$mkv_fht
summ_mkv_fht_w1_lrg_tsf$lower.CL <- summ_mkv_fht_w1_lrg_tsf$mkv_fht - summ_mkv_fht_w1_lrg_tsf$ci
summ_mkv_fht_w1_lrg_tsf$upper.CL <- summ_mkv_fht_w1_lrg_tsf$mkv_fht + summ_mkv_fht_w1_lrg_tsf$ci
summ_mkv_fht_w1_lrg_tsf$.group <- " "
summ_mkv_fht_w2_lrg_tsf$emmean <- summ_mkv_fht_w2_lrg_tsf$mkv_fht
summ_mkv_fht_w2_lrg_tsf$lower.CL <- summ_mkv_fht_w2_lrg_tsf$mkv_fht - summ_mkv_fht_w2_lrg_tsf$ci
summ_mkv_fht_w2_lrg_tsf$upper.CL <- summ_mkv_fht_w2_lrg_tsf$mkv_fht + summ_mkv_fht_w2_lrg_tsf$ci
summ_mkv_fht_w2_lrg_tsf$.group <- " "
summ_mkv_fht_w3_lrg_tsf$emmean <- summ_mkv_fht_w3_lrg_tsf$mkv_fht
summ_mkv_fht_w3_lrg_tsf$lower.CL <- summ_mkv_fht_w3_lrg_tsf$mkv_fht - summ_mkv_fht_w3_lrg_tsf$ci
summ_mkv_fht_w3_lrg_tsf$upper.CL <- summ_mkv_fht_w3_lrg_tsf$mkv_fht + summ_mkv_fht_w3_lrg_tsf$ci
summ_mkv_fht_w3_lrg_tsf$.group <- " "
summ_mkv_fht_w4_lrg_tsf$emmean <- summ_mkv_fht_w4_lrg_tsf$mkv_fht
summ_mkv_fht_w4_lrg_tsf$lower.CL <- summ_mkv_fht_w4_lrg_tsf$mkv_fht - summ_mkv_fht_w4_lrg_tsf$ci
summ_mkv_fht_w4_lrg_tsf$upper.CL <- summ_mkv_fht_w4_lrg_tsf$mkv_fht + summ_mkv_fht_w4_lrg_tsf$ci
summ_mkv_fht_w4_lrg_tsf$.group <- " "

common_cols_mkv_fht_lrg_tsf <- intersect(colnames(emm_mkv_fht_lrg_tsf), colnames(summ_mkv_fht_w1_lrg_tsf))
summ_mkv_fht_all_lrg_tsf <- rbind(#subset(summ_mkv_fht_w1_lrg_tsf, select = common_cols_mkv_fht_lrg_tsf),
                                  subset(summ_mkv_fht_w2_lrg_tsf, select = common_cols_mkv_fht_lrg_tsf),
                                  subset(summ_mkv_fht_w3_lrg_tsf, select = common_cols_mkv_fht_lrg_tsf),
                                  subset(summ_mkv_fht_w4_lrg_tsf, select = common_cols_mkv_fht_lrg_tsf),
                                  subset(emm_mkv_fht_lrg_tsf, select = common_cols_mkv_fht_lrg_tsf))
summ_mkv_fht_all_lrg_tsf$weather_set <- as.factor(summ_mkv_fht_all_lrg_tsf$weather_set)

plot_mkv_fht_lrg_tsf <- ggplot(data = summ_mkv_fht_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 16) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') #+
  # geom_text(aes(3.3, 1, label = "(i)")) +
  # geom_text(aes(3.3, 2.5, label = "(ii)")) +
  # geom_text(aes(3.3, 6, label = "(iii)")) +
  # geom_text(aes(3.3, 11, label = "(iv)"))
plot_mkv_fht_lrg_tsf

####################################################################################################
###########MKV ROS
emm_mkv_ros_sml_her <- emmeans(glmm_mkv_ros_sml_w5_1, "treatment", type = "response")
emm_mkv_ros_sml_her <- multcomp::cld(emm_mkv_ros_sml_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_her$weather_set <- 5
emm_mkv_ros_sml_her$.group <- trimws(emm_mkv_ros_sml_her$.group, which = c("both"))

summ_mkv_ros_w1_sml_her <- summarySE(values_sml_w1, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w2_sml_her <- summarySE(values_sml_w2, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w3_sml_her <- summarySE(values_sml_w3, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w4_sml_her <- summarySE(values_sml_w4, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w1_sml_her$weather_set <- 1
summ_mkv_ros_w2_sml_her$weather_set <- 2
summ_mkv_ros_w3_sml_her$weather_set <- 3
summ_mkv_ros_w4_sml_her$weather_set <- 4
summ_mkv_ros_w1_sml_her$emmean <- summ_mkv_ros_w1_sml_her$mkv_ros
summ_mkv_ros_w1_sml_her$lower.CL <- summ_mkv_ros_w1_sml_her$mkv_ros - summ_mkv_ros_w1_sml_her$ci
summ_mkv_ros_w1_sml_her$upper.CL <- summ_mkv_ros_w1_sml_her$mkv_ros + summ_mkv_ros_w1_sml_her$ci
summ_mkv_ros_w1_sml_her$.group <- " "
summ_mkv_ros_w2_sml_her$emmean <- summ_mkv_ros_w2_sml_her$mkv_ros
summ_mkv_ros_w2_sml_her$lower.CL <- summ_mkv_ros_w2_sml_her$mkv_ros - summ_mkv_ros_w2_sml_her$ci
summ_mkv_ros_w2_sml_her$upper.CL <- summ_mkv_ros_w2_sml_her$mkv_ros + summ_mkv_ros_w2_sml_her$ci
summ_mkv_ros_w2_sml_her$.group <- " "
summ_mkv_ros_w3_sml_her$emmean <- summ_mkv_ros_w3_sml_her$mkv_ros
summ_mkv_ros_w3_sml_her$lower.CL <- summ_mkv_ros_w3_sml_her$mkv_ros - summ_mkv_ros_w3_sml_her$ci
summ_mkv_ros_w3_sml_her$upper.CL <- summ_mkv_ros_w3_sml_her$mkv_ros + summ_mkv_ros_w3_sml_her$ci
summ_mkv_ros_w3_sml_her$.group <- " "
summ_mkv_ros_w4_sml_her$emmean <- summ_mkv_ros_w4_sml_her$mkv_ros
summ_mkv_ros_w4_sml_her$lower.CL <- summ_mkv_ros_w4_sml_her$mkv_ros - summ_mkv_ros_w4_sml_her$ci
summ_mkv_ros_w4_sml_her$upper.CL <- summ_mkv_ros_w4_sml_her$mkv_ros + summ_mkv_ros_w4_sml_her$ci
summ_mkv_ros_w4_sml_her$.group <- " "

common_cols_mkv_ros_sml_her <- intersect(colnames(emm_mkv_ros_sml_her), colnames(summ_mkv_ros_w1_sml_her))
summ_mkv_ros_all_sml_her <- rbind(#subset(summ_mkv_ros_w1_sml_her, select = common_cols_mkv_ros_sml_her),
                                  subset(summ_mkv_ros_w2_sml_her, select = common_cols_mkv_ros_sml_her),
                                  subset(summ_mkv_ros_w3_sml_her, select = common_cols_mkv_ros_sml_her),
                                  subset(summ_mkv_ros_w4_sml_her, select = common_cols_mkv_ros_sml_her),
                                  subset(emm_mkv_ros_sml_her, select = common_cols_mkv_ros_sml_her))
summ_mkv_ros_all_sml_her$weather_set <- as.factor(summ_mkv_ros_all_sml_her$weather_set)

plot_mkv_ros_sml_her <- ggplot(data = summ_mkv_ros_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.05), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.06, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_mkv_ros_sml_her
########################
emm_mkv_ros_sml_tsf <- emmeans(glmm_mkv_ros_sml_w5_1, "tsf_factor", type = "response")
emm_mkv_ros_sml_tsf <- multcomp::cld(emm_mkv_ros_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_tsf$weather_set <- 5
emm_mkv_ros_sml_tsf$.group <- trimws(emm_mkv_ros_sml_tsf$.group, which = c("both"))

summ_mkv_ros_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w1_sml_tsf$weather_set <- 1
summ_mkv_ros_w2_sml_tsf$weather_set <- 2
summ_mkv_ros_w3_sml_tsf$weather_set <- 3
summ_mkv_ros_w4_sml_tsf$weather_set <- 4
summ_mkv_ros_w1_sml_tsf$emmean <- summ_mkv_ros_w1_sml_tsf$mkv_ros
summ_mkv_ros_w1_sml_tsf$lower.CL <- summ_mkv_ros_w1_sml_tsf$mkv_ros - summ_mkv_ros_w1_sml_tsf$ci
summ_mkv_ros_w1_sml_tsf$upper.CL <- summ_mkv_ros_w1_sml_tsf$mkv_ros + summ_mkv_ros_w1_sml_tsf$ci
summ_mkv_ros_w1_sml_tsf$.group <- " "
summ_mkv_ros_w2_sml_tsf$emmean <- summ_mkv_ros_w2_sml_tsf$mkv_ros
summ_mkv_ros_w2_sml_tsf$lower.CL <- summ_mkv_ros_w2_sml_tsf$mkv_ros - summ_mkv_ros_w2_sml_tsf$ci
summ_mkv_ros_w2_sml_tsf$upper.CL <- summ_mkv_ros_w2_sml_tsf$mkv_ros + summ_mkv_ros_w2_sml_tsf$ci
summ_mkv_ros_w2_sml_tsf$.group <- " "
summ_mkv_ros_w3_sml_tsf$emmean <- summ_mkv_ros_w3_sml_tsf$mkv_ros
summ_mkv_ros_w3_sml_tsf$lower.CL <- summ_mkv_ros_w3_sml_tsf$mkv_ros - summ_mkv_ros_w3_sml_tsf$ci
summ_mkv_ros_w3_sml_tsf$upper.CL <- summ_mkv_ros_w3_sml_tsf$mkv_ros + summ_mkv_ros_w3_sml_tsf$ci
summ_mkv_ros_w3_sml_tsf$.group <- " "
summ_mkv_ros_w4_sml_tsf$emmean <- summ_mkv_ros_w4_sml_tsf$mkv_ros
summ_mkv_ros_w4_sml_tsf$lower.CL <- summ_mkv_ros_w4_sml_tsf$mkv_ros - summ_mkv_ros_w4_sml_tsf$ci
summ_mkv_ros_w4_sml_tsf$upper.CL <- summ_mkv_ros_w4_sml_tsf$mkv_ros + summ_mkv_ros_w4_sml_tsf$ci
summ_mkv_ros_w4_sml_tsf$.group <- " "

common_cols_mkv_ros_sml_tsf <- intersect(colnames(emm_mkv_ros_sml_tsf), colnames(summ_mkv_ros_w1_sml_tsf))
summ_mkv_ros_all_sml_tsf <- rbind(#subset(summ_mkv_ros_w1_sml_tsf, select = common_cols_mkv_ros_sml_tsf),
                                  subset(summ_mkv_ros_w2_sml_tsf, select = common_cols_mkv_ros_sml_tsf),
                                  subset(summ_mkv_ros_w3_sml_tsf, select = common_cols_mkv_ros_sml_tsf),
                                  subset(summ_mkv_ros_w4_sml_tsf, select = common_cols_mkv_ros_sml_tsf),
                                  subset(emm_mkv_ros_sml_tsf, select = common_cols_mkv_ros_sml_tsf))
summ_mkv_ros_all_sml_tsf$weather_set <- as.factor(summ_mkv_ros_all_sml_tsf$weather_set)

plot_mkv_ros_sml_tsf <- ggplot(data = summ_mkv_ros_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +  
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.05), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed')
plot_mkv_ros_sml_tsf

########################
emm_mkv_ros_lrg_her <- emmeans(glmm_mkv_ros_lrg_w5_1, "treatment", type = "response")
emm_mkv_ros_lrg_her <- multcomp::cld(emm_mkv_ros_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_her$weather_set <- 5
emm_mkv_ros_lrg_her$.group <- trimws(emm_mkv_ros_lrg_her$.group, which = c("both"))

summ_mkv_ros_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "mkv_ros", groupvars = c("treatment"))
summ_mkv_ros_w1_lrg_her$weather_set <- 1
summ_mkv_ros_w2_lrg_her$weather_set <- 2
summ_mkv_ros_w3_lrg_her$weather_set <- 3
summ_mkv_ros_w4_lrg_her$weather_set <- 4
summ_mkv_ros_w1_lrg_her$emmean <- summ_mkv_ros_w1_lrg_her$mkv_ros
summ_mkv_ros_w1_lrg_her$lower.CL <- summ_mkv_ros_w1_lrg_her$mkv_ros - summ_mkv_ros_w1_lrg_her$ci
summ_mkv_ros_w1_lrg_her$upper.CL <- summ_mkv_ros_w1_lrg_her$mkv_ros + summ_mkv_ros_w1_lrg_her$ci
summ_mkv_ros_w1_lrg_her$.group <- " "
summ_mkv_ros_w2_lrg_her$emmean <- summ_mkv_ros_w2_lrg_her$mkv_ros
summ_mkv_ros_w2_lrg_her$lower.CL <- summ_mkv_ros_w2_lrg_her$mkv_ros - summ_mkv_ros_w2_lrg_her$ci
summ_mkv_ros_w2_lrg_her$upper.CL <- summ_mkv_ros_w2_lrg_her$mkv_ros + summ_mkv_ros_w2_lrg_her$ci
summ_mkv_ros_w2_lrg_her$.group <- " "
summ_mkv_ros_w3_lrg_her$emmean <- summ_mkv_ros_w3_lrg_her$mkv_ros
summ_mkv_ros_w3_lrg_her$lower.CL <- summ_mkv_ros_w3_lrg_her$mkv_ros - summ_mkv_ros_w3_lrg_her$ci
summ_mkv_ros_w3_lrg_her$upper.CL <- summ_mkv_ros_w3_lrg_her$mkv_ros + summ_mkv_ros_w3_lrg_her$ci
summ_mkv_ros_w3_lrg_her$.group <- " "
summ_mkv_ros_w4_lrg_her$emmean <- summ_mkv_ros_w4_lrg_her$mkv_ros
summ_mkv_ros_w4_lrg_her$lower.CL <- summ_mkv_ros_w4_lrg_her$mkv_ros - summ_mkv_ros_w4_lrg_her$ci
summ_mkv_ros_w4_lrg_her$upper.CL <- summ_mkv_ros_w4_lrg_her$mkv_ros + summ_mkv_ros_w4_lrg_her$ci
summ_mkv_ros_w4_lrg_her$.group <- " "

common_cols_mkv_ros_lrg_her <- intersect(colnames(emm_mkv_ros_lrg_her), colnames(summ_mkv_ros_w1_lrg_her))
summ_mkv_ros_all_lrg_her <- rbind(#subset(summ_mkv_ros_w1_lrg_her, select = common_cols_mkv_ros_lrg_her),
                                  subset(summ_mkv_ros_w2_lrg_her, select = common_cols_mkv_ros_lrg_her),
                                  subset(summ_mkv_ros_w3_lrg_her, select = common_cols_mkv_ros_lrg_her),
                                  subset(summ_mkv_ros_w4_lrg_her, select = common_cols_mkv_ros_lrg_her),
                                  subset(emm_mkv_ros_lrg_her, select = common_cols_mkv_ros_lrg_her))
summ_mkv_ros_all_lrg_her$weather_set <- as.factor(summ_mkv_ros_all_lrg_her$weather_set)

plot_mkv_ros_lrg_her <- ggplot(data = summ_mkv_ros_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +  
  labs(colour = "weather set") +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.05), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_mkv_ros_lrg_her
########################
emm_mkv_ros_lrg_tsf <- emmeans(glmm_mkv_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_mkv_ros_lrg_tsf <- multcomp::cld(emm_mkv_ros_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_tsf$weather_set <- 5
emm_mkv_ros_lrg_tsf$.group <- trimws(emm_mkv_ros_lrg_tsf$.group, which = c("both"))

summ_mkv_ros_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "mkv_ros", groupvars = c("tsf_factor"))
summ_mkv_ros_w1_lrg_tsf$weather_set <- 1
summ_mkv_ros_w2_lrg_tsf$weather_set <- 2
summ_mkv_ros_w3_lrg_tsf$weather_set <- 3
summ_mkv_ros_w4_lrg_tsf$weather_set <- 4
summ_mkv_ros_w1_lrg_tsf$emmean <- summ_mkv_ros_w1_lrg_tsf$mkv_ros
summ_mkv_ros_w1_lrg_tsf$lower.CL <- summ_mkv_ros_w1_lrg_tsf$mkv_ros - summ_mkv_ros_w1_lrg_tsf$ci
summ_mkv_ros_w1_lrg_tsf$upper.CL <- summ_mkv_ros_w1_lrg_tsf$mkv_ros + summ_mkv_ros_w1_lrg_tsf$ci
summ_mkv_ros_w1_lrg_tsf$.group <- " "
summ_mkv_ros_w2_lrg_tsf$emmean <- summ_mkv_ros_w2_lrg_tsf$mkv_ros
summ_mkv_ros_w2_lrg_tsf$lower.CL <- summ_mkv_ros_w2_lrg_tsf$mkv_ros - summ_mkv_ros_w2_lrg_tsf$ci
summ_mkv_ros_w2_lrg_tsf$upper.CL <- summ_mkv_ros_w2_lrg_tsf$mkv_ros + summ_mkv_ros_w2_lrg_tsf$ci
summ_mkv_ros_w2_lrg_tsf$.group <- " "
summ_mkv_ros_w3_lrg_tsf$emmean <- summ_mkv_ros_w3_lrg_tsf$mkv_ros
summ_mkv_ros_w3_lrg_tsf$lower.CL <- summ_mkv_ros_w3_lrg_tsf$mkv_ros - summ_mkv_ros_w3_lrg_tsf$ci
summ_mkv_ros_w3_lrg_tsf$upper.CL <- summ_mkv_ros_w3_lrg_tsf$mkv_ros + summ_mkv_ros_w3_lrg_tsf$ci
summ_mkv_ros_w3_lrg_tsf$.group <- " "
summ_mkv_ros_w4_lrg_tsf$emmean <- summ_mkv_ros_w4_lrg_tsf$mkv_ros
summ_mkv_ros_w4_lrg_tsf$lower.CL <- summ_mkv_ros_w4_lrg_tsf$mkv_ros - summ_mkv_ros_w4_lrg_tsf$ci
summ_mkv_ros_w4_lrg_tsf$upper.CL <- summ_mkv_ros_w4_lrg_tsf$mkv_ros + summ_mkv_ros_w4_lrg_tsf$ci
summ_mkv_ros_w4_lrg_tsf$.group <- " "

common_cols_mkv_ros_lrg_tsf <- intersect(colnames(emm_mkv_ros_lrg_tsf), colnames(summ_mkv_ros_w1_lrg_tsf))
summ_mkv_ros_all_lrg_tsf <- rbind(#subset(summ_mkv_ros_w1_lrg_tsf, select = common_cols_mkv_ros_lrg_tsf),
                                  subset(summ_mkv_ros_w2_lrg_tsf, select = common_cols_mkv_ros_lrg_tsf),
                                  subset(summ_mkv_ros_w3_lrg_tsf, select = common_cols_mkv_ros_lrg_tsf),
                                  subset(summ_mkv_ros_w4_lrg_tsf, select = common_cols_mkv_ros_lrg_tsf),
                                  subset(emm_mkv_ros_lrg_tsf, select = common_cols_mkv_ros_lrg_tsf))
summ_mkv_ros_all_lrg_tsf$weather_set <- as.factor(summ_mkv_ros_all_lrg_tsf$weather_set)

plot_mkv_ros_lrg_tsf <- ggplot(data = summ_mkv_ros_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +  
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.05), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_mkv_ros_lrg_tsf

####################################################################################################
########################MKV FLI
emm_mkv_fli_sml_her <- emmeans(glmm_mkv_fli_sml_w5_1, "treatment", type = "response")
emm_mkv_fli_sml_her <- multcomp::cld(emm_mkv_fli_sml_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_her$emmean <- emm_mkv_fli_sml_her$emmean * 1000
emm_mkv_fli_sml_her$lower.CL <- emm_mkv_fli_sml_her$lower.CL * 1000
emm_mkv_fli_sml_her$upper.CL <- emm_mkv_fli_sml_her$upper.CL * 1000
emm_mkv_fli_sml_her$weather_set <- 5
emm_mkv_fli_sml_her$.group <- trimws(emm_mkv_fli_sml_her$.group, which = c("both"))

summ_mkv_fli_w1_sml_her <- summarySE(values_sml_w1, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w2_sml_her <- summarySE(values_sml_w2, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w3_sml_her <- summarySE(values_sml_w3, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w4_sml_her <- summarySE(values_sml_w4, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w1_sml_her$weather_set <- 1
summ_mkv_fli_w2_sml_her$weather_set <- 2
summ_mkv_fli_w3_sml_her$weather_set <- 3
summ_mkv_fli_w4_sml_her$weather_set <- 4
summ_mkv_fli_w1_sml_her$emmean <- summ_mkv_fli_w1_sml_her$mkv_fli
summ_mkv_fli_w1_sml_her$lower.CL <- summ_mkv_fli_w1_sml_her$mkv_fli - summ_mkv_fli_w1_sml_her$ci
summ_mkv_fli_w1_sml_her$upper.CL <- summ_mkv_fli_w1_sml_her$mkv_fli + summ_mkv_fli_w1_sml_her$ci
summ_mkv_fli_w1_sml_her$.group <- " "
summ_mkv_fli_w2_sml_her$emmean <- summ_mkv_fli_w2_sml_her$mkv_fli
summ_mkv_fli_w2_sml_her$lower.CL <- summ_mkv_fli_w2_sml_her$mkv_fli - summ_mkv_fli_w2_sml_her$ci
summ_mkv_fli_w2_sml_her$upper.CL <- summ_mkv_fli_w2_sml_her$mkv_fli + summ_mkv_fli_w2_sml_her$ci
summ_mkv_fli_w2_sml_her$.group <- " "
summ_mkv_fli_w3_sml_her$emmean <- summ_mkv_fli_w3_sml_her$mkv_fli
summ_mkv_fli_w3_sml_her$lower.CL <- summ_mkv_fli_w3_sml_her$mkv_fli - summ_mkv_fli_w3_sml_her$ci
summ_mkv_fli_w3_sml_her$upper.CL <- summ_mkv_fli_w3_sml_her$mkv_fli + summ_mkv_fli_w3_sml_her$ci
summ_mkv_fli_w3_sml_her$.group <- " "
summ_mkv_fli_w4_sml_her$emmean <- summ_mkv_fli_w4_sml_her$mkv_fli
summ_mkv_fli_w4_sml_her$lower.CL <- summ_mkv_fli_w4_sml_her$mkv_fli - summ_mkv_fli_w4_sml_her$ci
summ_mkv_fli_w4_sml_her$upper.CL <- summ_mkv_fli_w4_sml_her$mkv_fli + summ_mkv_fli_w4_sml_her$ci
summ_mkv_fli_w4_sml_her$.group <- " "

common_cols_mkv_fli_sml_her <- intersect(colnames(emm_mkv_fli_sml_her), colnames(summ_mkv_fli_w1_sml_her))
summ_mkv_fli_all_sml_her <- rbind(#subset(summ_mkv_fli_w1_sml_her, select = common_cols_mkv_fli_sml_her),
                                  subset(summ_mkv_fli_w2_sml_her, select = common_cols_mkv_fli_sml_her),
                                  subset(summ_mkv_fli_w3_sml_her, select = common_cols_mkv_fli_sml_her),
                                  subset(summ_mkv_fli_w4_sml_her, select = common_cols_mkv_fli_sml_her),
                                  subset(emm_mkv_fli_sml_her, select = common_cols_mkv_fli_sml_her))
summ_mkv_fli_all_sml_her$weather_set <- as.factor(summ_mkv_fli_all_sml_her$weather_set)

plot_mkv_fli_sml_her <- ggplot(data = summ_mkv_fli_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 10000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_mkv_fli_sml_her
########################
emm_mkv_fli_sml_tsf <- emmeans(glmm_mkv_fli_sml_w5_1, "tsf_factor", type = "response")
emm_mkv_fli_sml_tsf <- multcomp::cld(emm_mkv_fli_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_tsf$emmean <- emm_mkv_fli_sml_tsf$emmean * 1000
emm_mkv_fli_sml_tsf$lower.CL <- emm_mkv_fli_sml_tsf$lower.CL * 1000
emm_mkv_fli_sml_tsf$upper.CL <- emm_mkv_fli_sml_tsf$upper.CL * 1000
emm_mkv_fli_sml_tsf$weather_set <- 5
emm_mkv_fli_sml_tsf$.group <- trimws(emm_mkv_fli_sml_tsf$.group, which = c("both"))

summ_mkv_fli_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w1_sml_tsf$weather_set <- 1
summ_mkv_fli_w2_sml_tsf$weather_set <- 2
summ_mkv_fli_w3_sml_tsf$weather_set <- 3
summ_mkv_fli_w4_sml_tsf$weather_set <- 4
summ_mkv_fli_w1_sml_tsf$emmean <- summ_mkv_fli_w1_sml_tsf$mkv_fli
summ_mkv_fli_w1_sml_tsf$lower.CL <- summ_mkv_fli_w1_sml_tsf$mkv_fli - summ_mkv_fli_w1_sml_tsf$ci
summ_mkv_fli_w1_sml_tsf$upper.CL <- summ_mkv_fli_w1_sml_tsf$mkv_fli + summ_mkv_fli_w1_sml_tsf$ci
summ_mkv_fli_w1_sml_tsf$.group <- " "
summ_mkv_fli_w2_sml_tsf$emmean <- summ_mkv_fli_w2_sml_tsf$mkv_fli
summ_mkv_fli_w2_sml_tsf$lower.CL <- summ_mkv_fli_w2_sml_tsf$mkv_fli - summ_mkv_fli_w2_sml_tsf$ci
summ_mkv_fli_w2_sml_tsf$upper.CL <- summ_mkv_fli_w2_sml_tsf$mkv_fli + summ_mkv_fli_w2_sml_tsf$ci
summ_mkv_fli_w2_sml_tsf$.group <- " "
summ_mkv_fli_w3_sml_tsf$emmean <- summ_mkv_fli_w3_sml_tsf$mkv_fli
summ_mkv_fli_w3_sml_tsf$lower.CL <- summ_mkv_fli_w3_sml_tsf$mkv_fli - summ_mkv_fli_w3_sml_tsf$ci
summ_mkv_fli_w3_sml_tsf$upper.CL <- summ_mkv_fli_w3_sml_tsf$mkv_fli + summ_mkv_fli_w3_sml_tsf$ci
summ_mkv_fli_w3_sml_tsf$.group <- " "
summ_mkv_fli_w4_sml_tsf$emmean <- summ_mkv_fli_w4_sml_tsf$mkv_fli
summ_mkv_fli_w4_sml_tsf$lower.CL <- summ_mkv_fli_w4_sml_tsf$mkv_fli - summ_mkv_fli_w4_sml_tsf$ci
summ_mkv_fli_w4_sml_tsf$upper.CL <- summ_mkv_fli_w4_sml_tsf$mkv_fli + summ_mkv_fli_w4_sml_tsf$ci
summ_mkv_fli_w4_sml_tsf$.group <- " "

common_cols_mkv_fli_sml_tsf <- intersect(colnames(emm_mkv_fli_sml_tsf), colnames(summ_mkv_fli_w1_sml_tsf))
summ_mkv_fli_all_sml_tsf <- rbind(#subset(summ_mkv_fli_w1_sml_tsf, select = common_cols_mkv_fli_sml_tsf),
                                  subset(summ_mkv_fli_w2_sml_tsf, select = common_cols_mkv_fli_sml_tsf),
                                  subset(summ_mkv_fli_w3_sml_tsf, select = common_cols_mkv_fli_sml_tsf),
                                  subset(summ_mkv_fli_w4_sml_tsf, select = common_cols_mkv_fli_sml_tsf),
                                  subset(emm_mkv_fli_sml_tsf, select = common_cols_mkv_fli_sml_tsf))
summ_mkv_fli_all_sml_tsf$weather_set <- as.factor(summ_mkv_fli_all_sml_tsf$weather_set)

plot_mkv_fli_sml_tsf <- ggplot(data = summ_mkv_fli_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 10000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_mkv_fli_sml_tsf

########################
emm_mkv_fli_lrg_her <- emmeans(glmm_mkv_fli_lrg_w5_1, "treatment", type = "response")
emm_mkv_fli_lrg_her         <- multcomp::cld(emm_mkv_fli_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_her$emmean    <- emm_mkv_fli_lrg_her$emmean * 1000
emm_mkv_fli_lrg_her$lower.CL  <- emm_mkv_fli_lrg_her$lower.CL * 1000
emm_mkv_fli_lrg_her$upper.CL  <- emm_mkv_fli_lrg_her$upper.CL * 1000
emm_mkv_fli_lrg_her$weather_set <- 5
emm_mkv_fli_lrg_her$.group <- trimws(emm_mkv_fli_lrg_her$.group, which = c("both"))

summ_mkv_fli_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "mkv_fli", groupvars = c("treatment"))
summ_mkv_fli_w1_lrg_her$weather_set <- 1
summ_mkv_fli_w2_lrg_her$weather_set <- 2
summ_mkv_fli_w3_lrg_her$weather_set <- 3
summ_mkv_fli_w4_lrg_her$weather_set <- 4
summ_mkv_fli_w1_lrg_her$emmean <- summ_mkv_fli_w1_lrg_her$mkv_fli
summ_mkv_fli_w1_lrg_her$lower.CL <- summ_mkv_fli_w1_lrg_her$mkv_fli - summ_mkv_fli_w1_lrg_her$ci
summ_mkv_fli_w1_lrg_her$upper.CL <- summ_mkv_fli_w1_lrg_her$mkv_fli + summ_mkv_fli_w1_lrg_her$ci
summ_mkv_fli_w1_lrg_her$.group <- " "
summ_mkv_fli_w2_lrg_her$emmean <- summ_mkv_fli_w2_lrg_her$mkv_fli
summ_mkv_fli_w2_lrg_her$lower.CL <- summ_mkv_fli_w2_lrg_her$mkv_fli - summ_mkv_fli_w2_lrg_her$ci
summ_mkv_fli_w2_lrg_her$upper.CL <- summ_mkv_fli_w2_lrg_her$mkv_fli + summ_mkv_fli_w2_lrg_her$ci
summ_mkv_fli_w2_lrg_her$.group <- " "
summ_mkv_fli_w3_lrg_her$emmean <- summ_mkv_fli_w3_lrg_her$mkv_fli
summ_mkv_fli_w3_lrg_her$lower.CL <- summ_mkv_fli_w3_lrg_her$mkv_fli - summ_mkv_fli_w3_lrg_her$ci
summ_mkv_fli_w3_lrg_her$upper.CL <- summ_mkv_fli_w3_lrg_her$mkv_fli + summ_mkv_fli_w3_lrg_her$ci
summ_mkv_fli_w3_lrg_her$.group <- " "
summ_mkv_fli_w4_lrg_her$emmean <- summ_mkv_fli_w4_lrg_her$mkv_fli
summ_mkv_fli_w4_lrg_her$lower.CL <- summ_mkv_fli_w4_lrg_her$mkv_fli - summ_mkv_fli_w4_lrg_her$ci
summ_mkv_fli_w4_lrg_her$upper.CL <- summ_mkv_fli_w4_lrg_her$mkv_fli + summ_mkv_fli_w4_lrg_her$ci
summ_mkv_fli_w4_lrg_her$.group <- " "

common_cols_mkv_fli_lrg_her <- intersect(colnames(emm_mkv_fli_lrg_her), colnames(summ_mkv_fli_w1_lrg_her))
summ_mkv_fli_all_lrg_her <- rbind(#subset(summ_mkv_fli_w1_lrg_her, select = common_cols_mkv_fli_lrg_her),
                                  subset(summ_mkv_fli_w2_lrg_her, select = common_cols_mkv_fli_lrg_her),
                                  subset(summ_mkv_fli_w3_lrg_her, select = common_cols_mkv_fli_lrg_her),
                                  subset(summ_mkv_fli_w4_lrg_her, select = common_cols_mkv_fli_lrg_her),
                                  subset(emm_mkv_fli_lrg_her, select = common_cols_mkv_fli_lrg_her))
summ_mkv_fli_all_lrg_her$weather_set <- as.factor(summ_mkv_fli_all_lrg_her$weather_set)

plot_mkv_fli_lrg_her <- ggplot(data = summ_mkv_fli_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 10000) +
  labs(colour = "weather set") +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_mkv_fli_lrg_her
########################
emm_mkv_fli_lrg_tsf <- emmeans(glmm_mkv_fli_lrg_w5_1, "tsf_factor", type = "response")
emm_mkv_fli_lrg_tsf <- multcomp::cld(emm_mkv_fli_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_tsf$emmean    <- emm_mkv_fli_lrg_tsf$emmean * 1000
emm_mkv_fli_lrg_tsf$lower.CL  <- emm_mkv_fli_lrg_tsf$lower.CL * 1000
emm_mkv_fli_lrg_tsf$upper.CL  <- emm_mkv_fli_lrg_tsf$upper.CL * 1000
emm_mkv_fli_lrg_tsf$weather_set <- 5
emm_mkv_fli_lrg_tsf$.group <- trimws(emm_mkv_fli_lrg_tsf$.group, which = c("both"))

summ_mkv_fli_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "mkv_fli", groupvars = c("tsf_factor"))
summ_mkv_fli_w1_lrg_tsf$weather_set <- 1
summ_mkv_fli_w2_lrg_tsf$weather_set <- 2
summ_mkv_fli_w3_lrg_tsf$weather_set <- 3
summ_mkv_fli_w4_lrg_tsf$weather_set <- 4
summ_mkv_fli_w1_lrg_tsf$emmean <- summ_mkv_fli_w1_lrg_tsf$mkv_fli
summ_mkv_fli_w1_lrg_tsf$lower.CL <- summ_mkv_fli_w1_lrg_tsf$mkv_fli - summ_mkv_fli_w1_lrg_tsf$ci
summ_mkv_fli_w1_lrg_tsf$upper.CL <- summ_mkv_fli_w1_lrg_tsf$mkv_fli + summ_mkv_fli_w1_lrg_tsf$ci
summ_mkv_fli_w1_lrg_tsf$.group <- " "
summ_mkv_fli_w2_lrg_tsf$emmean <- summ_mkv_fli_w2_lrg_tsf$mkv_fli
summ_mkv_fli_w2_lrg_tsf$lower.CL <- summ_mkv_fli_w2_lrg_tsf$mkv_fli - summ_mkv_fli_w2_lrg_tsf$ci
summ_mkv_fli_w2_lrg_tsf$upper.CL <- summ_mkv_fli_w2_lrg_tsf$mkv_fli + summ_mkv_fli_w2_lrg_tsf$ci
summ_mkv_fli_w2_lrg_tsf$.group <- " "
summ_mkv_fli_w3_lrg_tsf$emmean <- summ_mkv_fli_w3_lrg_tsf$mkv_fli
summ_mkv_fli_w3_lrg_tsf$lower.CL <- summ_mkv_fli_w3_lrg_tsf$mkv_fli - summ_mkv_fli_w3_lrg_tsf$ci
summ_mkv_fli_w3_lrg_tsf$upper.CL <- summ_mkv_fli_w3_lrg_tsf$mkv_fli + summ_mkv_fli_w3_lrg_tsf$ci
summ_mkv_fli_w3_lrg_tsf$.group <- " "
summ_mkv_fli_w4_lrg_tsf$emmean <- summ_mkv_fli_w4_lrg_tsf$mkv_fli
summ_mkv_fli_w4_lrg_tsf$lower.CL <- summ_mkv_fli_w4_lrg_tsf$mkv_fli - summ_mkv_fli_w4_lrg_tsf$ci
summ_mkv_fli_w4_lrg_tsf$upper.CL <- summ_mkv_fli_w4_lrg_tsf$mkv_fli + summ_mkv_fli_w4_lrg_tsf$ci
summ_mkv_fli_w4_lrg_tsf$.group <- " "

common_cols_mkv_fli_lrg_tsf <- intersect(colnames(emm_mkv_fli_lrg_tsf), colnames(summ_mkv_fli_w1_lrg_tsf))
summ_mkv_fli_all_lrg_tsf <- rbind(#subset(summ_mkv_fli_w1_lrg_tsf, select = common_cols_mkv_fli_lrg_tsf),
                                  subset(summ_mkv_fli_w2_lrg_tsf, select = common_cols_mkv_fli_lrg_tsf),
                                  subset(summ_mkv_fli_w3_lrg_tsf, select = common_cols_mkv_fli_lrg_tsf),
                                  subset(summ_mkv_fli_w4_lrg_tsf, select = common_cols_mkv_fli_lrg_tsf),
                                  subset(emm_mkv_fli_lrg_tsf, select = common_cols_mkv_fli_lrg_tsf))
summ_mkv_fli_all_lrg_tsf$weather_set <- as.factor(summ_mkv_fli_all_lrg_tsf$weather_set)

plot_mkv_fli_lrg_tsf <- ggplot(data = summ_mkv_fli_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 10000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed') 
plot_mkv_fli_lrg_tsf


####################################################################################################################
####################VES mk2 FIN PLOTS############################
####################################################

#checking significance 
#mk5
#her
emm_mkv_fht_sml_her_w2 <- emmeans(glmm_mkv_fht_sml_w2_1, "treatment", type = "response")
emm_mkv_fht_sml_her_w2 <- multcomp::cld(emm_mkv_fht_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_her_w2 #open higher

emm_mkv_fht_sml_her_w3 <- emmeans(glmm_mkv_fht_sml_w3_1, "treatment", type = "response")
emm_mkv_fht_sml_her_w3 <- multcomp::cld(emm_mkv_fht_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_her_w3 #sopen higher

emm_mkv_fht_sml_her_w4 <- emmeans(glmm_mkv_fht_sml_w4_1, "treatment", type = "response")
emm_mkv_fht_sml_her_w4 <- multcomp::cld(emm_mkv_fht_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_her_w4 #open higher

emm_mkv_fht_sml_her_w5 <- emmeans(glmm_mkv_fht_sml_w5_1, "treatment", type = "response")
emm_mkv_fht_sml_her_w5 <- multcomp::cld(emm_mkv_fht_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_her_w5 #open higher

emm_mkv_ros_sml_her_w2 <- emmeans(glmm_mkv_ros_sml_w2_1, "treatment", type = "response")
emm_mkv_ros_sml_her_w2 <- multcomp::cld(emm_mkv_ros_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_her_w2 #open higher

emm_mkv_ros_sml_her_w3 <- emmeans(glmm_mkv_ros_sml_w3_1, "treatment", type = "response")
emm_mkv_ros_sml_her_w3 <- multcomp::cld(emm_mkv_ros_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_her_w3 #open higher

emm_mkv_ros_sml_her_w4 <- emmeans(glmm_mkv_ros_sml_w4_1, "treatment", type = "response")
emm_mkv_ros_sml_her_w4 <- multcomp::cld(emm_mkv_ros_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_her_w4 #open higher

emm_mkv_ros_sml_her_w5 <- emmeans(glmm_mkv_ros_sml_w5_1, "treatment", type = "response")
emm_mkv_ros_sml_her_w5 <- multcomp::cld(emm_mkv_ros_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_her_w5 #open higher

emm_mkv_fli_sml_her_w2 <- emmeans(glmm_mkv_fli_sml_w2_1, "treatment", type = "response")
emm_mkv_fli_sml_her_w2 <- multcomp::cld(emm_mkv_fli_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_her_w2 #open higher

emm_mkv_fli_sml_her_w3 <- emmeans(glmm_mkv_fli_sml_w3_1, "treatment", type = "response")
emm_mkv_fli_sml_her_w3 <- multcomp::cld(emm_mkv_fli_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_her_w3 #open higher

emm_mkv_fli_sml_her_w4 <- emmeans(glmm_mkv_fli_sml_w4_1, "treatment", type = "response")
emm_mkv_fli_sml_her_w4 <- multcomp::cld(emm_mkv_fli_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_her_w4 #open higher

emm_mkv_fli_sml_her_w5 <- emmeans(glmm_mkv_fli_sml_w5_1, "treatment", type = "response")
emm_mkv_fli_sml_her_w5 <- multcomp::cld(emm_mkv_fli_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_her_w5 #open higher

#tsf
emm_mkv_fht_sml_tsf_w2 <- emmeans(glmm_mkv_fht_sml_w2_1, "tsf_factor", type = "response")
emm_mkv_fht_sml_tsf_w2 <- multcomp::cld(emm_mkv_fht_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_tsf_w2 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_fht_sml_tsf_w3 <- emmeans(glmm_mkv_fht_sml_w3_1, "tsf_factor", type = "response")
emm_mkv_fht_sml_tsf_w3 <- multcomp::cld(emm_mkv_fht_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_fht_sml_tsf_w4 <- emmeans(glmm_mkv_fht_sml_w4_1, "tsf_factor", type = "response")
emm_mkv_fht_sml_tsf_w4 <- multcomp::cld(emm_mkv_fht_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_sml_tsf_w4 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_ros_sml_tsf_w2 <- emmeans(glmm_mkv_ros_sml_w2_1, "tsf_factor", type = "response")
emm_mkv_ros_sml_tsf_w2 <- multcomp::cld(emm_mkv_ros_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_tsf_w2 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_ros_sml_tsf_w3 <- emmeans(glmm_mkv_ros_sml_w3_1, "tsf_factor", type = "response")
emm_mkv_ros_sml_tsf_w3 <- multcomp::cld(emm_mkv_ros_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_ros_sml_tsf_w4 <- emmeans(glmm_mkv_ros_sml_w4_1, "tsf_factor", type = "response")
emm_mkv_ros_sml_tsf_w4 <- multcomp::cld(emm_mkv_ros_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_sml_tsf_w4 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_fli_sml_tsf_w2 <- emmeans(glmm_mkv_fli_sml_w2_1, "tsf_factor", type = "response")
emm_mkv_fli_sml_tsf_w2 <- multcomp::cld(emm_mkv_fli_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_tsf_w2 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_mkv_fli_sml_tsf_w3 <- emmeans(glmm_mkv_fli_sml_w3_1, "tsf_factor", type = "response")
emm_mkv_fli_sml_tsf_w3 <- multcomp::cld(emm_mkv_fli_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_tsf_w3 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_mkv_fli_sml_tsf_w4 <- emmeans(glmm_mkv_fli_sml_w4_1, "tsf_factor", type = "response")
emm_mkv_fli_sml_tsf_w4 <- multcomp::cld(emm_mkv_fli_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_sml_tsf_w4 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

#########LARGE PLOTS
#her
emm_mkv_fht_lrg_her_w2 <- emmeans(glmm_mkv_fht_lrg_w2_1, "treatment", type = "response")
emm_mkv_fht_lrg_her_w2 <- multcomp::cld(emm_mkv_fht_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_her_w2 #NA

emm_mkv_fht_lrg_her_w3 <- emmeans(glmm_mkv_fht_lrg_w3_1, "treatment", type = "response")
emm_mkv_fht_lrg_her_w3 <- multcomp::cld(emm_mkv_fht_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_her_w3 #NA

emm_mkv_fht_lrg_her_w4 <- emmeans(glmm_mkv_fht_lrg_w4_1, "treatment", type = "response")
emm_mkv_fht_lrg_her_w4 <- multcomp::cld(emm_mkv_fht_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_her_w4 #NA

emm_mkv_ros_lrg_her_w2 <- emmeans(glmm_mkv_ros_lrg_w2_1, "treatment", type = "response")
emm_mkv_ros_lrg_her_w2 <- multcomp::cld(emm_mkv_ros_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_her_w2 #nothing

emm_mkv_ros_lrg_her_w3 <- emmeans(glmm_mkv_ros_lrg_w3_1, "treatment", type = "response")
emm_mkv_ros_lrg_her_w3 <- multcomp::cld(emm_mkv_ros_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_her_w3 #nothing

emm_mkv_ros_lrg_her_w4 <- emmeans(glmm_mkv_ros_lrg_w4_1, "treatment", type = "response")
emm_mkv_ros_lrg_her_w4 <- multcomp::cld(emm_mkv_ros_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_her_w4 #nothing

emm_mkv_fli_lrg_her_w2 <- emmeans(glmm_mkv_fli_lrg_w2_1, "treatment", type = "response")
emm_mkv_fli_lrg_her_w2 <- multcomp::cld(emm_mkv_fli_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_her_w2 #nothing

emm_mkv_fli_lrg_her_w3 <- emmeans(glmm_mkv_fli_lrg_w3_1, "treatment", type = "response")
emm_mkv_fli_lrg_her_w3 <- multcomp::cld(emm_mkv_fli_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_her_w3 #nothing

emm_mkv_fli_lrg_her_w4 <- emmeans(glmm_mkv_fli_lrg_w4_1, "treatment", type = "response")
emm_mkv_fli_lrg_her_w4 <- multcomp::cld(emm_mkv_fli_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_her_w4 #nothing

#tsf
emm_mkv_fht_lrg_tsf_w2 <- emmeans(glmm_mkv_fht_lrg_w2_1, "tsf_factor", type = "response")
emm_mkv_fht_lrg_tsf_w2 <- multcomp::cld(emm_mkv_fht_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_tsf_w2 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_fht_lrg_tsf_w3 <- emmeans(glmm_mkv_fht_lrg_w3_1, "tsf_factor", type = "response")
emm_mkv_fht_lrg_tsf_w3 <- multcomp::cld(emm_mkv_fht_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_fht_lrg_tsf_w4 <- emmeans(glmm_mkv_fht_lrg_w4_1, "tsf_factor", type = "response")
emm_mkv_fht_lrg_tsf_w4 <- multcomp::cld(emm_mkv_fht_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fht_lrg_tsf_w4 #sig higher in 2 & 3 (b) compared to 1

emm_mkv_ros_lrg_tsf_w2 <- emmeans(glmm_mkv_ros_lrg_w2_1, "tsf_factor", type = "response")
emm_mkv_ros_lrg_tsf_w2 <- multcomp::cld(emm_mkv_ros_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_tsf_w2 #sig higher in 3 (c) then 2 (b) then 1 (a)

emm_mkv_ros_lrg_tsf_w3 <- emmeans(glmm_mkv_ros_lrg_w3_1, "tsf_factor", type = "response")
emm_mkv_ros_lrg_tsf_w3 <- multcomp::cld(emm_mkv_ros_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_tsf_w3 #sig higher in 3 (c) then 2 (b) then 1 (a)

emm_mkv_ros_lrg_tsf_w4 <- emmeans(glmm_mkv_ros_lrg_w4_1, "tsf_factor", type = "response")
emm_mkv_ros_lrg_tsf_w4 <- multcomp::cld(emm_mkv_ros_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_ros_lrg_tsf_w4 ##sig higher in 3 (c) then 2 (b) then 1 (a)

emm_mkv_fli_lrg_tsf_w2 <- emmeans(glmm_mkv_fli_lrg_w2_1, "tsf_factor", type = "response")
emm_mkv_fli_lrg_tsf_w2 <- multcomp::cld(emm_mkv_fli_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_tsf_w2 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_mkv_fli_lrg_tsf_w3 <- emmeans(glmm_mkv_fli_lrg_w3_1, "tsf_factor", type = "response")
emm_mkv_fli_lrg_tsf_w3 <- multcomp::cld(emm_mkv_fli_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_tsf_w3 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_mkv_fli_lrg_tsf_w4 <- emmeans(glmm_mkv_fli_lrg_w4_1, "tsf_factor", type = "response")
emm_mkv_fli_lrg_tsf_w4 <- multcomp::cld(emm_mkv_fli_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_mkv_fli_lrg_tsf_w4 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)


#ves mk2
#########SMALL PLOTS
#her
emm_ves2_fht_sml_her_w2 <- emmeans(glmm_ves2_fht_sml_w2_1, "treatment", type = "response")
emm_ves2_fht_sml_her_w2 <- multcomp::cld(emm_ves2_fht_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_her_w2 #sig higher in closed (b) partial (ab)

emm_ves2_fht_sml_her_w3 <- emmeans(glmm_ves2_fht_sml_w3_1, "treatment", type = "response")
emm_ves2_fht_sml_her_w3 <- multcomp::cld(emm_ves2_fht_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_her_w3 #sig higher in closed (b) partial (ab)

emm_ves2_fht_sml_her_w4 <- emmeans(glmm_ves2_fht_sml_w4_1, "treatment", type = "response")
emm_ves2_fht_sml_her_w4 <- multcomp::cld(emm_ves2_fht_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_her_w4 #sig higher in closed (b) partial (ab)

emm_ves2_fht_sml_her_w5 <- emmeans(glmm_ves2_fht_sml_w5_1, "treatment", type = "response")
emm_ves2_fht_sml_her_w5 <- multcomp::cld(emm_ves2_fht_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_her_w5 #sig higher in closed (b) partial (ab)

emm_ves2_ros_sml_her_w2 <- emmeans(glmm_ves2_ros_sml_w2_1, "treatment", type = "response")
emm_ves2_ros_sml_her_w2 <- multcomp::cld(emm_ves2_ros_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_her_w2 #nothing

emm_ves2_ros_sml_her_w3 <- emmeans(glmm_ves2_ros_sml_w3_1, "treatment", type = "response")
emm_ves2_ros_sml_her_w3 <- multcomp::cld(emm_ves2_ros_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_her_w3 #nothing

emm_ves2_ros_sml_her_w4 <- emmeans(glmm_ves2_ros_sml_w4_1, "treatment", type = "response")
emm_ves2_ros_sml_her_w4 <- multcomp::cld(emm_ves2_ros_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_her_w4 #nothing

emm_ves2_ros_sml_her_w5 <- emmeans(glmm_ves2_ros_sml_w5_1, "treatment", type = "response")
emm_ves2_ros_sml_her_w5 <- multcomp::cld(emm_ves2_ros_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_her_w5 #nothing

emm_ves2_fli_sml_her_w2 <- emmeans(glmm_ves2_fli_sml_w2_1, "treatment", type = "response")
emm_ves2_fli_sml_her_w2 <- multcomp::cld(emm_ves2_fli_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_her_w2 #nothing

emm_ves2_fli_sml_her_w3 <- emmeans(glmm_ves2_fli_sml_w3_1, "treatment", type = "response")
emm_ves2_fli_sml_her_w3 <- multcomp::cld(emm_ves2_fli_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_her_w3 #open is higher (b)

emm_ves2_fli_sml_her_w4 <- emmeans(glmm_ves2_fli_sml_w4_1, "treatment", type = "response")
emm_ves2_fli_sml_her_w4 <- multcomp::cld(emm_ves2_fli_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_her_w4 #nothing

emm_ves2_fli_sml_her_w5 <- emmeans(glmm_ves2_fli_sml_w5_1, "treatment", type = "response")
emm_ves2_fli_sml_her_w5 <- multcomp::cld(emm_ves2_fli_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_her_w5 #nothing

#tsf
emm_ves2_fht_sml_tsf_w2 <- emmeans(glmm_ves2_fht_sml_w2_1, "tsf_factor", type = "response")
emm_ves2_fht_sml_tsf_w2 <- multcomp::cld(emm_ves2_fht_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_tsf_w2 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_fht_sml_tsf_w3 <- emmeans(glmm_ves2_fht_sml_w3_1, "tsf_factor", type = "response")
emm_ves2_fht_sml_tsf_w3 <- multcomp::cld(emm_ves2_fht_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_fht_sml_tsf_w4 <- emmeans(glmm_ves2_fht_sml_w4_1, "tsf_factor", type = "response")
emm_ves2_fht_sml_tsf_w4 <- multcomp::cld(emm_ves2_fht_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_tsf_w4 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_ros_sml_tsf_w2 <- emmeans(glmm_ves2_ros_sml_w2_1, "tsf_factor", type = "response")
emm_ves2_ros_sml_tsf_w2 <- multcomp::cld(emm_ves2_ros_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_tsf_w2 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_ros_sml_tsf_w3 <- emmeans(glmm_ves2_ros_sml_w3_1, "tsf_factor", type = "response")
emm_ves2_ros_sml_tsf_w3 <- multcomp::cld(emm_ves2_ros_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_ros_sml_tsf_w4 <- emmeans(glmm_ves2_ros_sml_w4_1, "tsf_factor", type = "response")
emm_ves2_ros_sml_tsf_w4 <- multcomp::cld(emm_ves2_ros_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_tsf_w4 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_fli_sml_tsf_w2 <- emmeans(glmm_ves2_fli_sml_w2_1, "tsf_factor", type = "response")
emm_ves2_fli_sml_tsf_w2 <- multcomp::cld(emm_ves2_fli_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_tsf_w2 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_ves2_fli_sml_tsf_w3 <- emmeans(glmm_ves2_fli_sml_w3_1, "tsf_factor", type = "response")
emm_ves2_fli_sml_tsf_w3 <- multcomp::cld(emm_ves2_fli_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_tsf_w3 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_ves2_fli_sml_tsf_w4 <- emmeans(glmm_ves2_fli_sml_w4_1, "tsf_factor", type = "response")
emm_ves2_fli_sml_tsf_w4 <- multcomp::cld(emm_ves2_fli_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_tsf_w4 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

#########LARGE PLOTS
#her
emm_ves2_fht_lrg_her_w2 <- emmeans(glmm_ves2_fht_lrg_w2_1, "treatment", type = "response")
emm_ves2_fht_lrg_her_w2 <- multcomp::cld(emm_ves2_fht_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_her_w2 #NA

emm_ves2_fht_lrg_her_w3 <- emmeans(glmm_ves2_fht_lrg_w3_1, "treatment", type = "response")
emm_ves2_fht_lrg_her_w3 <- multcomp::cld(emm_ves2_fht_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_her_w3 #NA

emm_ves2_fht_lrg_her_w4 <- emmeans(glmm_ves2_fht_lrg_w4_1, "treatment", type = "response")
emm_ves2_fht_lrg_her_w4 <- multcomp::cld(emm_ves2_fht_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_her_w4 #NA

emm_ves2_ros_lrg_her_w2 <- emmeans(glmm_ves2_ros_lrg_w2_1, "treatment", type = "response")
emm_ves2_ros_lrg_her_w2 <- multcomp::cld(emm_ves2_ros_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_her_w2 #nothing

emm_ves2_ros_lrg_her_w3 <- emmeans(glmm_ves2_ros_lrg_w3_1, "treatment", type = "response")
emm_ves2_ros_lrg_her_w3 <- multcomp::cld(emm_ves2_ros_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_her_w3 #nothing

emm_ves2_ros_lrg_her_w4 <- emmeans(glmm_ves2_ros_lrg_w4_1, "treatment", type = "response")
emm_ves2_ros_lrg_her_w4 <- multcomp::cld(emm_ves2_ros_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_her_w4 #nothing

emm_ves2_fli_lrg_her_w2 <- emmeans(glmm_ves2_fli_lrg_w2_1, "treatment", type = "response")
emm_ves2_fli_lrg_her_w2 <- multcomp::cld(emm_ves2_fli_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_her_w2 #nothing

emm_ves2_fli_lrg_her_w3 <- emmeans(glmm_ves2_fli_lrg_w3_1, "treatment", type = "response")
emm_ves2_fli_lrg_her_w3 <- multcomp::cld(emm_ves2_fli_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_her_w3 #nothing

emm_ves2_fli_lrg_her_w4 <- emmeans(glmm_ves2_fli_lrg_w4_1, "treatment", type = "response")
emm_ves2_fli_lrg_her_w4 <- multcomp::cld(emm_ves2_fli_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_her_w4 #nothing

#tsf
emm_ves2_fht_lrg_tsf_w2 <- emmeans(glmm_ves2_fht_lrg_w2_1, "tsf_factor", type = "response")
emm_ves2_fht_lrg_tsf_w2 <- multcomp::cld(emm_ves2_fht_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_tsf_w2 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_fht_lrg_tsf_w3 <- emmeans(glmm_ves2_fht_lrg_w3_1, "tsf_factor", type = "response")
emm_ves2_fht_lrg_tsf_w3 <- multcomp::cld(emm_ves2_fht_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_fht_lrg_tsf_w4 <- emmeans(glmm_ves2_fht_lrg_w4_1, "tsf_factor", type = "response")
emm_ves2_fht_lrg_tsf_w4 <- multcomp::cld(emm_ves2_fht_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_tsf_w4 #sig higher in 2 & 3 (b) compared to 1

emm_ves2_ros_lrg_tsf_w2 <- emmeans(glmm_ves2_ros_lrg_w2_1, "tsf_factor", type = "response")
emm_ves2_ros_lrg_tsf_w2 <- multcomp::cld(emm_ves2_ros_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_tsf_w2 #sig higher in 3 (c) then 2 (b) then 1 (a)

emm_ves2_ros_lrg_tsf_w3 <- emmeans(glmm_ves2_ros_lrg_w3_1, "tsf_factor", type = "response")
emm_ves2_ros_lrg_tsf_w3 <- multcomp::cld(emm_ves2_ros_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_tsf_w3 #sig higher in 3 (c) then 2 (b) then 1 (a)

emm_ves2_ros_lrg_tsf_w4 <- emmeans(glmm_ves2_ros_lrg_w4_1, "tsf_factor", type = "response")
emm_ves2_ros_lrg_tsf_w4 <- multcomp::cld(emm_ves2_ros_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_tsf_w4 ##sig higher in 3 (c) then 2 (b) then 1 (a)

emm_ves2_fli_lrg_tsf_w2 <- emmeans(glmm_ves2_fli_lrg_w2_1, "tsf_factor", type = "response")
emm_ves2_fli_lrg_tsf_w2 <- multcomp::cld(emm_ves2_fli_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_tsf_w2 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_ves2_fli_lrg_tsf_w3 <- emmeans(glmm_ves2_fli_lrg_w3_1, "tsf_factor", type = "response")
emm_ves2_fli_lrg_tsf_w3 <- multcomp::cld(emm_ves2_fli_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_tsf_w3 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

emm_ves2_fli_lrg_tsf_w4 <- emmeans(glmm_ves2_fli_lrg_w4_1, "tsf_factor", type = "response")
emm_ves2_fli_lrg_tsf_w4 <- multcomp::cld(emm_ves2_fli_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_tsf_w4 #sig higher in 3 (c) compared to 2 (b) compared to 1 (a)

#checking significance 
###########ZYL
#########SMALL PLOTS
#her
emm_zyl_fht_sml_her_w2 <- emmeans(glmm_zyl_fht_sml_w2_1, "treatment", type = "response")
emm_zyl_fht_sml_her_w2 <- multcomp::cld(emm_zyl_fht_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_her_w2 #NA

emm_zyl_fht_sml_her_w3 <- emmeans(glmm_zyl_fht_sml_w3_1, "treatment", type = "response")
emm_zyl_fht_sml_her_w3 <- multcomp::cld(emm_zyl_fht_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_her_w3 #NA

emm_zyl_fht_sml_her_w4 <- emmeans(glmm_zyl_fht_sml_w4_1, "treatment", type = "response")
emm_zyl_fht_sml_her_w4 <- multcomp::cld(emm_zyl_fht_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_her_w4 #NA

emm_zyl_fht_sml_her_w5 <- emmeans(glmm_zyl_fht_sml_w5_1, "treatment", type = "response")
emm_zyl_fht_sml_her_w5 <- multcomp::cld(emm_zyl_fht_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_her_w5 #NA

emm_zyl_ros_sml_her_w2 <- emmeans(glmm_zyl_ros_sml_w2_1, "treatment", type = "response")
emm_zyl_ros_sml_her_w2 <- multcomp::cld(emm_zyl_ros_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_her_w2 #nothing

emm_zyl_ros_sml_her_w3 <- emmeans(glmm_zyl_ros_sml_w3_1, "treatment", type = "response")
emm_zyl_ros_sml_her_w3 <- multcomp::cld(emm_zyl_ros_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_her_w3 #nothing

emm_zyl_ros_sml_her_w4 <- emmeans(glmm_zyl_ros_sml_w4_1, "treatment", type = "response")
emm_zyl_ros_sml_her_w4 <- multcomp::cld(emm_zyl_ros_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_her_w4 #nothing

emm_zyl_ros_sml_her_w5 <- emmeans(glmm_zyl_ros_sml_w5_1, "treatment", type = "response")
emm_zyl_ros_sml_her_w5 <- multcomp::cld(emm_zyl_ros_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_her_w5 #nothing

emm_zyl_fli_sml_her_w2 <- emmeans(glmm_zyl_fli_sml_w2_1, "treatment", type = "response")
emm_zyl_fli_sml_her_w2 <- multcomp::cld(emm_zyl_fli_sml_her_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_her_w2 #open higher (b)

emm_zyl_fli_sml_her_w3 <- emmeans(glmm_zyl_fli_sml_w3_1, "treatment", type = "response")
emm_zyl_fli_sml_her_w3 <- multcomp::cld(emm_zyl_fli_sml_her_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_her_w3 #NA

emm_zyl_fli_sml_her_w4 <- emmeans(glmm_zyl_fli_sml_w4_1, "treatment", type = "response")
emm_zyl_fli_sml_her_w4 <- multcomp::cld(emm_zyl_fli_sml_her_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_her_w4 #nothing

emm_zyl_fli_sml_her_w5 <- emmeans(glmm_zyl_fli_sml_w5_1, "treatment", type = "response")
emm_zyl_fli_sml_her_w5 <- multcomp::cld(emm_zyl_fli_sml_her_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_her_w5 #higher in open (b) partial (ab) closed (a)

#tsf
emm_zyl_fht_sml_tsf_w2 <- emmeans(glmm_zyl_fht_sml_w2_1, "tsf_factor", type = "response")
emm_zyl_fht_sml_tsf_w2 <- multcomp::cld(emm_zyl_fht_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_tsf_w2 #sig higher in 1??(b), 2 (ab), 3 (b) 

emm_zyl_fht_sml_tsf_w3 <- emmeans(glmm_zyl_fht_sml_w3_1, "tsf_factor", type = "response")
emm_zyl_fht_sml_tsf_w3 <- multcomp::cld(emm_zyl_fht_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_tsf_w3 #NA

emm_zyl_fht_sml_tsf_w4 <- emmeans(glmm_zyl_fht_sml_w4_1, "tsf_factor", type = "response")
emm_zyl_fht_sml_tsf_w4 <- multcomp::cld(emm_zyl_fht_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_tsf_w4 #NA

emm_zyl_fht_sml_tsf_w5 <- emmeans(glmm_zyl_fht_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_fht_sml_tsf_w5 <- multcomp::cld(emm_zyl_fht_sml_tsf_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_tsf_w5 # higher in 1 (b) 2 (ab) 3 (a)

emm_zyl_ros_sml_tsf_w2 <- emmeans(glmm_zyl_ros_sml_w2_1, "tsf_factor", type = "response")
emm_zyl_ros_sml_tsf_w2 <- multcomp::cld(emm_zyl_ros_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_tsf_w2 #sig higher in 2??? (c), 3 (b) compared to 1 (a)

emm_zyl_ros_sml_tsf_w3 <- emmeans(glmm_zyl_ros_sml_w3_1, "tsf_factor", type = "response")
emm_zyl_ros_sml_tsf_w3 <- multcomp::cld(emm_zyl_ros_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_tsf_w3 #sig higher in 2 & 3 (b) compared to 1

emm_zyl_ros_sml_tsf_w4 <- emmeans(glmm_zyl_ros_sml_w4_1, "tsf_factor", type = "response")
emm_zyl_ros_sml_tsf_w4 <- multcomp::cld(emm_zyl_ros_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_tsf_w4 #sig higher in 2??? (c), 3 (b) compared to 1 (a)

emm_zyl_fli_sml_tsf_w2 <- emmeans(glmm_zyl_fli_sml_w2_1, "tsf_factor", type = "response")
emm_zyl_fli_sml_tsf_w2 <- multcomp::cld(emm_zyl_fli_sml_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_tsf_w2 #sig higher in 3 & 2 (b) compared to 1 (a)

emm_zyl_fli_sml_tsf_w3 <- emmeans(glmm_zyl_fli_sml_w3_1, "tsf_factor", type = "response")
emm_zyl_fli_sml_tsf_w3 <- multcomp::cld(emm_zyl_fli_sml_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_tsf_w3 #sig higher in 3 & 2 (b) compared to 1 (a)

emm_zyl_fli_sml_tsf_w4 <- emmeans(glmm_zyl_fli_sml_w4_1, "tsf_factor", type = "response")
emm_zyl_fli_sml_tsf_w4 <- multcomp::cld(emm_zyl_fli_sml_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_tsf_w4 #sig higher in 3 & 2 (b) compared to 1 (a)

#########LARGE PLOTS
#her
emm_zyl_fht_lrg_her_w2 <- emmeans(glmm_zyl_fht_lrg_w2_1, "treatment", type = "response")
emm_zyl_fht_lrg_her_w2 <- multcomp::cld(emm_zyl_fht_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_her_w2 #NA

emm_zyl_fht_lrg_her_w3 <- emmeans(glmm_zyl_fht_lrg_w3_1, "treatment", type = "response")
emm_zyl_fht_lrg_her_w3 <- multcomp::cld(emm_zyl_fht_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_her_w3 #NA

emm_zyl_fht_lrg_her_w4 <- emmeans(glmm_zyl_fht_lrg_w4_1, "treatment", type = "response")
emm_zyl_fht_lrg_her_w4 <- multcomp::cld(emm_zyl_fht_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_her_w4 #NA

emm_zyl_ros_lrg_her_w2 <- emmeans(glmm_zyl_ros_lrg_w2_1, "treatment", type = "response")
emm_zyl_ros_lrg_her_w2 <- multcomp::cld(emm_zyl_ros_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_her_w2 #higher in closed (b)

emm_zyl_ros_lrg_her_w3 <- emmeans(glmm_zyl_ros_lrg_w3_1, "treatment", type = "response")
emm_zyl_ros_lrg_her_w3 <- multcomp::cld(emm_zyl_ros_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_her_w3 #higher in closed (b)

emm_zyl_ros_lrg_her_w4 <- emmeans(glmm_zyl_ros_lrg_w4_1, "treatment", type = "response")
emm_zyl_ros_lrg_her_w4 <- multcomp::cld(emm_zyl_ros_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_her_w4 #higher in closed (b)

emm_zyl_ros_lrg_her_w5 <- emmeans(glmm_zyl_ros_lrg_w5_1, "treatment", type = "response")
emm_zyl_ros_lrg_her_w5 <- multcomp::cld(emm_zyl_ros_lrg_her_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_her_w5 #higher in closed (b)

emm_zyl_fli_lrg_her_w2 <- emmeans(glmm_zyl_fli_lrg_w2_1, "treatment", type = "response")
emm_zyl_fli_lrg_her_w2 <- multcomp::cld(emm_zyl_fli_lrg_her_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_her_w2 #higher in closed (b)

emm_zyl_fli_lrg_her_w3 <- emmeans(glmm_zyl_fli_lrg_w3_1, "treatment", type = "response")
emm_zyl_fli_lrg_her_w3 <- multcomp::cld(emm_zyl_fli_lrg_her_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_her_w3 #higher in closed (b)

emm_zyl_fli_lrg_her_w4 <- emmeans(glmm_zyl_fli_lrg_w4_1, "treatment", type = "response")
emm_zyl_fli_lrg_her_w4 <- multcomp::cld(emm_zyl_fli_lrg_her_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_her_w4 #higher in closed (b)

emm_zyl_fli_lrg_her_w5 <- emmeans(glmm_zyl_fli_lrg_w5_1, "treatment", type = "response")
emm_zyl_fli_lrg_her_w5 <- multcomp::cld(emm_zyl_fli_lrg_her_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_her_w5 #higher in closed (b)

#tsf
emm_zyl_fht_lrg_tsf_w2 <- emmeans(glmm_zyl_fht_lrg_w2_1, "tsf_factor", type = "response")
emm_zyl_fht_lrg_tsf_w2 <- multcomp::cld(emm_zyl_fht_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_tsf_w2 #NA

emm_zyl_fht_lrg_tsf_w3 <- emmeans(glmm_zyl_fht_lrg_w3_1, "tsf_factor", type = "response")
emm_zyl_fht_lrg_tsf_w3 <- multcomp::cld(emm_zyl_fht_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_tsf_w3 #NA

emm_zyl_fht_lrg_tsf_w4 <- emmeans(glmm_zyl_fht_lrg_w4_1, "tsf_factor", type = "response")
emm_zyl_fht_lrg_tsf_w4 <- multcomp::cld(emm_zyl_fht_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_tsf_w4 #NA

emm_zyl_ros_lrg_tsf_w2 <- emmeans(glmm_zyl_ros_lrg_w2_1, "tsf_factor", type = "response")
emm_zyl_ros_lrg_tsf_w2 <- multcomp::cld(emm_zyl_ros_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_tsf_w2 #sig higher in 2?? (b) then 3 (ab) then 1 (a)

emm_zyl_ros_lrg_tsf_w3 <- emmeans(glmm_zyl_ros_lrg_w3_1, "tsf_factor", type = "response")
emm_zyl_ros_lrg_tsf_w3 <- multcomp::cld(emm_zyl_ros_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_tsf_w3 #NA

emm_zyl_ros_lrg_tsf_w4 <- emmeans(glmm_zyl_ros_lrg_w4_1, "tsf_factor", type = "response")
emm_zyl_ros_lrg_tsf_w4 <- multcomp::cld(emm_zyl_ros_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_tsf_w4 #sig higher in 2?? (b) then 3 (ab) then 1 (a)

emm_zyl_ros_lrg_tsf_w5 <- emmeans(glmm_zyl_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_ros_lrg_tsf_w5 <- multcomp::cld(emm_zyl_ros_lrg_tsf_w5, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_tsf_w5 #2 higher (b) than 1 & 3 (a)

emm_zyl_fli_lrg_tsf_w2 <- emmeans(glmm_zyl_fli_lrg_w2_1, "tsf_factor", type = "response")
emm_zyl_fli_lrg_tsf_w2 <- multcomp::cld(emm_zyl_fli_lrg_tsf_w2, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_tsf_w2 #sig higher in 3 & 2 (b) compared to 1 (a)

emm_zyl_fli_lrg_tsf_w3 <- emmeans(glmm_zyl_fli_lrg_w3_1, "tsf_factor", type = "response")
emm_zyl_fli_lrg_tsf_w3 <- multcomp::cld(emm_zyl_fli_lrg_tsf_w3, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_tsf_w3 #sig higher in 3 & 2 (b) compared to 1 (a)

emm_zyl_fli_lrg_tsf_w4 <- emmeans(glmm_zyl_fli_lrg_w4_1, "tsf_factor", type = "response")
emm_zyl_fli_lrg_tsf_w4 <- multcomp::cld(emm_zyl_fli_lrg_tsf_w4, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_tsf_w4 #sig higher in 3 & 2 (b) compared to 1 (a)

####################################################
####################################################
emm_ves2_fht_sml_her <- emmeans(glmm_ves2_fht_sml_w5_1, "treatment", type = "response")
emm_ves2_fht_sml_her <- multcomp::cld(emm_ves2_fht_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_her$weather_set <- 5
emm_ves2_fht_sml_her$.group <- trimws(emm_ves2_fht_sml_her$.group, which = c("both"))

summ_ves2_fht_w1_sml_her <- summarySE(values_sml_w1, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w2_sml_her <- summarySE(values_sml_w2, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w3_sml_her <- summarySE(values_sml_w3, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w4_sml_her <- summarySE(values_sml_w4, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w1_sml_her$weather_set <- 1
summ_ves2_fht_w2_sml_her$weather_set <- 2
summ_ves2_fht_w3_sml_her$weather_set <- 3
summ_ves2_fht_w4_sml_her$weather_set <- 4
summ_ves2_fht_w1_sml_her$emmean <- summ_ves2_fht_w1_sml_her$ves2_fht
summ_ves2_fht_w1_sml_her$lower.CL <- summ_ves2_fht_w1_sml_her$ves2_fht - summ_ves2_fht_w1_sml_her$ci
summ_ves2_fht_w1_sml_her$upper.CL <- summ_ves2_fht_w1_sml_her$ves2_fht + summ_ves2_fht_w1_sml_her$ci
summ_ves2_fht_w1_sml_her$.group <- " "
summ_ves2_fht_w2_sml_her$emmean <- summ_ves2_fht_w2_sml_her$ves2_fht
summ_ves2_fht_w2_sml_her$lower.CL <- summ_ves2_fht_w2_sml_her$ves2_fht - summ_ves2_fht_w2_sml_her$ci
summ_ves2_fht_w2_sml_her$upper.CL <- summ_ves2_fht_w2_sml_her$ves2_fht + summ_ves2_fht_w2_sml_her$ci
summ_ves2_fht_w2_sml_her$.group <- " "
summ_ves2_fht_w3_sml_her$emmean <- summ_ves2_fht_w3_sml_her$ves2_fht
summ_ves2_fht_w3_sml_her$lower.CL <- summ_ves2_fht_w3_sml_her$ves2_fht - summ_ves2_fht_w3_sml_her$ci
summ_ves2_fht_w3_sml_her$upper.CL <- summ_ves2_fht_w3_sml_her$ves2_fht + summ_ves2_fht_w3_sml_her$ci
summ_ves2_fht_w3_sml_her$.group <- " "
summ_ves2_fht_w4_sml_her$emmean <- summ_ves2_fht_w4_sml_her$ves2_fht
summ_ves2_fht_w4_sml_her$lower.CL <- summ_ves2_fht_w4_sml_her$ves2_fht - summ_ves2_fht_w4_sml_her$ci
summ_ves2_fht_w4_sml_her$upper.CL <- summ_ves2_fht_w4_sml_her$ves2_fht + summ_ves2_fht_w4_sml_her$ci
summ_ves2_fht_w4_sml_her$.group <- " "

common_cols_ves2_fht_sml_her <- intersect(colnames(emm_ves2_fht_sml_her), colnames(summ_ves2_fht_w1_sml_her))
summ_ves2_fht_all_sml_her <- rbind(#subset(summ_ves2_fht_w1_sml_her, select = common_cols_ves2_fht_sml_her),
                                  subset(summ_ves2_fht_w2_sml_her, select = common_cols_ves2_fht_sml_her),
                                  subset(summ_ves2_fht_w3_sml_her, select = common_cols_ves2_fht_sml_her),
                                  subset(summ_ves2_fht_w4_sml_her, select = common_cols_ves2_fht_sml_her),
                                  subset(emm_ves2_fht_sml_her, select = common_cols_ves2_fht_sml_her))
summ_ves2_fht_all_sml_her$weather_set <- as.factor(summ_ves2_fht_all_sml_her$weather_set)

plot_ves2_fht_sml_her <- ggplot(data = summ_ves2_fht_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Flame height (m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_ves2_fht_sml_her

########################
emm_ves2_fht_sml_tsf <- emmeans(glmm_ves2_fht_sml_w5_1, "tsf_factor", type = "response")
emm_ves2_fht_sml_tsf <- multcomp::cld(emm_ves2_fht_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_sml_tsf$weather_set <- 5
emm_ves2_fht_sml_tsf$.group <- trimws(emm_ves2_fht_sml_tsf$.group, which = c("both"))

summ_ves2_fht_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w1_sml_tsf$weather_set <- 1
summ_ves2_fht_w2_sml_tsf$weather_set <- 2
summ_ves2_fht_w3_sml_tsf$weather_set <- 3
summ_ves2_fht_w4_sml_tsf$weather_set <- 4
summ_ves2_fht_w1_sml_tsf$emmean <- summ_ves2_fht_w1_sml_tsf$ves2_fht
summ_ves2_fht_w1_sml_tsf$lower.CL <- summ_ves2_fht_w1_sml_tsf$ves2_fht - summ_ves2_fht_w1_sml_tsf$ci
summ_ves2_fht_w1_sml_tsf$upper.CL <- summ_ves2_fht_w1_sml_tsf$ves2_fht + summ_ves2_fht_w1_sml_tsf$ci
summ_ves2_fht_w1_sml_tsf$.group <- " "
summ_ves2_fht_w2_sml_tsf$emmean <- summ_ves2_fht_w2_sml_tsf$ves2_fht
summ_ves2_fht_w2_sml_tsf$lower.CL <- summ_ves2_fht_w2_sml_tsf$ves2_fht - summ_ves2_fht_w2_sml_tsf$ci
summ_ves2_fht_w2_sml_tsf$upper.CL <- summ_ves2_fht_w2_sml_tsf$ves2_fht + summ_ves2_fht_w2_sml_tsf$ci
summ_ves2_fht_w2_sml_tsf$.group <- " "
summ_ves2_fht_w3_sml_tsf$emmean <- summ_ves2_fht_w3_sml_tsf$ves2_fht
summ_ves2_fht_w3_sml_tsf$lower.CL <- summ_ves2_fht_w3_sml_tsf$ves2_fht - summ_ves2_fht_w3_sml_tsf$ci
summ_ves2_fht_w3_sml_tsf$upper.CL <- summ_ves2_fht_w3_sml_tsf$ves2_fht + summ_ves2_fht_w3_sml_tsf$ci
summ_ves2_fht_w3_sml_tsf$.group <- " "
summ_ves2_fht_w4_sml_tsf$emmean <- summ_ves2_fht_w4_sml_tsf$ves2_fht
summ_ves2_fht_w4_sml_tsf$lower.CL <- summ_ves2_fht_w4_sml_tsf$ves2_fht - summ_ves2_fht_w4_sml_tsf$ci
summ_ves2_fht_w4_sml_tsf$upper.CL <- summ_ves2_fht_w4_sml_tsf$ves2_fht + summ_ves2_fht_w4_sml_tsf$ci
summ_ves2_fht_w4_sml_tsf$.group <- " "

common_cols_ves2_fht_sml_tsf <- intersect(colnames(emm_ves2_fht_sml_tsf), colnames(summ_ves2_fht_w1_sml_tsf))
summ_ves2_fht_all_sml_tsf <- rbind(#subset(summ_ves2_fht_w1_sml_tsf, select = common_cols_ves2_fht_sml_tsf),
                                  subset(summ_ves2_fht_w2_sml_tsf, select = common_cols_ves2_fht_sml_tsf),
                                  subset(summ_ves2_fht_w3_sml_tsf, select = common_cols_ves2_fht_sml_tsf),
                                  subset(summ_ves2_fht_w4_sml_tsf, select = common_cols_ves2_fht_sml_tsf),
                                  subset(emm_ves2_fht_sml_tsf, select = common_cols_ves2_fht_sml_tsf))
summ_ves2_fht_all_sml_tsf$weather_set <- as.factor(summ_ves2_fht_all_sml_tsf$weather_set)

plot_ves2_fht_sml_tsf <- ggplot(data = summ_ves2_fht_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 15) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') #+
  # geom_text(aes(3.3, 1, label = "(i)")) +
  # geom_text(aes(3.3, 2.5, label = "(ii)")) +
  # geom_text(aes(3.3, 6, label = "(iii)")) +
  # geom_text(aes(3.3, 11, label = "(iv)"))
plot_ves2_fht_sml_tsf

########################
emm_ves2_fht_lrg_her <- emmeans(glmm_ves2_fht_lrg_w5_1, "treatment", type = "response")
emm_ves2_fht_lrg_her <- multcomp::cld(emm_ves2_fht_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_her$weather_set <- 5
emm_ves2_fht_lrg_her$.group <- trimws(emm_ves2_fht_lrg_her$.group, which = c("both"))

summ_ves2_fht_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "ves2_fht", groupvars = c("treatment"))
summ_ves2_fht_w1_lrg_her$weather_set <- 1
summ_ves2_fht_w2_lrg_her$weather_set <- 2
summ_ves2_fht_w3_lrg_her$weather_set <- 3
summ_ves2_fht_w4_lrg_her$weather_set <- 4
summ_ves2_fht_w1_lrg_her$emmean <- summ_ves2_fht_w1_lrg_her$ves2_fht
summ_ves2_fht_w1_lrg_her$lower.CL <- summ_ves2_fht_w1_lrg_her$ves2_fht - summ_ves2_fht_w1_lrg_her$ci
summ_ves2_fht_w1_lrg_her$upper.CL <- summ_ves2_fht_w1_lrg_her$ves2_fht + summ_ves2_fht_w1_lrg_her$ci
summ_ves2_fht_w1_lrg_her$.group <- " "
summ_ves2_fht_w2_lrg_her$emmean <- summ_ves2_fht_w2_lrg_her$ves2_fht
summ_ves2_fht_w2_lrg_her$lower.CL <- summ_ves2_fht_w2_lrg_her$ves2_fht - summ_ves2_fht_w2_lrg_her$ci
summ_ves2_fht_w2_lrg_her$upper.CL <- summ_ves2_fht_w2_lrg_her$ves2_fht + summ_ves2_fht_w2_lrg_her$ci
summ_ves2_fht_w2_lrg_her$.group <- " "
summ_ves2_fht_w3_lrg_her$emmean <- summ_ves2_fht_w3_lrg_her$ves2_fht
summ_ves2_fht_w3_lrg_her$lower.CL <- summ_ves2_fht_w3_lrg_her$ves2_fht - summ_ves2_fht_w3_lrg_her$ci
summ_ves2_fht_w3_lrg_her$upper.CL <- summ_ves2_fht_w3_lrg_her$ves2_fht + summ_ves2_fht_w3_lrg_her$ci
summ_ves2_fht_w3_lrg_her$.group <- " "
summ_ves2_fht_w4_lrg_her$emmean <- summ_ves2_fht_w4_lrg_her$ves2_fht
summ_ves2_fht_w4_lrg_her$lower.CL <- summ_ves2_fht_w4_lrg_her$ves2_fht - summ_ves2_fht_w4_lrg_her$ci
summ_ves2_fht_w4_lrg_her$upper.CL <- summ_ves2_fht_w4_lrg_her$ves2_fht + summ_ves2_fht_w4_lrg_her$ci
summ_ves2_fht_w4_lrg_her$.group <- " "

common_cols_ves2_fht_lrg_her <- intersect(colnames(emm_ves2_fht_lrg_her), colnames(summ_ves2_fht_w1_lrg_her))
summ_ves2_fht_all_lrg_her <- rbind(#subset(summ_ves2_fht_w1_lrg_her, select = common_cols_ves2_fht_lrg_her),
                                  subset(summ_ves2_fht_w2_lrg_her, select = common_cols_ves2_fht_lrg_her),
                                  subset(summ_ves2_fht_w3_lrg_her, select = common_cols_ves2_fht_lrg_her),
                                  subset(summ_ves2_fht_w4_lrg_her, select = common_cols_ves2_fht_lrg_her),
                                  subset(emm_ves2_fht_lrg_her, select = common_cols_ves2_fht_lrg_her))
summ_ves2_fht_all_lrg_her$weather_set <- as.factor(summ_ves2_fht_all_lrg_her$weather_set)

plot_ves2_fht_lrg_her <- ggplot(data = summ_ves2_fht_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Flame height (m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  #theme(legend.justification = c(1, 1), axis.title.y = element_text(margin = margin(b = 70))) +
  #labs(colour = "weather set") +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 16) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_ves2_fht_lrg_her

########################
emm_ves2_fht_lrg_tsf <- emmeans(glmm_ves2_fht_lrg_w5_1, "tsf_factor", type = "response")
emm_ves2_fht_lrg_tsf <- multcomp::cld(emm_ves2_fht_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fht_lrg_tsf$weather_set <- 5
emm_ves2_fht_lrg_tsf$.group <- trimws(emm_ves2_fht_lrg_tsf$.group, which = c("both"))

summ_ves2_fht_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "ves2_fht", groupvars = c("tsf_factor"))
summ_ves2_fht_w1_lrg_tsf$weather_set <- 1
summ_ves2_fht_w2_lrg_tsf$weather_set <- 2
summ_ves2_fht_w3_lrg_tsf$weather_set <- 3
summ_ves2_fht_w4_lrg_tsf$weather_set <- 4
summ_ves2_fht_w1_lrg_tsf$emmean <- summ_ves2_fht_w1_lrg_tsf$ves2_fht
summ_ves2_fht_w1_lrg_tsf$lower.CL <- summ_ves2_fht_w1_lrg_tsf$ves2_fht - summ_ves2_fht_w1_lrg_tsf$ci
summ_ves2_fht_w1_lrg_tsf$upper.CL <- summ_ves2_fht_w1_lrg_tsf$ves2_fht + summ_ves2_fht_w1_lrg_tsf$ci
summ_ves2_fht_w1_lrg_tsf$.group <- " "
summ_ves2_fht_w2_lrg_tsf$emmean <- summ_ves2_fht_w2_lrg_tsf$ves2_fht
summ_ves2_fht_w2_lrg_tsf$lower.CL <- summ_ves2_fht_w2_lrg_tsf$ves2_fht - summ_ves2_fht_w2_lrg_tsf$ci
summ_ves2_fht_w2_lrg_tsf$upper.CL <- summ_ves2_fht_w2_lrg_tsf$ves2_fht + summ_ves2_fht_w2_lrg_tsf$ci
summ_ves2_fht_w2_lrg_tsf$.group <- " "
summ_ves2_fht_w3_lrg_tsf$emmean <- summ_ves2_fht_w3_lrg_tsf$ves2_fht
summ_ves2_fht_w3_lrg_tsf$lower.CL <- summ_ves2_fht_w3_lrg_tsf$ves2_fht - summ_ves2_fht_w3_lrg_tsf$ci
summ_ves2_fht_w3_lrg_tsf$upper.CL <- summ_ves2_fht_w3_lrg_tsf$ves2_fht + summ_ves2_fht_w3_lrg_tsf$ci
summ_ves2_fht_w3_lrg_tsf$.group <- " "
summ_ves2_fht_w4_lrg_tsf$emmean <- summ_ves2_fht_w4_lrg_tsf$ves2_fht
summ_ves2_fht_w4_lrg_tsf$lower.CL <- summ_ves2_fht_w4_lrg_tsf$ves2_fht - summ_ves2_fht_w4_lrg_tsf$ci
summ_ves2_fht_w4_lrg_tsf$upper.CL <- summ_ves2_fht_w4_lrg_tsf$ves2_fht + summ_ves2_fht_w4_lrg_tsf$ci
summ_ves2_fht_w4_lrg_tsf$.group <- " "

common_cols_ves2_fht_lrg_tsf <- intersect(colnames(emm_ves2_fht_lrg_tsf), colnames(summ_ves2_fht_w1_lrg_tsf))
summ_ves2_fht_all_lrg_tsf <- rbind(#subset(summ_ves2_fht_w1_lrg_tsf, select = common_cols_ves2_fht_lrg_tsf),
                                  subset(summ_ves2_fht_w2_lrg_tsf, select = common_cols_ves2_fht_lrg_tsf),
                                  subset(summ_ves2_fht_w3_lrg_tsf, select = common_cols_ves2_fht_lrg_tsf),
                                  subset(summ_ves2_fht_w4_lrg_tsf, select = common_cols_ves2_fht_lrg_tsf),
                                  subset(emm_ves2_fht_lrg_tsf, select = common_cols_ves2_fht_lrg_tsf))
summ_ves2_fht_all_lrg_tsf$weather_set <- as.factor(summ_ves2_fht_all_lrg_tsf$weather_set)

plot_ves2_fht_lrg_tsf <- ggplot(data = summ_ves2_fht_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 16) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') #+
  # geom_text(aes(3.3, 1, label = "(i)")) +
  # geom_text(aes(3.3, 2.5, label = "(ii)")) +
  # geom_text(aes(3.3, 6, label = "(iii)")) +
  # geom_text(aes(3.3, 11, label = "(iv)"))
plot_ves2_fht_lrg_tsf

####################################################################################################
###########ves ROS
install.packages("ggbreak")
library(ggbreak)
emm_ves2_ros_sml_her <- emmeans(glmm_ves2_ros_sml_w5_1, "treatment", type = "response")
emm_ves2_ros_sml_her <- multcomp::cld(emm_ves2_ros_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_her$weather_set <- 5
emm_ves2_ros_sml_her$.group <- trimws(emm_ves2_ros_sml_her$.group, which = c("both"))

summ_ves2_ros_w1_sml_her <- summarySE(values_sml_w1, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w2_sml_her <- summarySE(values_sml_w2, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w3_sml_her <- summarySE(values_sml_w3, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w4_sml_her <- summarySE(values_sml_w4, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w1_sml_her$weather_set <- 1
summ_ves2_ros_w2_sml_her$weather_set <- 2
summ_ves2_ros_w3_sml_her$weather_set <- 3
summ_ves2_ros_w4_sml_her$weather_set <- 4
summ_ves2_ros_w1_sml_her$emmean <- summ_ves2_ros_w1_sml_her$ves2_ros
summ_ves2_ros_w1_sml_her$lower.CL <- summ_ves2_ros_w1_sml_her$ves2_ros - summ_ves2_ros_w1_sml_her$ci
summ_ves2_ros_w1_sml_her$upper.CL <- summ_ves2_ros_w1_sml_her$ves2_ros + summ_ves2_ros_w1_sml_her$ci
summ_ves2_ros_w1_sml_her$.group <- " "
summ_ves2_ros_w2_sml_her$emmean <- summ_ves2_ros_w2_sml_her$ves2_ros
summ_ves2_ros_w2_sml_her$lower.CL <- summ_ves2_ros_w2_sml_her$ves2_ros - summ_ves2_ros_w2_sml_her$ci
summ_ves2_ros_w2_sml_her$upper.CL <- summ_ves2_ros_w2_sml_her$ves2_ros + summ_ves2_ros_w2_sml_her$ci
summ_ves2_ros_w2_sml_her$.group <- " "
summ_ves2_ros_w3_sml_her$emmean <- summ_ves2_ros_w3_sml_her$ves2_ros
summ_ves2_ros_w3_sml_her$lower.CL <- summ_ves2_ros_w3_sml_her$ves2_ros - summ_ves2_ros_w3_sml_her$ci
summ_ves2_ros_w3_sml_her$upper.CL <- summ_ves2_ros_w3_sml_her$ves2_ros + summ_ves2_ros_w3_sml_her$ci
summ_ves2_ros_w3_sml_her$.group <- " "
summ_ves2_ros_w4_sml_her$emmean <- summ_ves2_ros_w4_sml_her$ves2_ros
summ_ves2_ros_w4_sml_her$lower.CL <- summ_ves2_ros_w4_sml_her$ves2_ros - summ_ves2_ros_w4_sml_her$ci
summ_ves2_ros_w4_sml_her$upper.CL <- summ_ves2_ros_w4_sml_her$ves2_ros + summ_ves2_ros_w4_sml_her$ci
summ_ves2_ros_w4_sml_her$.group <- " "

common_cols_ves2_ros_sml_her <- intersect(colnames(emm_ves2_ros_sml_her), colnames(summ_ves2_ros_w1_sml_her))
summ_ves2_ros_all_sml_her <- rbind(#subset(summ_ves2_ros_w1_sml_her, select = common_cols_ves2_ros_sml_her),
                                  subset(summ_ves2_ros_w2_sml_her, select = common_cols_ves2_ros_sml_her),
                                  subset(summ_ves2_ros_w3_sml_her, select = common_cols_ves2_ros_sml_her),
                                  subset(summ_ves2_ros_w4_sml_her, select = common_cols_ves2_ros_sml_her),
                                  subset(emm_ves2_ros_sml_her, select = common_cols_ves2_ros_sml_her))
summ_ves2_ros_all_sml_her$weather_set <- as.factor(summ_ves2_ros_all_sml_her$weather_set)
view(summ_ves2_ros_all_sml_her)
plot_ves2_ros_sml_her <- ggplot(data = summ_ves2_ros_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 3) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.2), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') +
  scale_y_break(c(.8, 2.9))
plot_ves2_ros_sml_her
########################
emm_ves2_ros_sml_tsf <- emmeans(glmm_ves2_ros_sml_w5_1, "tsf_factor", type = "response")
emm_ves2_ros_sml_tsf <- multcomp::cld(emm_ves2_ros_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_sml_tsf$weather_set <- 5
emm_ves2_ros_sml_tsf$.group <- trimws(emm_ves2_ros_sml_tsf$.group, which = c("both"))

summ_ves2_ros_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w1_sml_tsf$weather_set <- 1
summ_ves2_ros_w2_sml_tsf$weather_set <- 2
summ_ves2_ros_w3_sml_tsf$weather_set <- 3
summ_ves2_ros_w4_sml_tsf$weather_set <- 4
summ_ves2_ros_w1_sml_tsf$emmean <- summ_ves2_ros_w1_sml_tsf$ves2_ros
summ_ves2_ros_w1_sml_tsf$lower.CL <- summ_ves2_ros_w1_sml_tsf$ves2_ros - summ_ves2_ros_w1_sml_tsf$ci
summ_ves2_ros_w1_sml_tsf$upper.CL <- summ_ves2_ros_w1_sml_tsf$ves2_ros + summ_ves2_ros_w1_sml_tsf$ci
summ_ves2_ros_w1_sml_tsf$.group <- " "
summ_ves2_ros_w2_sml_tsf$emmean <- summ_ves2_ros_w2_sml_tsf$ves2_ros
summ_ves2_ros_w2_sml_tsf$lower.CL <- summ_ves2_ros_w2_sml_tsf$ves2_ros - summ_ves2_ros_w2_sml_tsf$ci
summ_ves2_ros_w2_sml_tsf$upper.CL <- summ_ves2_ros_w2_sml_tsf$ves2_ros + summ_ves2_ros_w2_sml_tsf$ci
summ_ves2_ros_w2_sml_tsf$.group <- " "
summ_ves2_ros_w3_sml_tsf$emmean <- summ_ves2_ros_w3_sml_tsf$ves2_ros
summ_ves2_ros_w3_sml_tsf$lower.CL <- summ_ves2_ros_w3_sml_tsf$ves2_ros - summ_ves2_ros_w3_sml_tsf$ci
summ_ves2_ros_w3_sml_tsf$upper.CL <- summ_ves2_ros_w3_sml_tsf$ves2_ros + summ_ves2_ros_w3_sml_tsf$ci
summ_ves2_ros_w3_sml_tsf$.group <- " "
summ_ves2_ros_w4_sml_tsf$emmean <- summ_ves2_ros_w4_sml_tsf$ves2_ros
summ_ves2_ros_w4_sml_tsf$lower.CL <- summ_ves2_ros_w4_sml_tsf$ves2_ros - summ_ves2_ros_w4_sml_tsf$ci
summ_ves2_ros_w4_sml_tsf$upper.CL <- summ_ves2_ros_w4_sml_tsf$ves2_ros + summ_ves2_ros_w4_sml_tsf$ci
summ_ves2_ros_w4_sml_tsf$.group <- " "

common_cols_ves2_ros_sml_tsf <- intersect(colnames(emm_ves2_ros_sml_tsf), colnames(summ_ves2_ros_w1_sml_tsf))
summ_ves2_ros_all_sml_tsf <- rbind(#subset(summ_ves2_ros_w1_sml_tsf, select = common_cols_ves2_ros_sml_tsf),
                                  subset(summ_ves2_ros_w2_sml_tsf, select = common_cols_ves2_ros_sml_tsf),
                                  subset(summ_ves2_ros_w3_sml_tsf, select = common_cols_ves2_ros_sml_tsf),
                                  subset(summ_ves2_ros_w4_sml_tsf, select = common_cols_ves2_ros_sml_tsf),
                                  subset(emm_ves2_ros_sml_tsf, select = common_cols_ves2_ros_sml_tsf))
summ_ves2_ros_all_sml_tsf$weather_set <- as.factor(summ_ves2_ros_all_sml_tsf$weather_set)

plot_ves2_ros_sml_tsf <- ggplot(data = summ_ves2_ros_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 3) +  
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.2), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') +
  scale_y_break(c(.8, 2.9))
plot_ves2_ros_sml_tsf

########################
emm_ves2_ros_lrg_her <- emmeans(glmm_ves2_ros_lrg_w5_1, "treatment", type = "response")
emm_ves2_ros_lrg_her <- multcomp::cld(emm_ves2_ros_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_her$weather_set <- 5
emm_ves2_ros_lrg_her$.group <- trimws(emm_ves2_ros_lrg_her$.group, which = c("both"))

summ_ves2_ros_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "ves2_ros", groupvars = c("treatment"))
summ_ves2_ros_w1_lrg_her$weather_set <- 1
summ_ves2_ros_w2_lrg_her$weather_set <- 2
summ_ves2_ros_w3_lrg_her$weather_set <- 3
summ_ves2_ros_w4_lrg_her$weather_set <- 4
summ_ves2_ros_w1_lrg_her$emmean <- summ_ves2_ros_w1_lrg_her$ves2_ros
summ_ves2_ros_w1_lrg_her$lower.CL <- summ_ves2_ros_w1_lrg_her$ves2_ros - summ_ves2_ros_w1_lrg_her$ci
summ_ves2_ros_w1_lrg_her$upper.CL <- summ_ves2_ros_w1_lrg_her$ves2_ros + summ_ves2_ros_w1_lrg_her$ci
summ_ves2_ros_w1_lrg_her$.group <- " "
summ_ves2_ros_w2_lrg_her$emmean <- summ_ves2_ros_w2_lrg_her$ves2_ros
summ_ves2_ros_w2_lrg_her$lower.CL <- summ_ves2_ros_w2_lrg_her$ves2_ros - summ_ves2_ros_w2_lrg_her$ci
summ_ves2_ros_w2_lrg_her$upper.CL <- summ_ves2_ros_w2_lrg_her$ves2_ros + summ_ves2_ros_w2_lrg_her$ci
summ_ves2_ros_w2_lrg_her$.group <- " "
summ_ves2_ros_w3_lrg_her$emmean <- summ_ves2_ros_w3_lrg_her$ves2_ros
summ_ves2_ros_w3_lrg_her$lower.CL <- summ_ves2_ros_w3_lrg_her$ves2_ros - summ_ves2_ros_w3_lrg_her$ci
summ_ves2_ros_w3_lrg_her$upper.CL <- summ_ves2_ros_w3_lrg_her$ves2_ros + summ_ves2_ros_w3_lrg_her$ci
summ_ves2_ros_w3_lrg_her$.group <- " "
summ_ves2_ros_w4_lrg_her$emmean <- summ_ves2_ros_w4_lrg_her$ves2_ros
summ_ves2_ros_w4_lrg_her$lower.CL <- summ_ves2_ros_w4_lrg_her$ves2_ros - summ_ves2_ros_w4_lrg_her$ci
summ_ves2_ros_w4_lrg_her$upper.CL <- summ_ves2_ros_w4_lrg_her$ves2_ros + summ_ves2_ros_w4_lrg_her$ci
summ_ves2_ros_w4_lrg_her$.group <- " "

common_cols_ves2_ros_lrg_her <- intersect(colnames(emm_ves2_ros_lrg_her), colnames(summ_ves2_ros_w1_lrg_her))
summ_ves2_ros_all_lrg_her <- rbind(#subset(summ_ves2_ros_w1_lrg_her, select = common_cols_ves2_ros_lrg_her),
                                  subset(summ_ves2_ros_w2_lrg_her, select = common_cols_ves2_ros_lrg_her),
                                  subset(summ_ves2_ros_w3_lrg_her, select = common_cols_ves2_ros_lrg_her),
                                  subset(summ_ves2_ros_w4_lrg_her, select = common_cols_ves2_ros_lrg_her),
                                  subset(emm_ves2_ros_lrg_her, select = common_cols_ves2_ros_lrg_her))
summ_ves2_ros_all_lrg_her$weather_set <- as.factor(summ_ves2_ros_all_lrg_her$weather_set)

plot_ves2_ros_lrg_her <- ggplot(data = summ_ves2_ros_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 3) +  
  labs(colour = "weather set") +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.2), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') +
  scale_y_break(c(.8, 2.9))
plot_ves2_ros_lrg_her
########################
emm_ves2_ros_lrg_tsf <- emmeans(glmm_ves2_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_ves2_ros_lrg_tsf <- multcomp::cld(emm_ves2_ros_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_ros_lrg_tsf$weather_set <- 5
emm_ves2_ros_lrg_tsf$.group <- trimws(emm_ves2_ros_lrg_tsf$.group, which = c("both"))

summ_ves2_ros_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "ves2_ros", groupvars = c("tsf_factor"))
summ_ves2_ros_w1_lrg_tsf$weather_set <- 1
summ_ves2_ros_w2_lrg_tsf$weather_set <- 2
summ_ves2_ros_w3_lrg_tsf$weather_set <- 3
summ_ves2_ros_w4_lrg_tsf$weather_set <- 4
summ_ves2_ros_w1_lrg_tsf$emmean <- summ_ves2_ros_w1_lrg_tsf$ves2_ros
summ_ves2_ros_w1_lrg_tsf$lower.CL <- summ_ves2_ros_w1_lrg_tsf$ves2_ros - summ_ves2_ros_w1_lrg_tsf$ci
summ_ves2_ros_w1_lrg_tsf$upper.CL <- summ_ves2_ros_w1_lrg_tsf$ves2_ros + summ_ves2_ros_w1_lrg_tsf$ci
summ_ves2_ros_w1_lrg_tsf$.group <- " "
summ_ves2_ros_w2_lrg_tsf$emmean <- summ_ves2_ros_w2_lrg_tsf$ves2_ros
summ_ves2_ros_w2_lrg_tsf$lower.CL <- summ_ves2_ros_w2_lrg_tsf$ves2_ros - summ_ves2_ros_w2_lrg_tsf$ci
summ_ves2_ros_w2_lrg_tsf$upper.CL <- summ_ves2_ros_w2_lrg_tsf$ves2_ros + summ_ves2_ros_w2_lrg_tsf$ci
summ_ves2_ros_w2_lrg_tsf$.group <- " "
summ_ves2_ros_w3_lrg_tsf$emmean <- summ_ves2_ros_w3_lrg_tsf$ves2_ros
summ_ves2_ros_w3_lrg_tsf$lower.CL <- summ_ves2_ros_w3_lrg_tsf$ves2_ros - summ_ves2_ros_w3_lrg_tsf$ci
summ_ves2_ros_w3_lrg_tsf$upper.CL <- summ_ves2_ros_w3_lrg_tsf$ves2_ros + summ_ves2_ros_w3_lrg_tsf$ci
summ_ves2_ros_w3_lrg_tsf$.group <- " "
summ_ves2_ros_w4_lrg_tsf$emmean <- summ_ves2_ros_w4_lrg_tsf$ves2_ros
summ_ves2_ros_w4_lrg_tsf$lower.CL <- summ_ves2_ros_w4_lrg_tsf$ves2_ros - summ_ves2_ros_w4_lrg_tsf$ci
summ_ves2_ros_w4_lrg_tsf$upper.CL <- summ_ves2_ros_w4_lrg_tsf$ves2_ros + summ_ves2_ros_w4_lrg_tsf$ci
summ_ves2_ros_w4_lrg_tsf$.group <- " "

common_cols_ves2_ros_lrg_tsf <- intersect(colnames(emm_ves2_ros_lrg_tsf), colnames(summ_ves2_ros_w1_lrg_tsf))
summ_ves2_ros_all_lrg_tsf <- rbind(#subset(summ_ves2_ros_w1_lrg_tsf, select = common_cols_ves2_ros_lrg_tsf),
                                  subset(summ_ves2_ros_w2_lrg_tsf, select = common_cols_ves2_ros_lrg_tsf),
                                  subset(summ_ves2_ros_w3_lrg_tsf, select = common_cols_ves2_ros_lrg_tsf),
                                  subset(summ_ves2_ros_w4_lrg_tsf, select = common_cols_ves2_ros_lrg_tsf),
                                  subset(emm_ves2_ros_lrg_tsf, select = common_cols_ves2_ros_lrg_tsf))
summ_ves2_ros_all_lrg_tsf$weather_set <- as.factor(summ_ves2_ros_all_lrg_tsf$weather_set)

plot_ves2_ros_lrg_tsf <- ggplot(data = summ_ves2_ros_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 3) +  
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.2), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') +
  scale_y_break(c(.8, 2.9))
plot_ves2_ros_lrg_tsf

####################################################################################################
########################ves FLI
emm_ves2_fli_sml_her <- emmeans(glmm_ves2_fli_sml_w5_1, "treatment", type = "response")
emm_ves2_fli_sml_her <- multcomp::cld(emm_ves2_fli_sml_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_her$emmean <- emm_ves2_fli_sml_her$emmean * 1000
emm_ves2_fli_sml_her$lower.CL <- emm_ves2_fli_sml_her$lower.CL * 1000
emm_ves2_fli_sml_her$upper.CL <- emm_ves2_fli_sml_her$upper.CL * 1000
emm_ves2_fli_sml_her$weather_set <- 5
emm_ves2_fli_sml_her$.group <- trimws(emm_ves2_fli_sml_her$.group, which = c("both"))

summ_ves2_fli_w1_sml_her <- summarySE(values_sml_w1, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w2_sml_her <- summarySE(values_sml_w2, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w3_sml_her <- summarySE(values_sml_w3, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w4_sml_her <- summarySE(values_sml_w4, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w1_sml_her$weather_set <- 1
summ_ves2_fli_w2_sml_her$weather_set <- 2
summ_ves2_fli_w3_sml_her$weather_set <- 3
summ_ves2_fli_w4_sml_her$weather_set <- 4
summ_ves2_fli_w1_sml_her$emmean <- summ_ves2_fli_w1_sml_her$ves2_fli
summ_ves2_fli_w1_sml_her$lower.CL <- summ_ves2_fli_w1_sml_her$ves2_fli - summ_ves2_fli_w1_sml_her$ci
summ_ves2_fli_w1_sml_her$upper.CL <- summ_ves2_fli_w1_sml_her$ves2_fli + summ_ves2_fli_w1_sml_her$ci
summ_ves2_fli_w1_sml_her$.group <- " "
summ_ves2_fli_w2_sml_her$emmean <- summ_ves2_fli_w2_sml_her$ves2_fli
summ_ves2_fli_w2_sml_her$lower.CL <- summ_ves2_fli_w2_sml_her$ves2_fli - summ_ves2_fli_w2_sml_her$ci
summ_ves2_fli_w2_sml_her$upper.CL <- summ_ves2_fli_w2_sml_her$ves2_fli + summ_ves2_fli_w2_sml_her$ci
summ_ves2_fli_w2_sml_her$.group <- " "
summ_ves2_fli_w3_sml_her$emmean <- summ_ves2_fli_w3_sml_her$ves2_fli
summ_ves2_fli_w3_sml_her$lower.CL <- summ_ves2_fli_w3_sml_her$ves2_fli - summ_ves2_fli_w3_sml_her$ci
summ_ves2_fli_w3_sml_her$upper.CL <- summ_ves2_fli_w3_sml_her$ves2_fli + summ_ves2_fli_w3_sml_her$ci
summ_ves2_fli_w3_sml_her$.group <- " "
summ_ves2_fli_w4_sml_her$emmean <- summ_ves2_fli_w4_sml_her$ves2_fli
summ_ves2_fli_w4_sml_her$lower.CL <- summ_ves2_fli_w4_sml_her$ves2_fli - summ_ves2_fli_w4_sml_her$ci
summ_ves2_fli_w4_sml_her$upper.CL <- summ_ves2_fli_w4_sml_her$ves2_fli + summ_ves2_fli_w4_sml_her$ci
summ_ves2_fli_w4_sml_her$.group <- " "

common_cols_ves2_fli_sml_her <- intersect(colnames(emm_ves2_fli_sml_her), colnames(summ_ves2_fli_w1_sml_her))
summ_ves2_fli_all_sml_her <- rbind(#subset(summ_ves2_fli_w1_sml_her, select = common_cols_ves2_fli_sml_her),
                                  subset(summ_ves2_fli_w2_sml_her, select = common_cols_ves2_fli_sml_her),
                                  subset(summ_ves2_fli_w3_sml_her, select = common_cols_ves2_fli_sml_her),
                                  subset(summ_ves2_fli_w4_sml_her, select = common_cols_ves2_fli_sml_her),
                                  subset(emm_ves2_fli_sml_her, select = common_cols_ves2_fli_sml_her))
summ_ves2_fli_all_sml_her$weather_set <- as.factor(summ_ves2_fli_all_sml_her$weather_set)

plot_ves2_fli_sml_her <- ggplot(data = summ_ves2_fli_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 30800) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 2000), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_ves2_fli_sml_her
########################
emm_ves2_fli_sml_tsf <- emmeans(glmm_ves2_fli_sml_w5_1, "tsf_factor", type = "response")
emm_ves2_fli_sml_tsf <- multcomp::cld(emm_ves2_fli_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_sml_tsf$emmean <- emm_ves2_fli_sml_tsf$emmean * 1000
emm_ves2_fli_sml_tsf$lower.CL <- emm_ves2_fli_sml_tsf$lower.CL * 1000
emm_ves2_fli_sml_tsf$upper.CL <- emm_ves2_fli_sml_tsf$upper.CL * 1000
emm_ves2_fli_sml_tsf$weather_set <- 5
emm_ves2_fli_sml_tsf$.group <- trimws(emm_ves2_fli_sml_tsf$.group, which = c("both"))

summ_ves2_fli_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w1_sml_tsf$weather_set <- 1
summ_ves2_fli_w2_sml_tsf$weather_set <- 2
summ_ves2_fli_w3_sml_tsf$weather_set <- 3
summ_ves2_fli_w4_sml_tsf$weather_set <- 4
summ_ves2_fli_w1_sml_tsf$emmean <- summ_ves2_fli_w1_sml_tsf$ves2_fli
summ_ves2_fli_w1_sml_tsf$lower.CL <- summ_ves2_fli_w1_sml_tsf$ves2_fli - summ_ves2_fli_w1_sml_tsf$ci
summ_ves2_fli_w1_sml_tsf$upper.CL <- summ_ves2_fli_w1_sml_tsf$ves2_fli + summ_ves2_fli_w1_sml_tsf$ci
summ_ves2_fli_w1_sml_tsf$.group <- " "
summ_ves2_fli_w2_sml_tsf$emmean <- summ_ves2_fli_w2_sml_tsf$ves2_fli
summ_ves2_fli_w2_sml_tsf$lower.CL <- summ_ves2_fli_w2_sml_tsf$ves2_fli - summ_ves2_fli_w2_sml_tsf$ci
summ_ves2_fli_w2_sml_tsf$upper.CL <- summ_ves2_fli_w2_sml_tsf$ves2_fli + summ_ves2_fli_w2_sml_tsf$ci
summ_ves2_fli_w2_sml_tsf$.group <- " "
summ_ves2_fli_w3_sml_tsf$emmean <- summ_ves2_fli_w3_sml_tsf$ves2_fli
summ_ves2_fli_w3_sml_tsf$lower.CL <- summ_ves2_fli_w3_sml_tsf$ves2_fli - summ_ves2_fli_w3_sml_tsf$ci
summ_ves2_fli_w3_sml_tsf$upper.CL <- summ_ves2_fli_w3_sml_tsf$ves2_fli + summ_ves2_fli_w3_sml_tsf$ci
summ_ves2_fli_w3_sml_tsf$.group <- " "
summ_ves2_fli_w4_sml_tsf$emmean <- summ_ves2_fli_w4_sml_tsf$ves2_fli
summ_ves2_fli_w4_sml_tsf$lower.CL <- summ_ves2_fli_w4_sml_tsf$ves2_fli - summ_ves2_fli_w4_sml_tsf$ci
summ_ves2_fli_w4_sml_tsf$upper.CL <- summ_ves2_fli_w4_sml_tsf$ves2_fli + summ_ves2_fli_w4_sml_tsf$ci
summ_ves2_fli_w4_sml_tsf$.group <- " "

common_cols_ves2_fli_sml_tsf <- intersect(colnames(emm_ves2_fli_sml_tsf), colnames(summ_ves2_fli_w1_sml_tsf))
summ_ves2_fli_all_sml_tsf <- rbind(#subset(summ_ves2_fli_w1_sml_tsf, select = common_cols_ves2_fli_sml_tsf),
                                  subset(summ_ves2_fli_w2_sml_tsf, select = common_cols_ves2_fli_sml_tsf),
                                  subset(summ_ves2_fli_w3_sml_tsf, select = common_cols_ves2_fli_sml_tsf),
                                  subset(summ_ves2_fli_w4_sml_tsf, select = common_cols_ves2_fli_sml_tsf),
                                  subset(emm_ves2_fli_sml_tsf, select = common_cols_ves2_fli_sml_tsf))
summ_ves2_fli_all_sml_tsf$weather_set <- as.factor(summ_ves2_fli_all_sml_tsf$weather_set)
view(summ_ves2_fli_all_sml_tsf)
plot_ves2_fli_sml_tsf <- ggplot(data = summ_ves2_fli_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 30800) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 2000), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_ves2_fli_sml_tsf

########################
emm_ves2_fli_lrg_her <- emmeans(glmm_ves2_fli_lrg_w5_1, "treatment", type = "response")
emm_ves2_fli_lrg_her         <- multcomp::cld(emm_ves2_fli_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_her$emmean    <- emm_ves2_fli_lrg_her$emmean * 1000
emm_ves2_fli_lrg_her$lower.CL  <- emm_ves2_fli_lrg_her$lower.CL * 1000
emm_ves2_fli_lrg_her$upper.CL  <- emm_ves2_fli_lrg_her$upper.CL * 1000
emm_ves2_fli_lrg_her$weather_set <- 5
emm_ves2_fli_lrg_her$.group <- trimws(emm_ves2_fli_lrg_her$.group, which = c("both"))

summ_ves2_fli_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "ves2_fli", groupvars = c("treatment"))
summ_ves2_fli_w1_lrg_her$weather_set <- 1
summ_ves2_fli_w2_lrg_her$weather_set <- 2
summ_ves2_fli_w3_lrg_her$weather_set <- 3
summ_ves2_fli_w4_lrg_her$weather_set <- 4
summ_ves2_fli_w1_lrg_her$emmean <- summ_ves2_fli_w1_lrg_her$ves2_fli
summ_ves2_fli_w1_lrg_her$lower.CL <- summ_ves2_fli_w1_lrg_her$ves2_fli - summ_ves2_fli_w1_lrg_her$ci
summ_ves2_fli_w1_lrg_her$upper.CL <- summ_ves2_fli_w1_lrg_her$ves2_fli + summ_ves2_fli_w1_lrg_her$ci
summ_ves2_fli_w1_lrg_her$.group <- " "
summ_ves2_fli_w2_lrg_her$emmean <- summ_ves2_fli_w2_lrg_her$ves2_fli
summ_ves2_fli_w2_lrg_her$lower.CL <- summ_ves2_fli_w2_lrg_her$ves2_fli - summ_ves2_fli_w2_lrg_her$ci
summ_ves2_fli_w2_lrg_her$upper.CL <- summ_ves2_fli_w2_lrg_her$ves2_fli + summ_ves2_fli_w2_lrg_her$ci
summ_ves2_fli_w2_lrg_her$.group <- " "
summ_ves2_fli_w3_lrg_her$emmean <- summ_ves2_fli_w3_lrg_her$ves2_fli
summ_ves2_fli_w3_lrg_her$lower.CL <- summ_ves2_fli_w3_lrg_her$ves2_fli - summ_ves2_fli_w3_lrg_her$ci
summ_ves2_fli_w3_lrg_her$upper.CL <- summ_ves2_fli_w3_lrg_her$ves2_fli + summ_ves2_fli_w3_lrg_her$ci
summ_ves2_fli_w3_lrg_her$.group <- " "
summ_ves2_fli_w4_lrg_her$emmean <- summ_ves2_fli_w4_lrg_her$ves2_fli
summ_ves2_fli_w4_lrg_her$lower.CL <- summ_ves2_fli_w4_lrg_her$ves2_fli - summ_ves2_fli_w4_lrg_her$ci
summ_ves2_fli_w4_lrg_her$upper.CL <- summ_ves2_fli_w4_lrg_her$ves2_fli + summ_ves2_fli_w4_lrg_her$ci
summ_ves2_fli_w4_lrg_her$.group <- " "

common_cols_ves2_fli_lrg_her <- intersect(colnames(emm_ves2_fli_lrg_her), colnames(summ_ves2_fli_w1_lrg_her))
summ_ves2_fli_all_lrg_her <- rbind(#subset(summ_ves2_fli_w1_lrg_her, select = common_cols_ves2_fli_lrg_her),
                                  subset(summ_ves2_fli_w2_lrg_her, select = common_cols_ves2_fli_lrg_her),
                                  subset(summ_ves2_fli_w3_lrg_her, select = common_cols_ves2_fli_lrg_her),
                                  subset(summ_ves2_fli_w4_lrg_her, select = common_cols_ves2_fli_lrg_her),
                                  subset(emm_ves2_fli_lrg_her, select = common_cols_ves2_fli_lrg_her))
summ_ves2_fli_all_lrg_her$weather_set <- as.factor(summ_ves2_fli_all_lrg_her$weather_set)

plot_ves2_fli_lrg_her <- ggplot(data = summ_ves2_fli_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 31300) +
  labs(colour = "weather set") +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 2000), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_ves2_fli_lrg_her
########################
emm_ves2_fli_lrg_tsf <- emmeans(glmm_ves2_fli_lrg_w5_1, "tsf_factor", type = "response")
emm_ves2_fli_lrg_tsf <- multcomp::cld(emm_ves2_fli_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_ves2_fli_lrg_tsf$emmean    <- emm_ves2_fli_lrg_tsf$emmean * 1000
emm_ves2_fli_lrg_tsf$lower.CL  <- emm_ves2_fli_lrg_tsf$lower.CL * 1000
emm_ves2_fli_lrg_tsf$upper.CL  <- emm_ves2_fli_lrg_tsf$upper.CL * 1000
emm_ves2_fli_lrg_tsf$weather_set <- 5
emm_ves2_fli_lrg_tsf$.group <- trimws(emm_ves2_fli_lrg_tsf$.group, which = c("both"))

summ_ves2_fli_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "ves2_fli", groupvars = c("tsf_factor"))
summ_ves2_fli_w1_lrg_tsf$weather_set <- 1
summ_ves2_fli_w2_lrg_tsf$weather_set <- 2
summ_ves2_fli_w3_lrg_tsf$weather_set <- 3
summ_ves2_fli_w4_lrg_tsf$weather_set <- 4
summ_ves2_fli_w1_lrg_tsf$emmean <- summ_ves2_fli_w1_lrg_tsf$ves2_fli
summ_ves2_fli_w1_lrg_tsf$lower.CL <- summ_ves2_fli_w1_lrg_tsf$ves2_fli - summ_ves2_fli_w1_lrg_tsf$ci
summ_ves2_fli_w1_lrg_tsf$upper.CL <- summ_ves2_fli_w1_lrg_tsf$ves2_fli + summ_ves2_fli_w1_lrg_tsf$ci
summ_ves2_fli_w1_lrg_tsf$.group <- " "
summ_ves2_fli_w2_lrg_tsf$emmean <- summ_ves2_fli_w2_lrg_tsf$ves2_fli
summ_ves2_fli_w2_lrg_tsf$lower.CL <- summ_ves2_fli_w2_lrg_tsf$ves2_fli - summ_ves2_fli_w2_lrg_tsf$ci
summ_ves2_fli_w2_lrg_tsf$upper.CL <- summ_ves2_fli_w2_lrg_tsf$ves2_fli + summ_ves2_fli_w2_lrg_tsf$ci
summ_ves2_fli_w2_lrg_tsf$.group <- " "
summ_ves2_fli_w3_lrg_tsf$emmean <- summ_ves2_fli_w3_lrg_tsf$ves2_fli
summ_ves2_fli_w3_lrg_tsf$lower.CL <- summ_ves2_fli_w3_lrg_tsf$ves2_fli - summ_ves2_fli_w3_lrg_tsf$ci
summ_ves2_fli_w3_lrg_tsf$upper.CL <- summ_ves2_fli_w3_lrg_tsf$ves2_fli + summ_ves2_fli_w3_lrg_tsf$ci
summ_ves2_fli_w3_lrg_tsf$.group <- " "
summ_ves2_fli_w4_lrg_tsf$emmean <- summ_ves2_fli_w4_lrg_tsf$ves2_fli
summ_ves2_fli_w4_lrg_tsf$lower.CL <- summ_ves2_fli_w4_lrg_tsf$ves2_fli - summ_ves2_fli_w4_lrg_tsf$ci
summ_ves2_fli_w4_lrg_tsf$upper.CL <- summ_ves2_fli_w4_lrg_tsf$ves2_fli + summ_ves2_fli_w4_lrg_tsf$ci
summ_ves2_fli_w4_lrg_tsf$.group <- " "

common_cols_ves2_fli_lrg_tsf <- intersect(colnames(emm_ves2_fli_lrg_tsf), colnames(summ_ves2_fli_w1_lrg_tsf))
summ_ves2_fli_all_lrg_tsf <- rbind(#subset(summ_ves2_fli_w1_lrg_tsf, select = common_cols_ves2_fli_lrg_tsf),
                                  subset(summ_ves2_fli_w2_lrg_tsf, select = common_cols_ves2_fli_lrg_tsf),
                                  subset(summ_ves2_fli_w3_lrg_tsf, select = common_cols_ves2_fli_lrg_tsf),
                                  subset(summ_ves2_fli_w4_lrg_tsf, select = common_cols_ves2_fli_lrg_tsf),
                                  subset(emm_ves2_fli_lrg_tsf, select = common_cols_ves2_fli_lrg_tsf))
summ_ves2_fli_all_lrg_tsf$weather_set <- as.factor(summ_ves2_fli_all_lrg_tsf$weather_set)

plot_ves2_fli_lrg_tsf <- ggplot(data = summ_ves2_fli_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 31300) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 2000), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed') 
plot_ves2_fli_lrg_tsf

####################################################################################################
####################################################################################################
######################################zyl FINAL PLOTS########################################################
####################################################################################################
emm_zyl_fht_sml_her <- emmeans(glmm_zyl_fht_sml_w5_1, "treatment", type = "response")
emm_zyl_fht_sml_her <- multcomp::cld(emm_zyl_fht_sml_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_her$weather_set <- 5
emm_zyl_fht_sml_her$.group <- trimws(emm_zyl_fht_sml_her$.group, which = c("both"))

summ_zyl_fht_w1_sml_her <- summarySE(values_sml_w1, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w2_sml_her <- summarySE(values_sml_w2, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w3_sml_her <- summarySE(values_sml_w3, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w4_sml_her <- summarySE(values_sml_w4, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w1_sml_her$weather_set <- 1
summ_zyl_fht_w2_sml_her$weather_set <- 2
summ_zyl_fht_w3_sml_her$weather_set <- 3
summ_zyl_fht_w4_sml_her$weather_set <- 4
summ_zyl_fht_w1_sml_her$emmean <- summ_zyl_fht_w1_sml_her$zyl_fht
summ_zyl_fht_w1_sml_her$lower.CL <- summ_zyl_fht_w1_sml_her$zyl_fht - summ_zyl_fht_w1_sml_her$ci
summ_zyl_fht_w1_sml_her$upper.CL <- summ_zyl_fht_w1_sml_her$zyl_fht + summ_zyl_fht_w1_sml_her$ci
summ_zyl_fht_w1_sml_her$.group <- " "
summ_zyl_fht_w2_sml_her$emmean <- summ_zyl_fht_w2_sml_her$zyl_fht
summ_zyl_fht_w2_sml_her$lower.CL <- summ_zyl_fht_w2_sml_her$zyl_fht - summ_zyl_fht_w2_sml_her$ci
summ_zyl_fht_w2_sml_her$upper.CL <- summ_zyl_fht_w2_sml_her$zyl_fht + summ_zyl_fht_w2_sml_her$ci
summ_zyl_fht_w2_sml_her$.group <- " "
summ_zyl_fht_w3_sml_her$emmean <- summ_zyl_fht_w3_sml_her$zyl_fht
summ_zyl_fht_w3_sml_her$lower.CL <- summ_zyl_fht_w3_sml_her$zyl_fht - summ_zyl_fht_w3_sml_her$ci
summ_zyl_fht_w3_sml_her$upper.CL <- summ_zyl_fht_w3_sml_her$zyl_fht + summ_zyl_fht_w3_sml_her$ci
summ_zyl_fht_w3_sml_her$.group <- " "
summ_zyl_fht_w4_sml_her$emmean <- summ_zyl_fht_w4_sml_her$zyl_fht
summ_zyl_fht_w4_sml_her$lower.CL <- summ_zyl_fht_w4_sml_her$zyl_fht - summ_zyl_fht_w4_sml_her$ci
summ_zyl_fht_w4_sml_her$upper.CL <- summ_zyl_fht_w4_sml_her$zyl_fht + summ_zyl_fht_w4_sml_her$ci
summ_zyl_fht_w4_sml_her$.group <- " "

common_cols_zyl_fht_sml_her <- intersect(colnames(emm_zyl_fht_sml_her), colnames(summ_zyl_fht_w1_sml_her))
summ_zyl_fht_all_sml_her <- rbind(#subset(summ_zyl_fht_w1_sml_her, select = common_cols_zyl_fht_sml_her),
                                  subset(summ_zyl_fht_w2_sml_her, select = common_cols_zyl_fht_sml_her),
                                  subset(summ_zyl_fht_w3_sml_her, select = common_cols_zyl_fht_sml_her),
                                  subset(summ_zyl_fht_w4_sml_her, select = common_cols_zyl_fht_sml_her),
                                  subset(emm_zyl_fht_sml_her, select = common_cols_zyl_fht_sml_her))
summ_zyl_fht_all_sml_her$weather_set <- as.factor(summ_zyl_fht_all_sml_her$weather_set)

plot_zyl_fht_sml_her <- ggplot(data = summ_zyl_fht_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Flame height (m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 11) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_zyl_fht_sml_her
########################
emm_zyl_fht_sml_tsf <- emmeans(glmm_zyl_fht_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_fht_sml_tsf <- multcomp::cld(emm_zyl_fht_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_sml_tsf$weather_set <- 5
emm_zyl_fht_sml_tsf$.group <- trimws(emm_zyl_fht_sml_tsf$.group, which = c("both"))

summ_zyl_fht_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w1_sml_tsf$weather_set <- 1
summ_zyl_fht_w2_sml_tsf$weather_set <- 2
summ_zyl_fht_w3_sml_tsf$weather_set <- 3
summ_zyl_fht_w4_sml_tsf$weather_set <- 4
summ_zyl_fht_w1_sml_tsf$emmean <- summ_zyl_fht_w1_sml_tsf$zyl_fht
summ_zyl_fht_w1_sml_tsf$lower.CL <- summ_zyl_fht_w1_sml_tsf$zyl_fht - summ_zyl_fht_w1_sml_tsf$ci
summ_zyl_fht_w1_sml_tsf$upper.CL <- summ_zyl_fht_w1_sml_tsf$zyl_fht + summ_zyl_fht_w1_sml_tsf$ci
summ_zyl_fht_w1_sml_tsf$.group <- " "
summ_zyl_fht_w2_sml_tsf$emmean <- summ_zyl_fht_w2_sml_tsf$zyl_fht
summ_zyl_fht_w2_sml_tsf$lower.CL <- summ_zyl_fht_w2_sml_tsf$zyl_fht - summ_zyl_fht_w2_sml_tsf$ci
summ_zyl_fht_w2_sml_tsf$upper.CL <- summ_zyl_fht_w2_sml_tsf$zyl_fht + summ_zyl_fht_w2_sml_tsf$ci
summ_zyl_fht_w2_sml_tsf$.group <- " "
summ_zyl_fht_w3_sml_tsf$emmean <- summ_zyl_fht_w3_sml_tsf$zyl_fht
summ_zyl_fht_w3_sml_tsf$lower.CL <- summ_zyl_fht_w3_sml_tsf$zyl_fht - summ_zyl_fht_w3_sml_tsf$ci
summ_zyl_fht_w3_sml_tsf$upper.CL <- summ_zyl_fht_w3_sml_tsf$zyl_fht + summ_zyl_fht_w3_sml_tsf$ci
summ_zyl_fht_w3_sml_tsf$.group <- " "
summ_zyl_fht_w4_sml_tsf$emmean <- summ_zyl_fht_w4_sml_tsf$zyl_fht
summ_zyl_fht_w4_sml_tsf$lower.CL <- summ_zyl_fht_w4_sml_tsf$zyl_fht - summ_zyl_fht_w4_sml_tsf$ci
summ_zyl_fht_w4_sml_tsf$upper.CL <- summ_zyl_fht_w4_sml_tsf$zyl_fht + summ_zyl_fht_w4_sml_tsf$ci
summ_zyl_fht_w4_sml_tsf$.group <- " "

common_cols_zyl_fht_sml_tsf <- intersect(colnames(emm_zyl_fht_sml_tsf), colnames(summ_zyl_fht_w1_sml_tsf))
summ_zyl_fht_all_sml_tsf <- rbind(#subset(summ_zyl_fht_w1_sml_tsf, select = common_cols_zyl_fht_sml_tsf),
                                  subset(summ_zyl_fht_w2_sml_tsf, select = common_cols_zyl_fht_sml_tsf),
                                  subset(summ_zyl_fht_w3_sml_tsf, select = common_cols_zyl_fht_sml_tsf),
                                  subset(summ_zyl_fht_w4_sml_tsf, select = common_cols_zyl_fht_sml_tsf),
                                  subset(emm_zyl_fht_sml_tsf, select = common_cols_zyl_fht_sml_tsf))
summ_zyl_fht_all_sml_tsf$weather_set <- as.factor(summ_zyl_fht_all_sml_tsf$weather_set)

plot_zyl_fht_sml_tsf <- ggplot(data = summ_zyl_fht_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 11) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') #+
  # geom_text(aes(3.3, 1, label = "(i)")) +
  # geom_text(aes(3.3, 2.5, label = "(ii)")) +
  # geom_text(aes(3.3, 6, label = "(iii)")) +
  # geom_text(aes(3.3, 11, label = "(iv)"))
plot_zyl_fht_sml_tsf

########################
emm_zyl_fht_lrg_her <- emmeans(glmm_zyl_fht_lrg_w5_1, "treatment", type = "response")
emm_zyl_fht_lrg_her <- multcomp::cld(emm_zyl_fht_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_her$weather_set <- 5
emm_zyl_fht_lrg_her$.group <- trimws(emm_zyl_fht_lrg_her$.group, which = c("both"))

summ_zyl_fht_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "zyl_fht", groupvars = c("treatment"))
summ_zyl_fht_w1_lrg_her$weather_set <- 1
summ_zyl_fht_w2_lrg_her$weather_set <- 2
summ_zyl_fht_w3_lrg_her$weather_set <- 3
summ_zyl_fht_w4_lrg_her$weather_set <- 4
summ_zyl_fht_w1_lrg_her$emmean <- summ_zyl_fht_w1_lrg_her$zyl_fht
summ_zyl_fht_w1_lrg_her$lower.CL <- summ_zyl_fht_w1_lrg_her$zyl_fht - summ_zyl_fht_w1_lrg_her$ci
summ_zyl_fht_w1_lrg_her$upper.CL <- summ_zyl_fht_w1_lrg_her$zyl_fht + summ_zyl_fht_w1_lrg_her$ci
summ_zyl_fht_w1_lrg_her$.group <- " "
summ_zyl_fht_w2_lrg_her$emmean <- summ_zyl_fht_w2_lrg_her$zyl_fht
summ_zyl_fht_w2_lrg_her$lower.CL <- summ_zyl_fht_w2_lrg_her$zyl_fht - summ_zyl_fht_w2_lrg_her$ci
summ_zyl_fht_w2_lrg_her$upper.CL <- summ_zyl_fht_w2_lrg_her$zyl_fht + summ_zyl_fht_w2_lrg_her$ci
summ_zyl_fht_w2_lrg_her$.group <- " "
summ_zyl_fht_w3_lrg_her$emmean <- summ_zyl_fht_w3_lrg_her$zyl_fht
summ_zyl_fht_w3_lrg_her$lower.CL <- summ_zyl_fht_w3_lrg_her$zyl_fht - summ_zyl_fht_w3_lrg_her$ci
summ_zyl_fht_w3_lrg_her$upper.CL <- summ_zyl_fht_w3_lrg_her$zyl_fht + summ_zyl_fht_w3_lrg_her$ci
summ_zyl_fht_w3_lrg_her$.group <- " "
summ_zyl_fht_w4_lrg_her$emmean <- summ_zyl_fht_w4_lrg_her$zyl_fht
summ_zyl_fht_w4_lrg_her$lower.CL <- summ_zyl_fht_w4_lrg_her$zyl_fht - summ_zyl_fht_w4_lrg_her$ci
summ_zyl_fht_w4_lrg_her$upper.CL <- summ_zyl_fht_w4_lrg_her$zyl_fht + summ_zyl_fht_w4_lrg_her$ci
summ_zyl_fht_w4_lrg_her$.group <- " "

common_cols_zyl_fht_lrg_her <- intersect(colnames(emm_zyl_fht_lrg_her), colnames(summ_zyl_fht_w1_lrg_her))
summ_zyl_fht_all_lrg_her <- rbind(#subset(summ_zyl_fht_w1_lrg_her, select = common_cols_zyl_fht_lrg_her),
                                  subset(summ_zyl_fht_w2_lrg_her, select = common_cols_zyl_fht_lrg_her),
                                  subset(summ_zyl_fht_w3_lrg_her, select = common_cols_zyl_fht_lrg_her),
                                  subset(summ_zyl_fht_w4_lrg_her, select = common_cols_zyl_fht_lrg_her),
                                  subset(emm_zyl_fht_lrg_her, select = common_cols_zyl_fht_lrg_her))
summ_zyl_fht_all_lrg_her$weather_set <- as.factor(summ_zyl_fht_all_lrg_her$weather_set)

plot_zyl_fht_lrg_her <- ggplot(data = summ_zyl_fht_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Flame height (m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  #theme(legend.justification = c(1, 1), axis.title.y = element_text(margin = margin(b = 70))) +
  #labs(colour = "weather set") +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 11) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') 
plot_zyl_fht_lrg_her
########################
emm_zyl_fht_lrg_tsf <- emmeans(glmm_zyl_fht_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_fht_lrg_tsf <- multcomp::cld(emm_zyl_fht_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fht_lrg_tsf$weather_set <- 5
emm_zyl_fht_lrg_tsf$.group <- trimws(emm_zyl_fht_lrg_tsf$.group, which = c("both"))

summ_zyl_fht_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "zyl_fht", groupvars = c("tsf_factor"))
summ_zyl_fht_w1_lrg_tsf$weather_set <- 1
summ_zyl_fht_w2_lrg_tsf$weather_set <- 2
summ_zyl_fht_w3_lrg_tsf$weather_set <- 3
summ_zyl_fht_w4_lrg_tsf$weather_set <- 4
summ_zyl_fht_w1_lrg_tsf$emmean <- summ_zyl_fht_w1_lrg_tsf$zyl_fht
summ_zyl_fht_w1_lrg_tsf$lower.CL <- summ_zyl_fht_w1_lrg_tsf$zyl_fht - summ_zyl_fht_w1_lrg_tsf$ci
summ_zyl_fht_w1_lrg_tsf$upper.CL <- summ_zyl_fht_w1_lrg_tsf$zyl_fht + summ_zyl_fht_w1_lrg_tsf$ci
summ_zyl_fht_w1_lrg_tsf$.group <- " "
summ_zyl_fht_w2_lrg_tsf$emmean <- summ_zyl_fht_w2_lrg_tsf$zyl_fht
summ_zyl_fht_w2_lrg_tsf$lower.CL <- summ_zyl_fht_w2_lrg_tsf$zyl_fht - summ_zyl_fht_w2_lrg_tsf$ci
summ_zyl_fht_w2_lrg_tsf$upper.CL <- summ_zyl_fht_w2_lrg_tsf$zyl_fht + summ_zyl_fht_w2_lrg_tsf$ci
summ_zyl_fht_w2_lrg_tsf$.group <- " "
summ_zyl_fht_w3_lrg_tsf$emmean <- summ_zyl_fht_w3_lrg_tsf$zyl_fht
summ_zyl_fht_w3_lrg_tsf$lower.CL <- summ_zyl_fht_w3_lrg_tsf$zyl_fht - summ_zyl_fht_w3_lrg_tsf$ci
summ_zyl_fht_w3_lrg_tsf$upper.CL <- summ_zyl_fht_w3_lrg_tsf$zyl_fht + summ_zyl_fht_w3_lrg_tsf$ci
summ_zyl_fht_w3_lrg_tsf$.group <- " "
summ_zyl_fht_w4_lrg_tsf$emmean <- summ_zyl_fht_w4_lrg_tsf$zyl_fht
summ_zyl_fht_w4_lrg_tsf$lower.CL <- summ_zyl_fht_w4_lrg_tsf$zyl_fht - summ_zyl_fht_w4_lrg_tsf$ci
summ_zyl_fht_w4_lrg_tsf$upper.CL <- summ_zyl_fht_w4_lrg_tsf$zyl_fht + summ_zyl_fht_w4_lrg_tsf$ci
summ_zyl_fht_w4_lrg_tsf$.group <- " "

common_cols_zyl_fht_lrg_tsf <- intersect(colnames(emm_zyl_fht_lrg_tsf), colnames(summ_zyl_fht_w1_lrg_tsf))
summ_zyl_fht_all_lrg_tsf <- rbind(#subset(summ_zyl_fht_w1_lrg_tsf, select = common_cols_zyl_fht_lrg_tsf),
                                  subset(summ_zyl_fht_w2_lrg_tsf, select = common_cols_zyl_fht_lrg_tsf),
                                  subset(summ_zyl_fht_w3_lrg_tsf, select = common_cols_zyl_fht_lrg_tsf),
                                  subset(summ_zyl_fht_w4_lrg_tsf, select = common_cols_zyl_fht_lrg_tsf),
                                  subset(emm_zyl_fht_lrg_tsf, select = common_cols_zyl_fht_lrg_tsf))
summ_zyl_fht_all_lrg_tsf$weather_set <- as.factor(summ_zyl_fht_all_lrg_tsf$weather_set)

plot_zyl_fht_lrg_tsf <- ggplot(data = summ_zyl_fht_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 11) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.5), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2, linetype='dotted') +
  geom_hline(yintercept = 3, linetype='dotdash') +
  geom_hline(yintercept = 10, linetype='dashed') #+
  # geom_text(aes(3.3, 1, label = "(i)")) +
  # geom_text(aes(3.3, 2.5, label = "(ii)")) +
  # geom_text(aes(3.3, 6, label = "(iii)")) +
  # geom_text(aes(3.3, 11, label = "(iv)"))
plot_zyl_fht_lrg_tsf

####################################################################################################
###########zyl ROS
emm_zyl_ros_sml_her <- emmeans(glmm_zyl_ros_sml_w5_1, "treatment", type = "response")
emm_zyl_ros_sml_her <- multcomp::cld(emm_zyl_ros_sml_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_her$weather_set <- 5
emm_zyl_ros_sml_her$.group <- trimws(emm_zyl_ros_sml_her$.group, which = c("both"))

summ_zyl_ros_w1_sml_her <- summarySE(values_sml_w1, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w2_sml_her <- summarySE(values_sml_w2, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w3_sml_her <- summarySE(values_sml_w3, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w4_sml_her <- summarySE(values_sml_w4, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w1_sml_her$weather_set <- 1
summ_zyl_ros_w2_sml_her$weather_set <- 2
summ_zyl_ros_w3_sml_her$weather_set <- 3
summ_zyl_ros_w4_sml_her$weather_set <- 4
summ_zyl_ros_w1_sml_her$emmean <- summ_zyl_ros_w1_sml_her$zyl_ros
summ_zyl_ros_w1_sml_her$lower.CL <- summ_zyl_ros_w1_sml_her$zyl_ros - summ_zyl_ros_w1_sml_her$ci
summ_zyl_ros_w1_sml_her$upper.CL <- summ_zyl_ros_w1_sml_her$zyl_ros + summ_zyl_ros_w1_sml_her$ci
summ_zyl_ros_w1_sml_her$.group <- " "
summ_zyl_ros_w2_sml_her$emmean <- summ_zyl_ros_w2_sml_her$zyl_ros
summ_zyl_ros_w2_sml_her$lower.CL <- summ_zyl_ros_w2_sml_her$zyl_ros - summ_zyl_ros_w2_sml_her$ci
summ_zyl_ros_w2_sml_her$upper.CL <- summ_zyl_ros_w2_sml_her$zyl_ros + summ_zyl_ros_w2_sml_her$ci
summ_zyl_ros_w2_sml_her$.group <- " "
summ_zyl_ros_w3_sml_her$emmean <- summ_zyl_ros_w3_sml_her$zyl_ros
summ_zyl_ros_w3_sml_her$lower.CL <- summ_zyl_ros_w3_sml_her$zyl_ros - summ_zyl_ros_w3_sml_her$ci
summ_zyl_ros_w3_sml_her$upper.CL <- summ_zyl_ros_w3_sml_her$zyl_ros + summ_zyl_ros_w3_sml_her$ci
summ_zyl_ros_w3_sml_her$.group <- " "
summ_zyl_ros_w4_sml_her$emmean <- summ_zyl_ros_w4_sml_her$zyl_ros
summ_zyl_ros_w4_sml_her$lower.CL <- summ_zyl_ros_w4_sml_her$zyl_ros - summ_zyl_ros_w4_sml_her$ci
summ_zyl_ros_w4_sml_her$upper.CL <- summ_zyl_ros_w4_sml_her$zyl_ros + summ_zyl_ros_w4_sml_her$ci
summ_zyl_ros_w4_sml_her$.group <- " "

common_cols_zyl_ros_sml_her <- intersect(colnames(emm_zyl_ros_sml_her), colnames(summ_zyl_ros_w1_sml_her))
summ_zyl_ros_all_sml_her <- rbind(#subset(summ_zyl_ros_w1_sml_her, select = common_cols_zyl_ros_sml_her),
                                  subset(summ_zyl_ros_w2_sml_her, select = common_cols_zyl_ros_sml_her),
                                  subset(summ_zyl_ros_w3_sml_her, select = common_cols_zyl_ros_sml_her),
                                  subset(summ_zyl_ros_w4_sml_her, select = common_cols_zyl_ros_sml_her),
                                  subset(emm_zyl_ros_sml_her, select = common_cols_zyl_ros_sml_her))
summ_zyl_ros_all_sml_her$weather_set <- as.factor(summ_zyl_ros_all_sml_her$weather_set)

plot_zyl_ros_sml_her <- ggplot(data = summ_zyl_ros_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.08), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_zyl_ros_sml_her
########################
emm_zyl_ros_sml_tsf <- emmeans(glmm_zyl_ros_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_ros_sml_tsf <- multcomp::cld(emm_zyl_ros_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_sml_tsf$weather_set <- 5
emm_zyl_ros_sml_tsf$.group <- trimws(emm_zyl_ros_sml_tsf$.group, which = c("both"))

summ_zyl_ros_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w1_sml_tsf$weather_set <- 1
summ_zyl_ros_w2_sml_tsf$weather_set <- 2
summ_zyl_ros_w3_sml_tsf$weather_set <- 3
summ_zyl_ros_w4_sml_tsf$weather_set <- 4
summ_zyl_ros_w1_sml_tsf$emmean <- summ_zyl_ros_w1_sml_tsf$zyl_ros
summ_zyl_ros_w1_sml_tsf$lower.CL <- summ_zyl_ros_w1_sml_tsf$zyl_ros - summ_zyl_ros_w1_sml_tsf$ci
summ_zyl_ros_w1_sml_tsf$upper.CL <- summ_zyl_ros_w1_sml_tsf$zyl_ros + summ_zyl_ros_w1_sml_tsf$ci
summ_zyl_ros_w1_sml_tsf$.group <- " "
summ_zyl_ros_w2_sml_tsf$emmean <- summ_zyl_ros_w2_sml_tsf$zyl_ros
summ_zyl_ros_w2_sml_tsf$lower.CL <- summ_zyl_ros_w2_sml_tsf$zyl_ros - summ_zyl_ros_w2_sml_tsf$ci
summ_zyl_ros_w2_sml_tsf$upper.CL <- summ_zyl_ros_w2_sml_tsf$zyl_ros + summ_zyl_ros_w2_sml_tsf$ci
summ_zyl_ros_w2_sml_tsf$.group <- " "
summ_zyl_ros_w3_sml_tsf$emmean <- summ_zyl_ros_w3_sml_tsf$zyl_ros
summ_zyl_ros_w3_sml_tsf$lower.CL <- summ_zyl_ros_w3_sml_tsf$zyl_ros - summ_zyl_ros_w3_sml_tsf$ci
summ_zyl_ros_w3_sml_tsf$upper.CL <- summ_zyl_ros_w3_sml_tsf$zyl_ros + summ_zyl_ros_w3_sml_tsf$ci
summ_zyl_ros_w3_sml_tsf$.group <- " "
summ_zyl_ros_w4_sml_tsf$emmean <- summ_zyl_ros_w4_sml_tsf$zyl_ros
summ_zyl_ros_w4_sml_tsf$lower.CL <- summ_zyl_ros_w4_sml_tsf$zyl_ros - summ_zyl_ros_w4_sml_tsf$ci
summ_zyl_ros_w4_sml_tsf$upper.CL <- summ_zyl_ros_w4_sml_tsf$zyl_ros + summ_zyl_ros_w4_sml_tsf$ci
summ_zyl_ros_w4_sml_tsf$.group <- " "

common_cols_zyl_ros_sml_tsf <- intersect(colnames(emm_zyl_ros_sml_tsf), colnames(summ_zyl_ros_w1_sml_tsf))
summ_zyl_ros_all_sml_tsf <- rbind(#subset(summ_zyl_ros_w1_sml_tsf, select = common_cols_zyl_ros_sml_tsf),
                                  subset(summ_zyl_ros_w2_sml_tsf, select = common_cols_zyl_ros_sml_tsf),
                                  subset(summ_zyl_ros_w3_sml_tsf, select = common_cols_zyl_ros_sml_tsf),
                                  subset(summ_zyl_ros_w4_sml_tsf, select = common_cols_zyl_ros_sml_tsf),
                                  subset(emm_zyl_ros_sml_tsf, select = common_cols_zyl_ros_sml_tsf))
summ_zyl_ros_all_sml_tsf$weather_set <- as.factor(summ_zyl_ros_all_sml_tsf$weather_set)

plot_zyl_ros_sml_tsf <- ggplot(data = summ_zyl_ros_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +  
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.08), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed')
plot_zyl_ros_sml_tsf

########################
emm_zyl_ros_lrg_her <- emmeans(glmm_zyl_ros_lrg_w5_1, "treatment", type = "response")
emm_zyl_ros_lrg_her <- multcomp::cld(emm_zyl_ros_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_her$weather_set <- 5
emm_zyl_ros_lrg_her$.group <- trimws(emm_zyl_ros_lrg_her$.group, which = c("both"))

summ_zyl_ros_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "zyl_ros", groupvars = c("treatment"))
summ_zyl_ros_w1_lrg_her$weather_set <- 1
summ_zyl_ros_w2_lrg_her$weather_set <- 2
summ_zyl_ros_w3_lrg_her$weather_set <- 3
summ_zyl_ros_w4_lrg_her$weather_set <- 4
summ_zyl_ros_w1_lrg_her$emmean <- summ_zyl_ros_w1_lrg_her$zyl_ros
summ_zyl_ros_w1_lrg_her$lower.CL <- summ_zyl_ros_w1_lrg_her$zyl_ros - summ_zyl_ros_w1_lrg_her$ci
summ_zyl_ros_w1_lrg_her$upper.CL <- summ_zyl_ros_w1_lrg_her$zyl_ros + summ_zyl_ros_w1_lrg_her$ci
summ_zyl_ros_w1_lrg_her$.group <- " "
summ_zyl_ros_w2_lrg_her$emmean <- summ_zyl_ros_w2_lrg_her$zyl_ros
summ_zyl_ros_w2_lrg_her$lower.CL <- summ_zyl_ros_w2_lrg_her$zyl_ros - summ_zyl_ros_w2_lrg_her$ci
summ_zyl_ros_w2_lrg_her$upper.CL <- summ_zyl_ros_w2_lrg_her$zyl_ros + summ_zyl_ros_w2_lrg_her$ci
summ_zyl_ros_w2_lrg_her$.group <- " "
summ_zyl_ros_w3_lrg_her$emmean <- summ_zyl_ros_w3_lrg_her$zyl_ros
summ_zyl_ros_w3_lrg_her$lower.CL <- summ_zyl_ros_w3_lrg_her$zyl_ros - summ_zyl_ros_w3_lrg_her$ci
summ_zyl_ros_w3_lrg_her$upper.CL <- summ_zyl_ros_w3_lrg_her$zyl_ros + summ_zyl_ros_w3_lrg_her$ci
summ_zyl_ros_w3_lrg_her$.group <- " "
summ_zyl_ros_w4_lrg_her$emmean <- summ_zyl_ros_w4_lrg_her$zyl_ros
summ_zyl_ros_w4_lrg_her$lower.CL <- summ_zyl_ros_w4_lrg_her$zyl_ros - summ_zyl_ros_w4_lrg_her$ci
summ_zyl_ros_w4_lrg_her$upper.CL <- summ_zyl_ros_w4_lrg_her$zyl_ros + summ_zyl_ros_w4_lrg_her$ci
summ_zyl_ros_w4_lrg_her$.group <- " "

common_cols_zyl_ros_lrg_her <- intersect(colnames(emm_zyl_ros_lrg_her), colnames(summ_zyl_ros_w1_lrg_her))
summ_zyl_ros_all_lrg_her <- rbind(#subset(summ_zyl_ros_w1_lrg_her, select = common_cols_zyl_ros_lrg_her),
                                  subset(summ_zyl_ros_w2_lrg_her, select = common_cols_zyl_ros_lrg_her),
                                  subset(summ_zyl_ros_w3_lrg_her, select = common_cols_zyl_ros_lrg_her),
                                  subset(summ_zyl_ros_w4_lrg_her, select = common_cols_zyl_ros_lrg_her),
                                  subset(emm_zyl_ros_lrg_her, select = common_cols_zyl_ros_lrg_her))
summ_zyl_ros_all_lrg_her$weather_set <- as.factor(summ_zyl_ros_all_lrg_her$weather_set)

plot_zyl_ros_lrg_her <- ggplot(data = summ_zyl_ros_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = "Rate of fire spread (km/h)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +  
  labs(colour = "weather set") +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.08), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_zyl_ros_lrg_her
########################
emm_zyl_ros_lrg_tsf <- emmeans(glmm_zyl_ros_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_ros_lrg_tsf <- multcomp::cld(emm_zyl_ros_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_ros_lrg_tsf$weather_set <- 5
emm_zyl_ros_lrg_tsf$.group <- trimws(emm_zyl_ros_lrg_tsf$.group, which = c("both"))

summ_zyl_ros_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "zyl_ros", groupvars = c("tsf_factor"))
summ_zyl_ros_w1_lrg_tsf$weather_set <- 1
summ_zyl_ros_w2_lrg_tsf$weather_set <- 2
summ_zyl_ros_w3_lrg_tsf$weather_set <- 3
summ_zyl_ros_w4_lrg_tsf$weather_set <- 4
summ_zyl_ros_w1_lrg_tsf$emmean <- summ_zyl_ros_w1_lrg_tsf$zyl_ros
summ_zyl_ros_w1_lrg_tsf$lower.CL <- summ_zyl_ros_w1_lrg_tsf$zyl_ros - summ_zyl_ros_w1_lrg_tsf$ci
summ_zyl_ros_w1_lrg_tsf$upper.CL <- summ_zyl_ros_w1_lrg_tsf$zyl_ros + summ_zyl_ros_w1_lrg_tsf$ci
summ_zyl_ros_w1_lrg_tsf$.group <- " "
summ_zyl_ros_w2_lrg_tsf$emmean <- summ_zyl_ros_w2_lrg_tsf$zyl_ros
summ_zyl_ros_w2_lrg_tsf$lower.CL <- summ_zyl_ros_w2_lrg_tsf$zyl_ros - summ_zyl_ros_w2_lrg_tsf$ci
summ_zyl_ros_w2_lrg_tsf$upper.CL <- summ_zyl_ros_w2_lrg_tsf$zyl_ros + summ_zyl_ros_w2_lrg_tsf$ci
summ_zyl_ros_w2_lrg_tsf$.group <- " "
summ_zyl_ros_w3_lrg_tsf$emmean <- summ_zyl_ros_w3_lrg_tsf$zyl_ros
summ_zyl_ros_w3_lrg_tsf$lower.CL <- summ_zyl_ros_w3_lrg_tsf$zyl_ros - summ_zyl_ros_w3_lrg_tsf$ci
summ_zyl_ros_w3_lrg_tsf$upper.CL <- summ_zyl_ros_w3_lrg_tsf$zyl_ros + summ_zyl_ros_w3_lrg_tsf$ci
summ_zyl_ros_w3_lrg_tsf$.group <- " "
summ_zyl_ros_w4_lrg_tsf$emmean <- summ_zyl_ros_w4_lrg_tsf$zyl_ros
summ_zyl_ros_w4_lrg_tsf$lower.CL <- summ_zyl_ros_w4_lrg_tsf$zyl_ros - summ_zyl_ros_w4_lrg_tsf$ci
summ_zyl_ros_w4_lrg_tsf$upper.CL <- summ_zyl_ros_w4_lrg_tsf$zyl_ros + summ_zyl_ros_w4_lrg_tsf$ci
summ_zyl_ros_w4_lrg_tsf$.group <- " "

common_cols_zyl_ros_lrg_tsf <- intersect(colnames(emm_zyl_ros_lrg_tsf), colnames(summ_zyl_ros_w1_lrg_tsf))
summ_zyl_ros_all_lrg_tsf <- rbind(#subset(summ_zyl_ros_w1_lrg_tsf, select = common_cols_zyl_ros_lrg_tsf),
                                  subset(summ_zyl_ros_w2_lrg_tsf, select = common_cols_zyl_ros_lrg_tsf),
                                  subset(summ_zyl_ros_w3_lrg_tsf, select = common_cols_zyl_ros_lrg_tsf),
                                  subset(summ_zyl_ros_w4_lrg_tsf, select = common_cols_zyl_ros_lrg_tsf),
                                  subset(emm_zyl_ros_lrg_tsf, select = common_cols_zyl_ros_lrg_tsf))
summ_zyl_ros_all_lrg_tsf$weather_set <- as.factor(summ_zyl_ros_all_lrg_tsf$weather_set)

plot_zyl_ros_lrg_tsf <- ggplot(data = summ_zyl_ros_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = " ", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70)), axis.text.x=element_blank()) +
  ylim(0, 1) +  
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 0.08), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 0.03, linetype='dotted') +
  geom_hline(yintercept = 0.4, linetype='dotdash') +
  geom_hline(yintercept = 0.8, linetype='dashed') 
plot_zyl_ros_lrg_tsf

####################################################################################################
########################zyl FLI
emm_zyl_fli_sml_her <- emmeans(glmm_zyl_fli_sml_w5_1, "treatment", type = "response")
emm_zyl_fli_sml_her <- multcomp::cld(emm_zyl_fli_sml_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_her$emmean <- emm_zyl_fli_sml_her$emmean * 1000
emm_zyl_fli_sml_her$lower.CL <- emm_zyl_fli_sml_her$lower.CL * 1000
emm_zyl_fli_sml_her$upper.CL <- emm_zyl_fli_sml_her$upper.CL * 1000
emm_zyl_fli_sml_her$weather_set <- 5
emm_zyl_fli_sml_her$.group <- trimws(emm_zyl_fli_sml_her$.group, which = c("both"))

summ_zyl_fli_w1_sml_her <- summarySE(values_sml_w1, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w2_sml_her <- summarySE(values_sml_w2, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w3_sml_her <- summarySE(values_sml_w3, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w4_sml_her <- summarySE(values_sml_w4, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w1_sml_her$weather_set <- 1
summ_zyl_fli_w2_sml_her$weather_set <- 2
summ_zyl_fli_w3_sml_her$weather_set <- 3
summ_zyl_fli_w4_sml_her$weather_set <- 4
summ_zyl_fli_w1_sml_her$emmean <- summ_zyl_fli_w1_sml_her$zyl_fli
summ_zyl_fli_w1_sml_her$lower.CL <- summ_zyl_fli_w1_sml_her$zyl_fli - summ_zyl_fli_w1_sml_her$ci
summ_zyl_fli_w1_sml_her$upper.CL <- summ_zyl_fli_w1_sml_her$zyl_fli + summ_zyl_fli_w1_sml_her$ci
summ_zyl_fli_w1_sml_her$.group <- " "
summ_zyl_fli_w2_sml_her$emmean <- summ_zyl_fli_w2_sml_her$zyl_fli
summ_zyl_fli_w2_sml_her$lower.CL <- summ_zyl_fli_w2_sml_her$zyl_fli - summ_zyl_fli_w2_sml_her$ci
summ_zyl_fli_w2_sml_her$upper.CL <- summ_zyl_fli_w2_sml_her$zyl_fli + summ_zyl_fli_w2_sml_her$ci
summ_zyl_fli_w2_sml_her$.group <- " "
summ_zyl_fli_w3_sml_her$emmean <- summ_zyl_fli_w3_sml_her$zyl_fli
summ_zyl_fli_w3_sml_her$lower.CL <- summ_zyl_fli_w3_sml_her$zyl_fli - summ_zyl_fli_w3_sml_her$ci
summ_zyl_fli_w3_sml_her$upper.CL <- summ_zyl_fli_w3_sml_her$zyl_fli + summ_zyl_fli_w3_sml_her$ci
summ_zyl_fli_w3_sml_her$.group <- " "
summ_zyl_fli_w4_sml_her$emmean <- summ_zyl_fli_w4_sml_her$zyl_fli
summ_zyl_fli_w4_sml_her$lower.CL <- summ_zyl_fli_w4_sml_her$zyl_fli - summ_zyl_fli_w4_sml_her$ci
summ_zyl_fli_w4_sml_her$upper.CL <- summ_zyl_fli_w4_sml_her$zyl_fli + summ_zyl_fli_w4_sml_her$ci
summ_zyl_fli_w4_sml_her$.group <- " "

common_cols_zyl_fli_sml_her <- intersect(colnames(emm_zyl_fli_sml_her), colnames(summ_zyl_fli_w1_sml_her))
summ_zyl_fli_all_sml_her <- rbind(#subset(summ_zyl_fli_w1_sml_her, select = common_cols_zyl_fli_sml_her),
                                  subset(summ_zyl_fli_w2_sml_her, select = common_cols_zyl_fli_sml_her),
                                  subset(summ_zyl_fli_w3_sml_her, select = common_cols_zyl_fli_sml_her),
                                  subset(summ_zyl_fli_w4_sml_her, select = common_cols_zyl_fli_sml_her),
                                  subset(emm_zyl_fli_sml_her, select = common_cols_zyl_fli_sml_her))
summ_zyl_fli_all_sml_her$weather_set <- as.factor(summ_zyl_fli_all_sml_her$weather_set)

plot_zyl_fli_sml_her <- ggplot(data = summ_zyl_fli_all_sml_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 10000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_zyl_fli_sml_her
########################
emm_zyl_fli_sml_tsf <- emmeans(glmm_zyl_fli_sml_w5_1, "tsf_factor", type = "response")
emm_zyl_fli_sml_tsf <- multcomp::cld(emm_zyl_fli_sml_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_sml_tsf$emmean <- emm_zyl_fli_sml_tsf$emmean * 1000
emm_zyl_fli_sml_tsf$lower.CL <- emm_zyl_fli_sml_tsf$lower.CL * 1000
emm_zyl_fli_sml_tsf$upper.CL <- emm_zyl_fli_sml_tsf$upper.CL * 1000
emm_zyl_fli_sml_tsf$weather_set <- 5
emm_zyl_fli_sml_tsf$.group <- trimws(emm_zyl_fli_sml_tsf$.group, which = c("both"))

summ_zyl_fli_w1_sml_tsf <- summarySE(values_sml_w1, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w2_sml_tsf <- summarySE(values_sml_w2, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w3_sml_tsf <- summarySE(values_sml_w3, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w4_sml_tsf <- summarySE(values_sml_w4, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w1_sml_tsf$weather_set <- 1
summ_zyl_fli_w2_sml_tsf$weather_set <- 2
summ_zyl_fli_w3_sml_tsf$weather_set <- 3
summ_zyl_fli_w4_sml_tsf$weather_set <- 4
summ_zyl_fli_w1_sml_tsf$emmean <- summ_zyl_fli_w1_sml_tsf$zyl_fli
summ_zyl_fli_w1_sml_tsf$lower.CL <- summ_zyl_fli_w1_sml_tsf$zyl_fli - summ_zyl_fli_w1_sml_tsf$ci
summ_zyl_fli_w1_sml_tsf$upper.CL <- summ_zyl_fli_w1_sml_tsf$zyl_fli + summ_zyl_fli_w1_sml_tsf$ci
summ_zyl_fli_w1_sml_tsf$.group <- " "
summ_zyl_fli_w2_sml_tsf$emmean <- summ_zyl_fli_w2_sml_tsf$zyl_fli
summ_zyl_fli_w2_sml_tsf$lower.CL <- summ_zyl_fli_w2_sml_tsf$zyl_fli - summ_zyl_fli_w2_sml_tsf$ci
summ_zyl_fli_w2_sml_tsf$upper.CL <- summ_zyl_fli_w2_sml_tsf$zyl_fli + summ_zyl_fli_w2_sml_tsf$ci
summ_zyl_fli_w2_sml_tsf$.group <- " "
summ_zyl_fli_w3_sml_tsf$emmean <- summ_zyl_fli_w3_sml_tsf$zyl_fli
summ_zyl_fli_w3_sml_tsf$lower.CL <- summ_zyl_fli_w3_sml_tsf$zyl_fli - summ_zyl_fli_w3_sml_tsf$ci
summ_zyl_fli_w3_sml_tsf$upper.CL <- summ_zyl_fli_w3_sml_tsf$zyl_fli + summ_zyl_fli_w3_sml_tsf$ci
summ_zyl_fli_w3_sml_tsf$.group <- " "
summ_zyl_fli_w4_sml_tsf$emmean <- summ_zyl_fli_w4_sml_tsf$zyl_fli
summ_zyl_fli_w4_sml_tsf$lower.CL <- summ_zyl_fli_w4_sml_tsf$zyl_fli - summ_zyl_fli_w4_sml_tsf$ci
summ_zyl_fli_w4_sml_tsf$upper.CL <- summ_zyl_fli_w4_sml_tsf$zyl_fli + summ_zyl_fli_w4_sml_tsf$ci
summ_zyl_fli_w4_sml_tsf$.group <- " "

common_cols_zyl_fli_sml_tsf <- intersect(colnames(emm_zyl_fli_sml_tsf), colnames(summ_zyl_fli_w1_sml_tsf))
summ_zyl_fli_all_sml_tsf <- rbind(#subset(summ_zyl_fli_w1_sml_tsf, select = common_cols_zyl_fli_sml_tsf),
                                  subset(summ_zyl_fli_w2_sml_tsf, select = common_cols_zyl_fli_sml_tsf),
                                  subset(summ_zyl_fli_w3_sml_tsf, select = common_cols_zyl_fli_sml_tsf),
                                  subset(summ_zyl_fli_w4_sml_tsf, select = common_cols_zyl_fli_sml_tsf),
                                  subset(emm_zyl_fli_sml_tsf, select = common_cols_zyl_fli_sml_tsf))
summ_zyl_fli_all_sml_tsf$weather_set <- as.factor(summ_zyl_fli_all_sml_tsf$weather_set)

plot_zyl_fli_sml_tsf <- ggplot(data = summ_zyl_fli_all_sml_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 10000) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_zyl_fli_sml_tsf

########################
emm_zyl_fli_lrg_her <- emmeans(glmm_zyl_fli_lrg_w5_1, "treatment", type = "response")
emm_zyl_fli_lrg_her         <- multcomp::cld(emm_zyl_fli_lrg_her, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_her$emmean    <- emm_zyl_fli_lrg_her$emmean * 1000
emm_zyl_fli_lrg_her$lower.CL  <- emm_zyl_fli_lrg_her$lower.CL * 1000
emm_zyl_fli_lrg_her$upper.CL  <- emm_zyl_fli_lrg_her$upper.CL * 1000
emm_zyl_fli_lrg_her$weather_set <- 5
emm_zyl_fli_lrg_her$.group <- trimws(emm_zyl_fli_lrg_her$.group, which = c("both"))

summ_zyl_fli_w1_lrg_her <- summarySE(values_lrg_w1, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w2_lrg_her <- summarySE(values_lrg_w2, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w3_lrg_her <- summarySE(values_lrg_w3, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w4_lrg_her <- summarySE(values_lrg_w4, measurevar = "zyl_fli", groupvars = c("treatment"))
summ_zyl_fli_w1_lrg_her$weather_set <- 1
summ_zyl_fli_w2_lrg_her$weather_set <- 2
summ_zyl_fli_w3_lrg_her$weather_set <- 3
summ_zyl_fli_w4_lrg_her$weather_set <- 4
summ_zyl_fli_w1_lrg_her$emmean <- summ_zyl_fli_w1_lrg_her$zyl_fli
summ_zyl_fli_w1_lrg_her$lower.CL <- summ_zyl_fli_w1_lrg_her$zyl_fli - summ_zyl_fli_w1_lrg_her$ci
summ_zyl_fli_w1_lrg_her$upper.CL <- summ_zyl_fli_w1_lrg_her$zyl_fli + summ_zyl_fli_w1_lrg_her$ci
summ_zyl_fli_w1_lrg_her$.group <- " "
summ_zyl_fli_w2_lrg_her$emmean <- summ_zyl_fli_w2_lrg_her$zyl_fli
summ_zyl_fli_w2_lrg_her$lower.CL <- summ_zyl_fli_w2_lrg_her$zyl_fli - summ_zyl_fli_w2_lrg_her$ci
summ_zyl_fli_w2_lrg_her$upper.CL <- summ_zyl_fli_w2_lrg_her$zyl_fli + summ_zyl_fli_w2_lrg_her$ci
summ_zyl_fli_w2_lrg_her$.group <- " "
summ_zyl_fli_w3_lrg_her$emmean <- summ_zyl_fli_w3_lrg_her$zyl_fli
summ_zyl_fli_w3_lrg_her$lower.CL <- summ_zyl_fli_w3_lrg_her$zyl_fli - summ_zyl_fli_w3_lrg_her$ci
summ_zyl_fli_w3_lrg_her$upper.CL <- summ_zyl_fli_w3_lrg_her$zyl_fli + summ_zyl_fli_w3_lrg_her$ci
summ_zyl_fli_w3_lrg_her$.group <- " "
summ_zyl_fli_w4_lrg_her$emmean <- summ_zyl_fli_w4_lrg_her$zyl_fli
summ_zyl_fli_w4_lrg_her$lower.CL <- summ_zyl_fli_w4_lrg_her$zyl_fli - summ_zyl_fli_w4_lrg_her$ci
summ_zyl_fli_w4_lrg_her$upper.CL <- summ_zyl_fli_w4_lrg_her$zyl_fli + summ_zyl_fli_w4_lrg_her$ci
summ_zyl_fli_w4_lrg_her$.group <- " "

common_cols_zyl_fli_lrg_her <- intersect(colnames(emm_zyl_fli_lrg_her), colnames(summ_zyl_fli_w1_lrg_her))
summ_zyl_fli_all_lrg_her <- rbind(#subset(summ_zyl_fli_w1_lrg_her, select = common_cols_zyl_fli_lrg_her),
                                  subset(summ_zyl_fli_w2_lrg_her, select = common_cols_zyl_fli_lrg_her),
                                  subset(summ_zyl_fli_w3_lrg_her, select = common_cols_zyl_fli_lrg_her),
                                  subset(summ_zyl_fli_w4_lrg_her, select = common_cols_zyl_fli_lrg_her),
                                  subset(emm_zyl_fli_lrg_her, select = common_cols_zyl_fli_lrg_her))
summ_zyl_fli_all_lrg_her$weather_set <- as.factor(summ_zyl_fli_all_lrg_her$weather_set)

plot_zyl_fli_lrg_her <- ggplot(data = summ_zyl_fli_all_lrg_her, aes(y = emmean, x = treatment,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Fencing treatment", y = "Fireline intensity (kW/m)") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none") +
  ylim(0, 7500) +
  labs(colour = "weather set") +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed')
plot_zyl_fli_lrg_her
########################
emm_zyl_fli_lrg_tsf <- emmeans(glmm_zyl_fli_lrg_w5_1, "tsf_factor", type = "response")
emm_zyl_fli_lrg_tsf <- multcomp::cld(emm_zyl_fli_lrg_tsf, alpha = 0.10, Letters = LETTERS)
emm_zyl_fli_lrg_tsf$emmean    <- emm_zyl_fli_lrg_tsf$emmean * 1000
emm_zyl_fli_lrg_tsf$lower.CL  <- emm_zyl_fli_lrg_tsf$lower.CL * 1000
emm_zyl_fli_lrg_tsf$upper.CL  <- emm_zyl_fli_lrg_tsf$upper.CL * 1000
emm_zyl_fli_lrg_tsf$weather_set <- 5
emm_zyl_fli_lrg_tsf$.group <- trimws(emm_zyl_fli_lrg_tsf$.group, which = c("both"))

summ_zyl_fli_w1_lrg_tsf <- summarySE(values_lrg_w1, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w2_lrg_tsf <- summarySE(values_lrg_w2, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w3_lrg_tsf <- summarySE(values_lrg_w3, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w4_lrg_tsf <- summarySE(values_lrg_w4, measurevar = "zyl_fli", groupvars = c("tsf_factor"))
summ_zyl_fli_w1_lrg_tsf$weather_set <- 1
summ_zyl_fli_w2_lrg_tsf$weather_set <- 2
summ_zyl_fli_w3_lrg_tsf$weather_set <- 3
summ_zyl_fli_w4_lrg_tsf$weather_set <- 4
summ_zyl_fli_w1_lrg_tsf$emmean <- summ_zyl_fli_w1_lrg_tsf$zyl_fli
summ_zyl_fli_w1_lrg_tsf$lower.CL <- summ_zyl_fli_w1_lrg_tsf$zyl_fli - summ_zyl_fli_w1_lrg_tsf$ci
summ_zyl_fli_w1_lrg_tsf$upper.CL <- summ_zyl_fli_w1_lrg_tsf$zyl_fli + summ_zyl_fli_w1_lrg_tsf$ci
summ_zyl_fli_w1_lrg_tsf$.group <- " "
summ_zyl_fli_w2_lrg_tsf$emmean <- summ_zyl_fli_w2_lrg_tsf$zyl_fli
summ_zyl_fli_w2_lrg_tsf$lower.CL <- summ_zyl_fli_w2_lrg_tsf$zyl_fli - summ_zyl_fli_w2_lrg_tsf$ci
summ_zyl_fli_w2_lrg_tsf$upper.CL <- summ_zyl_fli_w2_lrg_tsf$zyl_fli + summ_zyl_fli_w2_lrg_tsf$ci
summ_zyl_fli_w2_lrg_tsf$.group <- " "
summ_zyl_fli_w3_lrg_tsf$emmean <- summ_zyl_fli_w3_lrg_tsf$zyl_fli
summ_zyl_fli_w3_lrg_tsf$lower.CL <- summ_zyl_fli_w3_lrg_tsf$zyl_fli - summ_zyl_fli_w3_lrg_tsf$ci
summ_zyl_fli_w3_lrg_tsf$upper.CL <- summ_zyl_fli_w3_lrg_tsf$zyl_fli + summ_zyl_fli_w3_lrg_tsf$ci
summ_zyl_fli_w3_lrg_tsf$.group <- " "
summ_zyl_fli_w4_lrg_tsf$emmean <- summ_zyl_fli_w4_lrg_tsf$zyl_fli
summ_zyl_fli_w4_lrg_tsf$lower.CL <- summ_zyl_fli_w4_lrg_tsf$zyl_fli - summ_zyl_fli_w4_lrg_tsf$ci
summ_zyl_fli_w4_lrg_tsf$upper.CL <- summ_zyl_fli_w4_lrg_tsf$zyl_fli + summ_zyl_fli_w4_lrg_tsf$ci
summ_zyl_fli_w4_lrg_tsf$.group <- " "

common_cols_zyl_fli_lrg_tsf <- intersect(colnames(emm_zyl_fli_lrg_tsf), colnames(summ_zyl_fli_w1_lrg_tsf))
summ_zyl_fli_all_lrg_tsf <- rbind(#subset(summ_zyl_fli_w1_lrg_tsf, select = common_cols_zyl_fli_lrg_tsf),
                                  subset(summ_zyl_fli_w2_lrg_tsf, select = common_cols_zyl_fli_lrg_tsf),
                                  subset(summ_zyl_fli_w3_lrg_tsf, select = common_cols_zyl_fli_lrg_tsf),
                                  subset(summ_zyl_fli_w4_lrg_tsf, select = common_cols_zyl_fli_lrg_tsf),
                                  subset(emm_zyl_fli_lrg_tsf, select = common_cols_zyl_fli_lrg_tsf))
summ_zyl_fli_all_lrg_tsf$weather_set <- as.factor(summ_zyl_fli_all_lrg_tsf$weather_set)

plot_zyl_fli_lrg_tsf <- ggplot(data = summ_zyl_fli_all_lrg_tsf, aes(y = emmean, x = tsf_factor,  
                                                                    ymin = lower.CL, ymax = upper.CL,
                                                                    colour = weather_set)) +
  labs(x = "Time since fire (years)", y = " ") +
  geom_point(position = position_dodge(width = 0.3)) +
  theme_classic() +
  scale_color_grey(start = 0.8, end = 0) +
  theme(legend.position = "none", axis.title.y = element_text(margin = margin(b = 70))) +
  ylim(0, 7500) +
  geom_errorbar(position = position_dodge(width = 0.3), size = 1, width = 0.2) +
  geom_text(aes(label = .group, y = upper.CL + 500), position = position_dodge(width = 0.3)) +
  geom_hline(yintercept = 2000, linetype='dotted') +
  geom_hline(yintercept = 3000, linetype='dotdash') +
  geom_hline(yintercept = 4000, linetype='dashed') 
plot_zyl_fli_lrg_tsf

#########################################################
###############################################################
###################################################################
#########################################################################
####################################################################################################

legend_weather <- cowplot::get_legend(plot_mkv_fht_lrg_her + guides(color = guide_legend(nrow = 1)) + theme(legend.position = "bottom"))

fin_mkv_plots_sml <- cowplot::plot_grid(plot_mkv_fht_sml_her, plot_mkv_fht_sml_tsf,
                                        plot_mkv_ros_sml_her, plot_mkv_ros_sml_tsf,plot_mkv_fli_sml_her, plot_mkv_fli_sml_tsf, ncol = 2,
                                        labels = "AUTO", label_x = 0.9, label_y = 1)
fin_mkv_plots_sml_leg <- cowplot::plot_grid(fin_mkv_plots_sml, legend_weather, ncol = 1, rel_heights = c(1, .1))
fin_mkv_plots_sml_leg
ggsave("fig_mkv_sml.tiff", width = 8.59, height = 12, units = c("in"))

fin_mkv_plots_lrg <- cowplot::plot_grid(plot_mkv_fht_lrg_her, plot_mkv_fht_lrg_tsf,
                                        plot_mkv_ros_lrg_her, plot_mkv_ros_lrg_tsf, plot_mkv_fli_lrg_her, plot_mkv_fli_lrg_tsf, ncol = 2,
                                        labels = "AUTO", label_x = 0.9, label_y = 1)
fin_mkv_plots_lrg_leg <- cowplot::plot_grid(fin_mkv_plots_lrg, legend_weather,ncol = 1, rel_heights = c(1, .1))
fin_mkv_plots_lrg_leg
ggsave("fig_mkv_lrg.tiff", width = 8.59, height = 12, units = c("in"))

fin_ves2_plots_sml <- cowplot::plot_grid(plot_ves2_fht_sml_her, plot_ves2_fht_sml_tsf,
                                        plot_ves2_ros_sml_her, plot_ves2_ros_sml_tsf,
                                        plot_ves2_fli_sml_her, plot_ves2_fli_sml_tsf, ncol = 2, 
                                        labels = "AUTO", label_x = 0.9, label_y = 1)
fin_ves2_plots_sml_leg <- cowplot::plot_grid(fin_ves2_plots_sml, legend_weather, ncol = 1, rel_heights = c(1, .1))
fin_ves2_plots_sml_leg
ggsave("fig_ves2_sml.tiff", width = 8.59, height = 12, units = c("in"))

fin_ves2_plots_lrg <- cowplot::plot_grid(plot_ves2_fht_lrg_her, plot_ves2_fht_lrg_tsf,
                                        plot_ves2_ros_lrg_her, plot_ves2_ros_lrg_tsf, 
                                        plot_ves2_fli_lrg_her, plot_ves2_fli_lrg_tsf, ncol = 2,
                                        labels = "AUTO", label_x = 0.9, label_y = 1)
fin_ves2_plots_lrg_leg <- cowplot::plot_grid(fin_ves2_plots_lrg, legend_weather,ncol = 1, rel_heights = c(1, .1))
fin_ves2_plots_lrg_leg
ggsave("fig_ves2_lrg.tiff", width = 8.59, height = 12, units = c("in"))

fin_zyl_plots_sml <- cowplot::plot_grid(plot_zyl_fht_sml_her, plot_zyl_fht_sml_tsf,
                                        plot_zyl_ros_sml_her, plot_zyl_ros_sml_tsf,plot_zyl_fli_sml_her, plot_zyl_fli_sml_tsf, ncol = 2,
                                        labels = "AUTO", label_x = 0.9, label_y = 1)
fin_zyl_plots_sml_leg <- cowplot::plot_grid(fin_zyl_plots_sml, legend_weather, ncol = 1, rel_heights = c(1, .1))
fin_zyl_plots_sml_leg
ggsave("fig_zyl_sml.tiff", width = 8.59, height = 12, units = c("in"))

fin_zyl_plots_lrg <- cowplot::plot_grid(plot_zyl_fht_lrg_her, plot_zyl_fht_lrg_tsf,
                                        plot_zyl_ros_lrg_her, plot_zyl_ros_lrg_tsf, plot_zyl_fli_lrg_her, plot_zyl_fli_lrg_tsf, ncol = 2,
                                        labels = "AUTO", label_x = 0.9, label_y = 1)
fin_zyl_plots_lrg_leg <- cowplot::plot_grid(fin_zyl_plots_lrg, legend_weather,ncol = 1, rel_heights = c(1, .1))
fin_zyl_plots_lrg_leg
ggsave("fig_zyl_lrg.tiff", width = 8.59, height = 12, units = c("in"))


#################################################################
#################################################################
#################################################################
#################################################################

fin_fuel_plots
ggsave("fig_tot_fuel.tiff", height = 9, units = c("in"))

fin_mkv_plots
ggsave("fig_mkv2.tiff", width = 8.59, height = 12, units = c("in"))

fin_ves_plots
ggsave("fig_ves.tiff", width = 8.59, height = 12, units = c("in"))

fin_zyl_plots
ggsave("fig_zyl.tiff", width = 8.59, height = 12, units = c("in"))
